#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#!BuildIgnore: Mesa-dri

%global flavor %{nil}
%if "%{flavor}" == "drivers"
%global psuffix -drivers
%else
%global psuffix %{nil}
%endif

%ifarch armv6l armv6hl
%define _lto_cflags %{nil}
%endif

# Possible patent issues, see
# https://gitlab.freedesktop.org/mesa/mesa/-/merge_requests/15258
# for more details
%if 0%{?BUILD_ORIG}
%define video_codecs 1
%else
%define video_codecs 0
%endif

%define drivers 0

%define glamor 1
%define _name_archive mesa
%define _version 23.3.0
%define with_opencl 0
%define with_rusticl 0
%define with_vulkan 0
%define with_llvm 0

%ifarch %{ix86} x86_64 %{arm} aarch64 ppc64 ppc64le riscv64
  %define gallium_loader 1
%else
  %define gallium_loader 0
%endif

%define vdpau_nouveau 0
%define vdpau_radeon 0
%define vdpau_virtio_gpu 0

%ifarch %{ix86} x86_64 aarch64 %{arm} ppc64 ppc64le riscv64
  %define vdpau_nouveau 1
  %define vdpau_radeon 1
  %define vdpau_virtio_gpu 1
%endif

%ifarch %{ix86} x86_64
  %define with_nine 1
%endif

%if 0%{gallium_loader}
  %define with_opencl 1
  %ifarch %{ix86} x86_64
    %define with_vulkan 1
    %define vulkan_drivers swrast,amd,intel,intel_hasvk
  %endif
  %ifarch %{arm} aarch64
    %define with_vulkan 1
    %define vulkan_drivers swrast,amd,broadcom,freedreno
  %endif
  %ifarch riscv64
    %define with_vulkan 1
    %define vulkan_drivers swrast,amd
  %endif
%endif

%ifarch aarch64 %{arm} ppc64 ppc64le riscv64 s390x %{ix86} x86_64
  %define with_llvm 1
%endif

%if 0%{with_opencl}
%define have_gallium 1
%else
%define have_gallium 0
%endif

%if "%{flavor}" == "drivers"
  %define glamor 0
%if 0%{?suse_version} > 1550 && 0%{with_opencl}
  %define with_rusticl 1
%endif
%else
  # No llvm dependencies
  %define with_llvm 0

  # OpenCL requires clang (LLVM)
  %define with_opencl 0

  # nine requires at least one non-swrast gallium driver
  %define with_nine 0

  # Not built because radeon driver is not built.
  %define vdpau_radeon 0

  # Not built because nouveau driver is not built.
  %define vdpau_nouveau 0

  # Not built because virtio_gpu driver is not built.
  %define vdpau_virtio_gpu 0

  # Vulkan includes radv driver which requires llvm
  %define with_vulkan 0
%endif

Name:           Mesa%{psuffix}
Version:        23.3.0
Release:        1.2
Summary:        System for rendering 3-D graphics
License:        MIT
Group:          System/Libraries
URL:            https://www.mesa3d.org
#Git-Clone:     git://anongit.freedesktop.org/mesa/mesa
Source:         https://archive.mesa3d.org/%{_name_archive}-%{_version}.tar.xz
#Source1:        https://archive.mesa3d.org/.tar.xz.sig
Source2:        baselibs.conf
Source3:        README.updates
Source4:        manual-pages.tar.bz2
Source6:        Mesa-rpmlintrc
Source7:        Mesa.keyring
Patch2:         n_add-Mesa-headers-again.patch
Patch3:         0001-hasvk-Force-to-expose-1.3-just-ignore-the-conformanc.patch
Patch4:         25742.patch
Patch5:         25841.patch
# Patches for LLVM 17, should all be in 23.2.
#Patch4:         U_clover-llvm-move-to-modern-pass-manager.patch
#Patch10:        U_radeonsi-prefix-function-with-si_-to-prevent-name-co.patch
# never to be upstreamed
#Patch54:        n_drirc-disable-rgb10-for-chromium-on-amd.patch
#Patch58:        u_dep_xcb.patch
#Patch100:       U_fix-mpeg1_2-decode-mesa-20.2.patch
#Patch200:       u_fix-build-on-ppc64le.patch
#Patch400:       n_stop-iris-flicker.patch
%ifarch %{ix86} x86_64
BuildRequires:  DirectX-Headers
%endif
BuildRequires:  bison
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  flex
%if 0%{?sle_version} >= 150400
BuildRequires:  gcc12-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  glslang-devel
BuildRequires:  imake
BuildRequires:  libtool
BuildRequires:  memory-constraints
BuildRequires:  meson >= 0.60
BuildRequires:  pkgconfig
BuildRequires:  python3-base
# dataclasses is in standard library of python >= 3.7
%if 0%{?suse_version} < 1550
BuildRequires:  python3-dataclasses
%endif
BuildRequires:  python3-Mako
BuildRequires:  python3-xml
BuildRequires:  pkgconfig(dri2proto)
BuildRequires:  pkgconfig(dri3proto)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(glproto)
BuildRequires:  pkgconfig(libdrm) >= 2.4.75
BuildRequires:  pkgconfig(libdrm_amdgpu) >= 2.4.95
BuildRequires:  pkgconfig(libdrm_nouveau) >= 2.4.66
BuildRequires:  pkgconfig(libdrm_radeon) >= 2.4.71
BuildRequires:  pkgconfig(libglvnd) >= 0.1.0
%ifarch aarch64 %{ix86} x86_64 ppc64le s390x
BuildRequires:  pkgconfig(valgrind)
%endif
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(presentproto)
%if "%{flavor}" == "drivers"
BuildRequires:  pkgconfig(vdpau) >= 1.1
%ifarch %{ix86} x86_64
BuildRequires:  pkgconfig(vulkan)
%endif
%endif
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(x11-xcb)
BuildRequires:  pkgconfig(xcb-dri2)
BuildRequires:  pkgconfig(xcb-dri3)
BuildRequires:  pkgconfig(xcb-glx)
BuildRequires:  pkgconfig(xcb-present)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xshmfence)
BuildRequires:  pkgconfig(xxf86vm)
BuildRequires:  pkgconfig(zlib)
Provides:       Mesa7 = %{version}
Obsoletes:      Mesa7 < %{version}
Provides:       intel-i810-Mesa = %{version}
Obsoletes:      intel-i810-Mesa < %{version}
Provides:       Mesa-libIndirectGL1 = %{version}
Obsoletes:      Mesa-libIndirectGL1 < %{version}
Provides:       Mesa-nouveau3d = %{version}
Provides:       xorg-x11-Mesa = %{version}
Obsoletes:      Mesa-nouveau3d < %{version}
Obsoletes:      xorg-x11-Mesa < %{version}
Provides:       s2tc = %{version}
Obsoletes:      s2tc < %{version}
Provides:       libXvMC_nouveau = %{version}
Obsoletes:      libXvMC_nouveau < %{version}
Provides:       libXvMC_r600 = %{version}
Obsoletes:      libXvMC_r600 < %{version}
Provides:       libtxc_dxtn = %{version}
Obsoletes:      libtxc_dxtn < %{version}
%ifarch %{arm} aarch64
BuildRequires:  pkgconfig(libdrm_etnaviv) >= 2.4.89
BuildRequires:  pkgconfig(libdrm_freedreno) >= 2.4.74
BuildRequires:  pkgconfig(libelf)
%endif
%ifarch x86_64 %{ix86}
BuildRequires:  libelf-devel
BuildRequires:  pkgconfig(libdrm_intel) >= 2.4.75
%else
%if 0%{with_opencl}
BuildRequires:  libelf-devel
%endif
%endif
# Requirements for wayland bumped up from 17.0
BuildRequires:  pkgconfig(wayland-client) >= 1.11
BuildRequires:  pkgconfig(wayland-protocols) >= 1.8
BuildRequires:  pkgconfig(wayland-server) >= 1.11
%if 0%{with_llvm}
%if 0%{?suse_version} >= 1550
BuildRequires:  llvm-devel
%else
%if 0%{?sle_version} >= 150500
BuildRequires:  llvm15-devel
%else
%if 0%{?sle_version} >= 150400
BuildRequires:  llvm13-devel
%else
%if 0%{?sle_version} >= 150300
BuildRequires:  llvm11-devel
%else
BuildRequires:  llvm9-devel
%endif
%endif
%endif
%endif
%endif

%if 0%{with_opencl}
%if 0%{?suse_version} >= 1550
BuildRequires:  clang-devel
%else
%if 0%{?sle_version} >= 150500
BuildRequires:  clang15-devel
%else
%if 0%{?sle_version} >= 150400
BuildRequires:  clang13-devel
%else
%if 0%{?sle_version} >= 150300
BuildRequires:  clang11-devel
%else
BuildRequires:  clang9-devel
%endif
%endif
%endif
%endif
BuildRequires:  libclc
%if 0%{with_rusticl}
BuildRequires:  rust
BuildRequires:  rust-bindgen
BuildRequires:  pkgconfig(LLVMSPIRVLib)
BuildRequires:  pkgconfig(SPIRV-Tools)
%endif
%endif

Requires:       Mesa-libEGL1 = %{version}
Requires:       Mesa-libGL1 = %{version}
Requires:       libglvnd >= 0.1.0

# This dependency on Mesa-dri and Mesa-gallium is here to make sure users that
# do not install recommends on their system still get working Mesa. It is
# ignored in obs when Mesa is installed as build dependency.
Requires:       Mesa-dri = %{version}
%if 0%{have_gallium}
Requires:       Mesa-gallium = %{version}
%endif

%description
Mesa is a 3-D graphics library with an API which is very similar to
that of OpenGL.* To the extent that Mesa utilizes the OpenGL command
syntax or state machine, it is being used with authorization from
Silicon Graphics, Inc.(SGI). However, the author does not possess an
OpenGL license from SGI, and makes no claim that Mesa is in any way a
compatible replacement for OpenGL or associated with SGI. Those who
want a licensed implementation of OpenGL should contact a licensed
vendor.

Please do not refer to the library as MesaGL (for legal reasons). It's
just Mesa or The Mesa 3-D graphics library.

* OpenGL is a trademark of Silicon Graphics Incorporated.

%package devel
Summary:        Libraries, includes and more to develop Mesa applications
Group:          Development/Libraries/X11
Requires:       Mesa = %{version}
Requires:       Mesa-dri-devel = %{version}
Requires:       Mesa-libEGL-devel = %{version}
Requires:       Mesa-libGL-devel = %{version}
Requires:       Mesa-libGLESv1_CM-devel = %{version}
Requires:       Mesa-libGLESv2-devel = %{version}
Requires:       Mesa-libglapi-devel = %{version}
Requires:       libOSMesa-devel = %{version}
Requires:       libgbm-devel
Provides:       Mesa-devel-static = %{version}
Provides:       xorg-x11-Mesa-devel = %{version}
Requires:       libglvnd-devel >= 1.2.0
Obsoletes:      Mesa-devel-static < %{version}
Obsoletes:      xorg-x11-Mesa-devel < %{version}
Provides:       Mesa-libIndirectGL-devel = %{version}
Obsoletes:      Mesa-libIndirectGL-devel < %{version}
Provides:       s2tc-devel = %{version}
Obsoletes:      s2tc-devel < %{version}
Provides:       libtxc_dxtn-devel = %{version}
Obsoletes:      libtxc_dxtn-devel < %{version}

%description devel
Mesa is a 3-D graphics library with an API which is very similar to
that of OpenGL.* To the extent that Mesa utilizes the OpenGL command
syntax or state machine, it is being used with authorization from
Silicon Graphics, Inc.(SGI). However, the author does not possess an
OpenGL license from SGI, and makes no claim that Mesa is in any way a
compatible replacement for OpenGL or associated with SGI. Those who
want a licensed implementation of OpenGL should contact a licensed
vendor.

Please do not refer to the library as MesaGL (for legal reasons). It's
just Mesa or The Mesa 3-D graphics library.

* OpenGL is a trademark of Silicon Graphics Incorporated.

%package libEGL1
# Kudos to Debian for the descriptions
Summary:        EGL API implementation
Group:          System/Libraries
Requires:       libglvnd >= 0.1.0

%description libEGL1
This package contains the EGL native platform graphics interface
library. EGL provides a platform-agnostic mechanism for creating
rendering surfaces for use with other graphics libraries, such as
OpenGL|ES and OpenVG.

This package contains modules to interface with the existing system
GLX or DRI2 drivers to provide OpenGL via EGL. The Mesa main package
provides drivers to provide hardware-accelerated OpenGL|ES and OpenVG
support.

%package libEGL-devel
Summary:        Development files for the EGL API
Group:          Development/Libraries/C and C++
Requires:       Mesa-KHR-devel = %{version}
Requires:       Mesa-libEGL1 = %{version}
Requires:       libglvnd-devel >= 0.1.0
Requires:       pkgconfig(x11)
# Other requires taken care of by pkgconfig already

%description libEGL-devel
This package contains the development environment required for
compiling programs against EGL native platform graphics interface
library. EGL provides a platform-agnostic mechanism for creating
rendering surfaces for use with other graphics libraries, such as
OpenGL|ES and OpenVG.

This package provides the development environment for compiling
programs against the EGL library.

%package KHR-devel
Summary:        Mesa Khronos development headers
Group:          Development/Libraries/C and C++
Provides:       Mesa-libGL-devel:/usr/include/KHR/khrplatform.h

%description KHR-devel
Mesa Khronos development headers.

%package libGL1
Summary:        The GL/GLX runtime of the Mesa 3D graphics library
Group:          System/Libraries
Requires:       Mesa = %{version}
Requires:       libglvnd >= 0.1.0

%description libGL1
Mesa is a software library for 3D computer graphics that provides a
generic OpenGL implementation for rendering three-dimensional
graphics.

GLX ("OpenGL Extension to the X Window System") provides the
interface connecting OpenGL and the X Window System: it enables
programs wishing to use OpenGL to do so within a window provided by
the X Window System.

%package libGL-devel
Summary:        GL/GLX development files of the OpenGL API
Group:          Development/Libraries/C and C++
Requires:       Mesa-KHR-devel = %{version}
Requires:       Mesa-libGL1 = %{version}
Requires:       libglvnd-devel >= 0.1.0
Requires:       pkgconfig(x11)

%description libGL-devel
Mesa is a software library for 3D computer graphics that provides a
generic OpenGL implementation for rendering three-dimensional
graphics.

This package includes headers and static libraries for compiling
programs with Mesa.

%package libGLESv1_CM-devel
Summary:        Development files for the OpenGL ES 1.x API
Group:          Development/Libraries/C and C++
Requires:       Mesa-KHR-devel = %{version}
Requires:       libglvnd-devel >= 0.1.0
Requires:       pkgconfig(egl)

%description libGLESv1_CM-devel
OpenGL|ES is an API for full-function 2D and 3D
graphics on embedded systems - including consoles, phones, appliances
and vehicles. It contains a subset of OpenGL plus a number of
extensions for the special needs of embedded systems.

OpenGL|ES 1.x provides an API for fixed-function hardware.

This package provides a development environment for building programs
using the OpenGL|ES 1.x APIs.

%package libGLESv2-devel
Summary:        Development files for the OpenGL ES 2.x API
Group:          Development/Libraries/C and C++
Requires:       Mesa-KHR-devel = %{version}
Requires:       libglvnd-devel >= 0.1.0
Requires:       pkgconfig(egl)

%description libGLESv2-devel
OpenGL|ES is an API for full-function 2D and 3D
graphics on embedded systems - including consoles, phones, appliances
and vehicles. It contains a subset of OpenGL plus a number of
extensions for the special needs of embedded systems.

OpenGL|ES 2.x provides an API for programmable hardware including
vertex and fragment shaders.

This package provides a development environment for building
applications using the OpenGL|ES 2.x APIs.

%package libGLESv3-devel
Summary:        Development files for the OpenGL ES 3.x API
Group:          Development/Libraries/C and C++
Requires:       Mesa-KHR-devel = %{version}
Requires:       pkgconfig(egl)

%description libGLESv3-devel
OpenGL|ES is an API for full-function 2D and 3D
graphics on embedded systems - including consoles, phones, appliances
and vehicles. It contains a subset of OpenGL plus a number of
extensions for the special needs of embedded systems.

This package provides a development environment for building
applications using the OpenGL|ES 3.x APIs.

%package -n libOSMesa8
Summary:        Mesa Off-screen rendering extension
# Wrongly named package shipped .so.8
Group:          System/Libraries
Obsoletes:      libOSMesa9 < %{version}
Provides:       libOSMesa9 = %{version}

%description -n libOSMesa8
OSmesa is a Mesa extension that allows programs to render to an
off-screen buffer using the OpenGL API without having to create a
rendering context on an X Server. It uses a pure software renderer.

%package -n libOSMesa-devel
Summary:        Development files for the Mesa Offscreen Rendering extension
Group:          Development/Libraries/C and C++
Requires:       libOSMesa8 = %{version}

%description -n libOSMesa-devel
Development files for the OSmesa Mesa extension that allows programs to render to an
off-screen buffer using the OpenGL API without having to create a
rendering context on an X Server. It uses a pure software renderer.

%package libglapi0
Summary:        Free implementation of the GL API
Group:          System/Libraries

%description libglapi0
The Mesa GL API module is responsible for dispatching all the gl*
functions. It is intended to be mainly used by the Mesa-libGLES*
packages.

%package libglapi-devel
Summary:        Development files for the Mesa GL API implementation
Group:          Development/Libraries/C and C++
Requires:       Mesa-libglapi0 = %{version}

%description libglapi-devel
Development files for the Mesa GL API module which is responsible for
dispatching all the gl* functions. It is intended to be mainly used by
the Mesa-libGLES* packages.

%package -n Mesa-dri
Summary:        DRI plug-ins for 3D acceleration
Group:          System/Libraries
Requires:       Mesa = %{version}
Supplements:    Mesa

%description -n Mesa-dri
This package contains Mesa DRI drivers for 3D acceleration.

%package dri-devel
Summary:        Development files for the DRI API
Group:          Development/Libraries/C and C++
Requires:       Mesa = %{version}

%description dri-devel
This package contains the development environment required for
compiling programs and libraries using the DRI API.

%package -n Mesa-dri-nouveau
Summary:        Mesa DRI plug-in for 3D acceleration via Nouveau
Group:          System/Libraries
Requires:       Mesa = %{version}

%description -n Mesa-dri-nouveau
This package contains nouveau_dri.so, which is necessary for
Nouveau's 3D acceleration to work. It is packaged separately
since it is still experimental.

%package -n Mesa-dri-vc4
Summary:        Mesa DRI plug-in for 3D acceleration on Raspberry Pi
Group:          System/Libraries
Requires:       Mesa = %{version}

%description -n Mesa-dri-vc4
This package contains vc4_dri.so, which is necessary for 3D
acceleration on the Raspberry Pi to work. It is packaged separately
since it is still experimental.

%package -n Mesa-gallium
Summary:        Mesa Gallium GPU drivers
Group:          System/Libraries
Requires:       Mesa = %{version}
Supplements:    Mesa

%description -n Mesa-gallium
This package contains Mesa Gallium drivers for 3D acceleration.

%package -n libgbm1
Summary:        Generic buffer management API
Group:          System/Libraries

%description -n libgbm1
This package contains the GBM buffer management library. It provides
a mechanism for allocating buffers for graphics rendering tied to
Mesa.

GBM is intended to be used as a native platform for EGL on drm or
openwfd.

%package -n libgbm-devel
Summary:        Development files for the EGL API
Group:          Development/Libraries/C and C++
Requires:       libgbm1 = %{version}

%description -n libgbm-devel
This package contains the GBM buffer management library. It provides
a mechanism for allocating buffers for graphics rendering tied to
Mesa.

GBM is intended to be used as a native platform for EGL on drm or
openwfd.

This package provides the development environment for compiling
programs against the GBM library.

%package -n Mesa-libd3d
Summary:        Mesa Direct3D9 state tracker
# Manually provide d3d library (bnc#918294)
Group:          System/Libraries
%ifarch x86_64 s390x ppc64 ppc64le aarch64 riscv64
Provides:       d3dadapter9.so.1()(64bit)
%else
Provides:       d3dadapter9.so.1
%endif

%description -n Mesa-libd3d
Mesa Direct3D9 state tracker

%package -n Mesa-libd3d-devel
Summary:        Mesa Direct3D9 state tracker development package
Group:          Development/Libraries/C and C++
Requires:       Mesa-libd3d = %{version}

%description -n Mesa-libd3d-devel
Mesa Direct3D9 state tracker development package

%package -n libvdpau_nouveau
Summary:        VDPAU state tracker for Nouveau
Group:          System/Libraries
Supplements:    modalias(pci:v000010DEd*sv*sd*bc03sc*i*)
Supplements:    modalias(pci:v000012D2d*sv*sd*bc03sc*i*)

%description -n libvdpau_nouveau
This package contains the VDPAU state tracker for Nouveau.

%package -n libvdpau_r600
Summary:        VDPAU state tracker for R600
Group:          System/Libraries
Supplements:    modalias(pci:v00001002d*sv*sd*bc03sc*i*)

%description -n libvdpau_r600
This package contains the VDPAU state tracker for R600.

%package -n libvdpau_radeonsi
Summary:        VDPAU state tracker for radeonsi
Group:          System/Libraries
Supplements:    modalias(pci:v00001002d*sv*sd*bc03sc*i*)

%description -n libvdpau_radeonsi
This package contains the VDPAU state tracker for radeonsi.

%package -n libvdpau_virtio_gpu
Summary:        VDPAU state tracker for VirtIO GPU
Group:          System/Libraries

%description -n libvdpau_virtio_gpu
This package contains the VDPAU state tracker for VirtIO GPU.

%package -n Mesa-libOpenCL
Summary:        Mesa OpenCL implementation (Clover)
Group:          System/Libraries
%if 0%{?suse_version} >= 1550 || 0%{?sle_version} >= 150300
Requires:       libclc(llvm%{_llvm_sonum})
%else
Requires:       libclc
%endif

%description -n Mesa-libOpenCL
This package contains the Mesa OpenCL implementation or GalliumCompute.

%package -n Mesa-libRusticlOpenCL
Summary:        Mesa OpenCL implementation (Rusticl)
Group:          System/Libraries
%if 0%{?suse_version} >= 1550 || 0%{?sle_version} >= 150300
Requires:       libclc(llvm%{_llvm_sonum})
%else
Requires:       libclc
%endif

%description -n Mesa-libRusticlOpenCL
This package contains the Mesa Rust-written OpenCL implementation.

%package -n Mesa-libva
Summary:        Mesa VA-API implementation
Group:          System/Libraries
Supplements:    Mesa

%description -n Mesa-libva
This package contains the Mesa VA-API implementation provided through gallium.

%package -n libvulkan_intel
Summary:        Mesa vulkan driver for Intel GPU
Group:          System/Libraries
Supplements:    modalias(pci:v00008086d*sv*sd*bc03sc*i*)
Requires:       Mesa-vulkan-device-select
# get rid of this package, which is no longer neeeded at all
Provides:       Mesa-libVulkan-devel = 22.0.0
Obsoletes:      Mesa-libVulkan-devel < 22.0.0

%description -n libvulkan_intel
This package contains the Vulkan parts for Mesa.

%package -n libvulkan_radeon
Summary:        Mesa vulkan driver for AMD GPU
Group:          System/Libraries
Supplements:    modalias(pci:v00001002d*sv*sd*bc03sc*i*)
Requires:       Mesa-vulkan-device-select

%description -n libvulkan_radeon
This package contains the Vulkan parts for Mesa.

%package -n libvulkan_lvp
Summary:        Mesa vulkan driver for LVP
Group:          System/Libraries
Requires:       Mesa-vulkan-device-select

%description -n libvulkan_lvp
This package contains the Vulkan parts for Mesa.

%ifarch %{arm} aarch64
%package -n libvulkan_broadcom
Summary:        Mesa vulkan driver for Broadcom
Group:          System/Libraries

%description -n libvulkan_broadcom
This package contains the Vulkan parts for Mesa.

%package -n libvulkan_freedreno
Summary:        Mesa vulkan driver for Freedreno
Group:          System/Libraries

%description -n libvulkan_freedreno
This package contains the Vulkan parts for Mesa.
%endif

%package -n Mesa-vulkan-device-select
Summary:        Vulkan layer to select Vulkan devices provided by Mesa
Group:          System/Libraries

%description -n Mesa-vulkan-device-select
This package contains the VK_MESA_device_select Vulkan layer

%package -n Mesa-vulkan-overlay
Summary:        Mesa Vulkan Overlay layer
Group:          System/Libraries

%description -n Mesa-vulkan-overlay
This package contains the VK_MESA_Overlay Vulkan layer

%package -n libxatracker2
Version:        1.0.0
Summary:        XA state tracker
Group:          System/Libraries

%description -n libxatracker2
This package contains the XA state tracker for gallium3D driver.
It superseeds the Xorg state tracker and provides an infrastructure
to accelerate Xorg 2D operations. It is currently used by vmwgfx
video driver.

%package -n libxatracker-devel
Version:        1.0.0
Summary:        Development files for the XA API
Group:          Development/Libraries/C and C++
Requires:       libxatracker2 = %{version}

%description -n libxatracker-devel
This package contains the XA state tracker for gallium3D driver.
It superseeds the Xorg state tracker and provides an infrastructure
to accelerate Xorg 2D operations. It is currently used by vmwgfx
video driver.

This package provides the development environment for compiling
programs against the XA state tracker.

%prep
%setup -q -n %{_name_archive}-%{_version} -b4
# remove some docs
rm -rf docs/README.{VMS,WIN32,OS2}

%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
#patch10 -p1
# no longer needed since gstreamer-plugins-vaapi 1.18.4
%if 0%{?suse_version} < 1550
#patch54 -p1
%endif
#patch58 -p1
#patch100 -p1
#patch200 -p1
#patch400 -p1

# Remove requires to vulkan libs from baselibs.conf on platforms
# where vulkan build is disabled; ugly ...
%if 0%{?with_vulkan} == 0
grep -v -i vulkan "%{_sourcedir}/baselibs.conf" >"%{_sourcedir}/temp" && \
  mv "%{_sourcedir}/temp" "%{_sourcedir}/baselibs.conf"
%endif

%build
# try to avoid OOM on ppc64 (boo#1194739)
%ifarch ppc64 ppc64le
%limit_build -m 1024
%endif
%if 0%{?sle_version} >= 150400
export CC=gcc-12
export CXX=g++-12
%endif

egl_platforms=x11,wayland

# needed to fix build of Mesa 23.1
# Mesa-drivers: -Dshader-cache=enabled
# Mesa: -Dxlib-lease=enabled
# recommended for both Mesa and Mesa-drivers to avoid some scary messages when
# comparing fds: -Dallow-kcmp=enabled
# Credits for figuring this out go to "llyyr" <llyyr.public@gmail.com>

%meson \
            --auto-features=disabled \
%if "%{flavor}" == "drivers"
            -Dosmesa=false \
            -Dglx=disabled \
            -Dxmlconfig=enabled \
            -Dexpat=enabled \
            -Dshader-cache=enabled \
%else
            -Dosmesa=true \
            -Dglx=auto \
            -Dllvm=disabled \
            -Dvulkan-drivers= \
%endif
            -Dxlib-lease=enabled \
            -Dglvnd=true \
            -Dgles1=enabled \
            -Dgles2=enabled \
            -Degl=enabled \
            -Dallow-kcmp=enabled \
            -Dplatforms=$egl_platforms \
            -Ddri3=enabled \
            -Dshared-glapi=enabled \
%if 0%{?with_nine}
            -Dgallium-nine=true \
%endif
%if %{glamor}
            -Dgbm=enabled \
%endif
%if 0%{with_opencl}
            -Dgallium-opencl=icd \
%if 0%{?suse_version} >= 1550
            --sysconfdir=%{_datadir} \
%endif
%if 0%{with_rusticl}
            -Dgallium-rusticl=true \
            -Drust_std=2021 \
%endif
%endif
            -Ddri-search-path=%{_libdir}/dri \
%if 0%{with_llvm}
            -Dllvm=enabled \
            -Dshared-llvm=enabled \
%endif
%if "%{flavor}" == "drivers"
%if %{video_codecs}
            -Dvideo-codecs=h264dec,h264enc,h265dec,h265enc,vc1dec \
%endif
%if %{gallium_loader}
            -Dgallium-vdpau=enabled \
            -Dgallium-va=enabled \
            -Dgallium-xa=enabled \
%endif
%if 0%{with_vulkan}
            -Dvulkan-drivers=%{?vulkan_drivers} \
            -Dvulkan-layers=device-select,overlay \
%else
            -Dvulkan-drivers= \
%endif
  %ifarch %{ix86} x86_64
            -Dgallium-drivers=r300,r600,radeonsi,nouveau,swrast,svga,virgl,iris,crocus,i915,d3d12,zink \
  %else
  %ifarch %{arm} aarch64
            -Dgallium-drivers=r300,r600,radeonsi,nouveau,swrast,virgl,freedreno,vc4,etnaviv,lima,panfrost,v3d,svga,tegra \
  %else
  %ifarch ppc64 ppc64le riscv64
            -Dgallium-drivers=r300,r600,radeonsi,nouveau,swrast,virgl \
  %else
            -Dgallium-drivers=swrast \
  %endif
  %endif
  %endif
%else
            -Dgallium-drivers=swrast \
%endif
%ifarch aarch64 %{ix86} x86_64 ppc64le s390x
            -Dvalgrind=enabled \
%endif
            -Db_ndebug=true \
            -Dc_args="%{optflags}" \
%ifarch %ix86
            -Dcpp_args="$(echo %{optflags}|sed 's/-flto=auto//')"
%else
            -Dcpp_args="%{optflags}"
%endif

%meson_build

%install
%meson_install
find %{buildroot} -type f -name "*.la" -delete -print

# libwayland-egl is provided by wayland itself
rm -f %{buildroot}/%{_libdir}/libwayland-egl.so*
rm -f %{buildroot}/%{_libdir}/pkgconfig/wayland-egl.pc

%if "%{flavor}" == "drivers"
# Delete things that we do not package in the Mesa-drivers variant, but can
# not disable from buildling and installing.

rm -f %{buildroot}/%{_libdir}/libEGL.so*
# in Mesa-libEGL-devel
rm %{buildroot}/%{_includedir}/EGL/egl.h
rm %{buildroot}/%{_includedir}/EGL/eglext.h
rm %{buildroot}/%{_includedir}/EGL/eglext_angle.h
rm %{buildroot}/%{_includedir}/EGL/eglmesaext.h
rm %{buildroot}/%{_includedir}/EGL/eglplatform.h

# in Mesa-libGL-devel
rm -rf %{buildroot}/%{_includedir}/GL

#in Mesa-libGLESv1_CM-devel
rm -rf %{buildroot}/%{_includedir}/GLES

#in Mesa-libGLESv2-devel
rm -rf %{buildroot}/%{_includedir}/GLES2

#in Mesa-libGLESv3-devel
rm -rf %{buildroot}/%{_includedir}/GLES3

#in Mesa-libEGL1
rm -f %{buildroot}/%{_libdir}/libEGL_mesa.so*
rm -rf %{buildroot}/%{_datadir}/glvnd

# in Mesa-libglapi0
rm %{buildroot}/%{_libdir}/libglapi.so*

# in libwayland-egl1
rm -f %{buildroot}/%{_libdir}/libwayland-egl.so*
rm -f %{buildroot}/%{_libdir}/pkgconfig/wayland-egl.pc

# in Mesa-dri-devel
rm %{buildroot}/%{_libdir}/pkgconfig/dri.pc

# in KHR-devel
rm -rf %{buildroot}/%{_includedir}/KHR

# workaround needed since Mesa 19.0.2
rm -f %{buildroot}/%{_libdir}/vdpau/libvdpau_gallium.so

%else
# package in Mesa-dri
rm -rf %{buildroot}/%{_datadir}/drirc.d

rm -f %{buildroot}/%{_libdir}/dri/*_dri.so

rm -f %{buildroot}%{_libdir}/libGLES*
# glvnd needs a default provider for indirect rendering where it cannot
# determine the vendor
ln -s %{_libdir}/libGLX_mesa.so.0 %{buildroot}%{_libdir}/libGLX_indirect.so.0

# pickup pkgconfig files from libglvnd build
rm -f %{buildroot}/%{_libdir}/pkgconfig/{gl,egl,glesv1_cm,glesv2}.pc
install -m 0644 /usr/share/doc/packages/libglvnd/pkgconfig/{gl,egl,glesv1_cm,glesv2}.pc \
   %{buildroot}/%{_libdir}/pkgconfig/

for dir in ../xc/doc/man/{GL/gl,GL/glx}; do
 pushd $dir
   xmkmf -a
   make %{?_smp_mflags} V=1
   make install.man DESTDIR=%{buildroot} MANPATH=%{_mandir} LIBMANSUFFIX=3gl
 popd
done
%endif

%fdupes -s %{buildroot}/%{_mandir}

%if "%{flavor}" != "drivers"
# Use dummy README file that can be included in both Mesa and Mesa-32bit. This way Mesa-32bit will be build (otherwise it would be skipped as empty) and it can be used by the other *-32bit packages.
echo "The \"Mesa\" package does not have the ability to render, but is supplemented by \"Mesa-dri\" and \"Mesa-gallium\" which contain the drivers for rendering" > docs/README.package.%{_arch}
%endif

%post   -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post   libEGL1 -p /sbin/ldconfig

%postun libEGL1 -p /sbin/ldconfig

%post   libGL1 -p /sbin/ldconfig

%postun libGL1 -p /sbin/ldconfig

%post   -n libOSMesa8 -p /sbin/ldconfig

%postun -n libOSMesa8 -p /sbin/ldconfig

%post   -n libgbm1 -p /sbin/ldconfig

%postun -n libgbm1 -p /sbin/ldconfig

%post   -n libxatracker2 -p /sbin/ldconfig

%postun -n libxatracker2 -p /sbin/ldconfig

%post   libglapi0 -p /sbin/ldconfig

%postun libglapi0 -p /sbin/ldconfig

%post -n Mesa-libd3d -p /sbin/ldconfig

%postun -n Mesa-libd3d -p /sbin/ldconfig

%if "%{flavor}" != "drivers"
%files
%license docs/license.rst
%doc docs/README*

%files libEGL1
%{_libdir}/libEGL_mesa.so*
%dir %{_datadir}/glvnd
%dir %{_datadir}/glvnd/egl_vendor.d
%{_datadir}/glvnd/egl_vendor.d/50_mesa.json

%files libEGL-devel
%{_includedir}/EGL
%{_libdir}/pkgconfig/egl.pc

%files KHR-devel
%{_includedir}/KHR

%files libGL1
%{_libdir}/libGLX_mesa.so*
%{_libdir}/libGLX_indirect.so*

%files libGL-devel
%dir %{_includedir}/GL
%{_includedir}/GL/*.h
%exclude %{_includedir}/GL/osmesa.h
%{_libdir}/pkgconfig/gl.pc
%{_mandir}/man3/gl[A-Z]*

%files libGLESv1_CM-devel
%{_includedir}/GLES
%{_libdir}/pkgconfig/glesv1_cm.pc

%files libGLESv2-devel
%{_includedir}/GLES2
%{_libdir}/pkgconfig/glesv2.pc

%files libGLESv3-devel
%{_includedir}/GLES3

%files -n libOSMesa8
%{_libdir}/libOSMesa.so.8.0.0
%{_libdir}/libOSMesa.so.8

%files -n libOSMesa-devel
%{_includedir}/GL/osmesa.h
%{_libdir}/libOSMesa.so
%{_libdir}/pkgconfig/osmesa.pc

%files -n libgbm1
%{_libdir}/libgbm.so.1*

%files -n libgbm-devel
%{_includedir}/gbm.h
%{_libdir}/libgbm.so
%{_libdir}/pkgconfig/gbm.pc
%endif

%if "%{flavor}" == "drivers"
%ifarch aarch64 %{ix86} x86_64 %{arm} ppc64 ppc64le riscv64
%files -n libxatracker2
%{_libdir}/libxatracker.so.2*

%files -n libxatracker-devel
%{_includedir}/xa_*.h
%{_libdir}/libxatracker.so
%{_libdir}/pkgconfig/xatracker.pc
%endif

%if %{vdpau_nouveau}
%files -n libvdpau_nouveau
%{_libdir}/vdpau/libvdpau_nouveau.so
%{_libdir}/vdpau/libvdpau_nouveau.so.1
%{_libdir}/vdpau/libvdpau_nouveau.so.1.0
%{_libdir}/vdpau/libvdpau_nouveau.so.1.0.0
%endif

%if %{vdpau_radeon}
%files -n libvdpau_r600
%{_libdir}/vdpau/libvdpau_r600.so
%{_libdir}/vdpau/libvdpau_r600.so.1
%{_libdir}/vdpau/libvdpau_r600.so.1.0
%{_libdir}/vdpau/libvdpau_r600.so.1.0.0
%endif

%ifarch %{ix86} x86_64 ppc64 ppc64le %{arm} aarch64 riscv64
%files -n libvdpau_radeonsi
%{_libdir}/vdpau/libvdpau_radeonsi.so
%{_libdir}/vdpau/libvdpau_radeonsi.so.1
%{_libdir}/vdpau/libvdpau_radeonsi.so.1.0
%{_libdir}/vdpau/libvdpau_radeonsi.so.1.0.0
%endif
%endif

%if %{vdpau_virtio_gpu}
%files -n libvdpau_virtio_gpu
%{_libdir}/vdpau/libvdpau_virtio_gpu.so
%{_libdir}/vdpau/libvdpau_virtio_gpu.so.1
%{_libdir}/vdpau/libvdpau_virtio_gpu.so.1.0
%{_libdir}/vdpau/libvdpau_virtio_gpu.so.1.0.0
%endif

%if "%{flavor}" != "drivers"
%files libglapi0
%{_libdir}/libglapi.so.0*

%files libglapi-devel
%{_libdir}/libglapi.so
%endif

%if "%{flavor}" == "drivers"
%files -n Mesa-dri
%dir %{_datadir}/drirc.d
%config %{_datadir}/drirc.d/*
%dir %{_libdir}/dri
%{_libdir}/dri/*_dri.so
%ifarch %{ix86} x86_64 aarch64 %{arm} ppc64 ppc64le riscv64
%exclude %{_libdir}/dri/nouveau_dri.so
%endif
%ifarch %{arm} aarch64
%exclude %{_libdir}/dri/vc4_dri.so
%endif

%if 0%{with_opencl}
# only built with opencl
%files -n Mesa-gallium
%dir %{_libdir}/gallium-pipe/
%{_libdir}/gallium-pipe/pipe_*.so
%endif

%ifarch %{ix86} x86_64 aarch64 %{arm} ppc64 ppc64le riscv64
%files -n Mesa-dri-nouveau
%{_libdir}/dri/nouveau_dri.so
%endif

%ifarch aarch64 %{arm}
%files -n Mesa-dri-vc4
%{_libdir}/dri/vc4_dri.so
%endif

# drivers
%endif

%if "%{flavor}" != "drivers"
%files dri-devel
%{_includedir}/GL/internal
%{_libdir}/pkgconfig/dri.pc

%files devel
%doc docs/*.rst

# !drivers
%endif

%if 0%{?with_nine}
%files -n Mesa-libd3d
%dir %{_libdir}/d3d/
%{_libdir}/d3d/*.so.*

%files -n Mesa-libd3d-devel
%{_libdir}/pkgconfig/d3d.pc
%{_includedir}/d3dadapter/
%{_libdir}/d3d/*.so
%endif

%if 0%{with_opencl}
%files -n Mesa-libOpenCL
%if 0%{?suse_version} >= 1550
%dir %{_datadir}/OpenCL
%dir %{_datadir}/OpenCL/vendors
%{_datadir}/OpenCL/vendors/mesa.icd
%else
%dir %{_sysconfdir}/OpenCL
%dir %{_sysconfdir}/OpenCL/vendors
%{_sysconfdir}/OpenCL/vendors/mesa.icd
%endif
%{_libdir}/libMesaOpenCL.so*
%endif

%if 0%{with_rusticl}
%files -n Mesa-libRusticlOpenCL
%if 0%{?suse_version} >= 1550
%dir %{_datadir}/OpenCL
%dir %{_datadir}/OpenCL/vendors
%{_datadir}/OpenCL/vendors/rusticl.icd
%else
%dir %{_sysconfdir}/OpenCL
%dir %{_sysconfdir}/OpenCL/vendors
%{_sysconfdir}/OpenCL/vendors/rusticl.icd
%endif
%{_libdir}/libRusticlOpenCL.so*
%endif

%if "%{flavor}" == "drivers"
%ifarch %{ix86} x86_64 aarch64 %{arm} ppc64 ppc64le riscv64
%files -n Mesa-libva
%{_libdir}/dri/*_drv_video.so
%endif
%endif

%if 0%{with_vulkan}
%ifarch %{ix86} x86_64
%files -n libvulkan_intel
%dir %{_datadir}/vulkan
%dir %{_datadir}/vulkan/icd.d
%{_datadir}/vulkan/icd.d/intel_icd.*.json
%{_libdir}/libvulkan_intel.so
%{_datadir}/vulkan/icd.d/intel_hasvk_icd.*.json
%{_libdir}/libvulkan_intel_hasvk.so
%endif

%files -n libvulkan_radeon
%{_libdir}/libvulkan_radeon.so
%dir %{_datadir}/vulkan
%dir %{_datadir}/vulkan/icd.d
%{_datadir}/vulkan/icd.d/radeon_icd.*.json

%files -n libvulkan_lvp
%{_libdir}/libvulkan_lvp.so
%dir %{_datadir}/vulkan
%dir %{_datadir}/vulkan/icd.d
%{_datadir}/vulkan/icd.d/lvp_icd.*.json

%ifarch %{arm} aarch64
%files -n libvulkan_broadcom
%{_libdir}/libvulkan_broadcom.so
%dir %{_datadir}/vulkan
%dir %{_datadir}/vulkan/icd.d
%{_datadir}/vulkan/icd.d/broadcom_icd.*.json

%files -n libvulkan_freedreno
%{_libdir}/libvulkan_freedreno.so
%dir %{_datadir}/vulkan
%dir %{_datadir}/vulkan/icd.d
%{_datadir}/vulkan/icd.d/freedreno_icd.*.json
%endif

%files -n Mesa-vulkan-device-select
%{_libdir}/libVkLayer_MESA_device_select.so
%dir %{_datadir}/vulkan
%dir %{_datadir}/vulkan/implicit_layer.d
%{_datadir}/vulkan/implicit_layer.d/VkLayer_MESA_device_select.json

%files -n Mesa-vulkan-overlay
%{_bindir}/mesa-overlay-control.py
%{_libdir}/libVkLayer_MESA_overlay.so
%dir %{_datadir}/vulkan
%dir %{_datadir}/vulkan/explicit_layer.d
%{_datadir}/vulkan/explicit_layer.d/VkLayer_MESA_overlay.json
%endif

%changelog
* Sat Oct 14 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add U_radeonsi-prefix-function-with-si_-to-prevent-name-co.patch
  Fix https://gitlab.freedesktop.org/mesa/mesa/-/issues/9889
* Wed Oct  4 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to Mesa 23.2.1
  * Mesa 23.2.1 is a new development release. People who are
    concerned with stability and reliability should stick with a
    previous release or wait for Mesa 23.2.2.
  * Mesa 23.2.1 is an unusual first stable release due to the
    accidentl tagging of 23.2.0 durring the rc cycle.
  * Mesa 23.2.1 implements the OpenGL 4.6 API, but the version
    reported by glGetString(GL_VERSION) or
    glGetIntegerv(GL_MAJOR_VERSION) /
    glGetIntegerv(GL_MINOR_VERSION) depends on the particular
    driver being used. Some drivers don't support all the features
    required in OpenGL 4.6. OpenGL 4.6 is **only** available if
    requested at context creation. Compatibility contexts may
    report a lower version depending on each driver.
  * Mesa 23.2.1 implements the Vulkan 1.3 API, but the version
    reported by the apiVersion property of the
    VkPhysicalDeviceProperties struct depends on the particular
    driver being used.
  * More details in:
  - -> https://gitlab.freedesktop.org/mesa/mesa/-/blob/23.2/docs/relnotes/23.2.1.rst
* Mon Sep 25 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to Mesa 23.2.0-rc4
  - -> https://lists.freedesktop.org/archives/mesa-announce/2023-September/000731.html
- supersedes U_llvmpipe-only-include-old-Transform-includes-when-ne.patch
- disabled u_fix-build-on-ppc64le.patch (no longer needed?)
- adjusted n_drirc-disable-rgb10-for-chromium-on-amd.patch
* Thu Sep 21 2023 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Backport upstream patches for compatibility with LLVM 17:
  * U_llvmpipe-only-include-old-Transform-includes-when-ne.patch
    removes unneeded includes of header files that no longer exist.
  * U_clover-llvm-move-to-modern-pass-manager.patch migrates Clover
    to the new pass manager, since the old PM has been removed.
* Thu Sep 21 2023 Stefan Dirsch <sndirsch@suse.com>
- disable nine on arm/aarch64 in the hope to fix build on this
  platform; there is no need for Direct3D/Wine for arm/aarch64
  anyway ...
* Thu Sep 21 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to bugfix release 23.1.8:
  - -> https://docs.mesa3d.org/relnotes/23.1.8.html
* Thu Sep  7 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to bugfix release 23.1.7:
  - -> https://docs.mesa3d.org/relnotes/23.1.7.html
* Fri Sep  1 2023 Stefan Dirsch <sndirsch@suse.com>
- mini-cleanup for python package BuildRequires in specfile
- added python3-dataclasses package for sle15/Leap15 to finally fix
  build for these build targets; dataclasses module is in standard
  library of python >= 3.7 ...
* Thu Aug 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to bugfix release 23.1.6:
  - -> https://docs.mesa3d.org/relnotes/23.1.6.html
* Thu Aug  3 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to bugfix release 23.1.5
  - -> https://docs.mesa3d.org/relnotes/23.1.5.html
* Mon Jul 24 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to bugfix release 23.1.4
  - -> https://docs.mesa3d.org/relnotes/23.1.4.html
- supersedes u_fix-glx-context-opengl-4.5.patch
* Fri Jun 23 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to bugfix release 23.1.3
- supersedes U_glx-Remove-pointless-GLX_INTEL_swap_event-paranoia.patch
  (boo#1209005)
- -Dxmlconfig=enabled now also needs -Dexpat=enabled as dependancy
* Fri Jun 16 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Add patch u_fix-glx-context-opengl-4.5.patch: Fix a regression
  that causes Wine to crash on GPUs that don't support OpenGL 4.6
  and later:.
  Mesa 23.1 has a regression [1] that breaks Wine if the GPU does not
  support OpenGL 4.6 (reportedly), Intel HD 4000 is affected.
  The problem was narrowed down to commit e89e1f504 [2] so this patch
  removes the offending [3] part from there to fix the problem.
  It's unlikely that there will be any side effects from that,
  should be just as good as it was in Mesa 23.0.
  [1] https://gitlab.freedesktop.org/mesa/mesa/-/issues/8901
  [2] https://gitlab.freedesktop.org/mesa/mesa/-/commit/e89e1f5049d3b78542fcd69b7d6106dd4bdafc39
  [3] https://gitlab.freedesktop.org/mesa/mesa/-/issues/8901#note_1962991
- Add intel_hasvk icd to baselibs.conf.
* Fri Jun 16 2023 Stefan Dirsch <sndirsch@suse.com>
- use -Dxlib-lease=enabled also for -drivers build
* Fri Jun 16 2023 Joan Torres <joan.torres@suse.com>
- Fix of bsc#1212345
  * After update to 23.1.1 this change affected our build split:
    https://gitlab.freedesktop.org/mesa/mesa/-/commit/2630f4b310f534c830250be44d285e485da83869
* Sat Jun 10 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to bugfix release 23.1.2
* Sat Jun 10 2023 Stefan Dirsch <sndirsch@suse.com>
- needed to fix build of Mesa 23.1
  * Mesa-drivers: -Dshader-cache=enabled
  * Mesa: -Dxlib-lease=enabled
  * recommended for both Mesa and Mesa-drivers to avoid some scary messages when
    comparing fds: -Dallow-kcmp=enabled
- Credits for figuring this out go to "llyyr" <llyyr.public@gmail.com>
- gbm files are no longer needed to be removed manually for -drivers build
- VDPAU support for r300 has been dropped with Mesa 23.1
- supersedes n_no-sse2-on-ix86-except-for-intel-drivers.patch
* Fri May 26 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to bugfix release 23.1.1
- adjusted u_dep_xcb.patch
* Thu May 11 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to 23.1.0
  * new feature release
  * some highlights
    + Our OpenCL implementation Rusticl added support for AMD GPUs.
    + Both ANV (Intel) and RADV (AMD) got initial support for Vulkan Video
    decoding.
    + Vulkan Graphics Pipeline Libraries (GPL) are now supported in RADV.
- adjusted n_stop-iris-flicker.patch
- supersedes U_ReturnME.patch
- meson option "-Ddri-drivers" has been removed; wasn't used any
  longer by us --> killed it
* Sat Apr 22 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 23.0.3
  * 3rd bug fix release: changes all across the tree, with no one
    subsystem seeing too many changes
* Fri Apr  7 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 23.0.2
  * 2nd bug fix release: lots of patches for all over the tree,
    zink being the biggest singel source of changes.
* Sun Mar 26 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 23.0.1
  * bug fix release which fixes bugs found since Mesa 23.0.0
- supersedes U_glx-fix-indirect-initialization-crash.patch
* Tue Mar 14 2023 Stefan Dirsch <sndirsch@suse.com>
- U_glx-Remove-pointless-GLX_INTEL_swap_event-paranoia.patch
  * reverse apply this patch to fix a regression caused by this
    commit, which resulted in gnome-shell constantly crashing, which
    is making a GNOME/X11 session impossible (boo#1209005)
* Wed Mar  1 2023 Stefan Dirsch <sndirsch@suse.com>
- U_glx-fix-indirect-initialization-crash.patch
  * Fixes: b090246a ("glx: Only compute client GL extensions for
    indirect contexts")
  * Closes: https://gitlab.freedesktop.org/mesa/mesa/-/issues/8393
- supersedes n_Revert-glx-Only-compute-client-GL-extensions-for-ind.patch
* Tue Feb 28 2023 Fabian Vogt <fvogt@suse.com>
- Add patch to fix GLX with indirect rendering:
  * n_Revert-glx-Only-compute-client-GL-extensions-for-ind.patch
* Thu Feb 23 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 23.0.0
  * first stable release of 2023
- refreshed patches
  * n_drirc-disable-rgb10-for-chromium-on-amd.patch
  * n_stop-iris-flicker.patch
  * u_dep_xcb.patch
  * u_fix-build-on-ppc64le.patch
- adjusted n_no-sse2-on-ix86-except-for-intel-drivers.patch
- meson: added -Dxmlconfig=enabled to fix link errors
  (missing "-lexpat")
* Fri Feb 10 2023 Stefan Dirsch <sndirsch@suse.com>
- U_ReturnME.patch
  * fixes blackscreen in Return To Monkey Island on Intel graphics
    (boo#1208145)
* Thu Feb  9 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 22.3.5
  * bug fix release which fixes bugs found since Mesa 22.3.4
  * see https://docs.mesa3d.org/relnotes/22.3.5.html for more
    details
- refreshed u_dep_xcb.patch
* Mon Feb  6 2023 Andreas Schwab <schwab@suse.de>
- Don't enable rusticl without opencl
* Fri Jan 27 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 22.3.4
  * bug fix release which fixes bugs found since Mesa 22.3.3
  * see https://docs.mesa3d.org/relnotes/22.3.4.html for more
    details
* Fri Jan 27 2023 Stefan Dirsch <sndirsch@suse.com>
- removing again BuildRequires for x264 and x265 in case
  video_codecs should be built (these were never needed nor used
  for build)
* Fri Jan 27 2023 Stefan Dirsch <sndirsch@suse.com>
- using gcc 12 now also on Leap 15.4; after changing build project
  to openSUSE:Leap:15.4:Update gcc 12 packages are found now ...
* Tue Jan 24 2023 Stefan Dirsch <sndirsch@suse.com>
- force usage of gcc 12 only on Leap 15.5; there is no gcc12 on
  Leap 15.4
* Tue Jan 24 2023 Manfred Hollstein <manfred.h@gmx.net>
- Add BuildRequires for x264 and x265 in case video_codecs should
  be built.
* Mon Jan 23 2023 Stefan Dirsch <sndirsch@suse.com>
- re-enable build on Leap, but only for 15.5; there is no gcc12
  on Leap 15.4, which is now officially required by Mesa 22.3
* Mon Jan 16 2023 Martin Hauke <mardnh@gmx.de>
- Add support for Rusticl - Mesa's new OpenCL implementation.
  * See https://docs.mesa3d.org/rusticl
  You will need to set your environment to use it
  * See https://docs.mesa3d.org/envvars#rusticl-environment-variables
* Mon Jan 16 2023 Hans-Peter Jansen <hp@urpla.net>
- Compile with gcc12 on Leaps: building drivers fails with:
  /usr/include/dxguids/dxguids.h:70:1: internal compiler error:
  in cxx_eval_bit_field_ref, at cp/constexpr.c:2578
* Sun Jan 15 2023 Martin Hauke <mardnh@gmx.de>
- Fix some deprecation warnings
  * WARNING: option "false" deprecated, please use "disabled" instead.
  * WARNING: option "true" deprecated, please use "enabled" instead.
* Wed Jan 11 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 22.3.3:
  * See https://docs.mesa3d.org/relnotes/22.3.3.html
* Mon Jan  2 2023 Andreas Schwab <schwab@suse.de>
- Update list of gallium-drivers to match default list
* Sat Dec 31 2022 Stefan Dirsch <sndirsch@suse.com>
- don't try to generate libvdpau_virtio_gpu package on ppc64le; for
  some reason this driver doesn't get built on this platform
* Thu Dec 29 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 22.3.0:
  * See https://docs.mesa3d.org/relnotes/22.3.0.html
- Update to version 22.3.1:
  * See https://docs.mesa3d.org/relnotes/22.3.1.html
- Update to version 22.3.2:
  * See https://docs.mesa3d.org/relnotes/22.3.2.html
- Remove the libXvMC_nouveau and libXvMC_r600 packages as XVMC
  support was removed.
- Add libvdpau_virtio_gpu package for VirtIO GPU.
- Rebase n_drirc-disable-rgb10-for-chromium-on-amd.patch.
- Rebase u_dep_xcb.patch.
- Rebase U_fix-mpeg1_2-decode-mesa-20.2.patch.
- Drop n_buildfix-21.3.0.patch: fixed upstream.
* Sat Dec  3 2022 Stefan Dirsch <sndirsch@suse.com>
- spefile: removed Release lines from libxatracker2,
  libxatracker-devel packages in the hope to have reproducibly
  builds also on Tumbleweed (boo#1205998)
* Thu Nov 17 2022 Dirk Müller <dmueller@suse.com>
- update to 22.2.4:
  * clover: windows:  library filename has \`-1` suffix and a \`lib` prefix
    when built with mingw
  * radv, dxvk: Rendering errors in World of Tanks after "Switch to dynamic
    rendering only"
  * gen9 gt3e/gt4e skus fail dEQP-VK.pipeline.multisample.sample_locations_ext.*
  * v3d: Wrong colors (pink) in videos in Firefox (likely YUV->RGB shader issue)
  * panfrost t860 glmark-es2 regression
  * radv: Flickering in Spider-Man Remastered (Regression) (Bisected)
  * radv: Hitman 2 using Direct3D 12 has discolored squares on RDNA2 with DCC
    enabled
  * panfrost/midgard -  on Duckstation PSX emulator: segfault on GLES 3.0 and
    bad shader compilations on 3.3
* Tue Nov 15 2022 Stefan Dirsch <sndirsch@suse.com>
- try to fix build on ppc64le due to running OOM (boo#1205441)
  * let's request 20G of physical memory via _constraints file
* Tue Nov  8 2022 Stefan Dirsch <sndirsch@suse.com>
- third bugfix release
  * some regressions in CI worked out
  * a bit of everything, and nothing too crazy
- supersedes u_0001-gallivm-Fix-LLVM-optimization-with-the-new-pass-mana.patch
- supersedes u_nouveau-corrupted-colors-boo1203949.patch
- get rid of Mesa-libVulkan-devel(-32bit) package, which is no
  longer needed at all by providing/obsoleting it by
  libvulkan_intel
* Mon Nov  7 2022 Stefan Dirsch <sndirsch@suse.com>
- Release 22.2.2 covers bugfixes for bsc#1197045,bsc#1197046,bsc#1200965,bsc#1202850
* Fri Nov  4 2022 Stefan Dirsch <sndirsch@suse.com>
- build against llvm15/clang15 on sle15-sp5/Leap 15.5
* Wed Nov  2 2022 Stefan Dirsch <sndirsch@suse.com>
- u_nouveau-corrupted-colors-boo1203949.patch
  * fixes corrupted colors in videos on nouveau with Kepler in
    Firefox (boo#1203949, issue#7416)
* Wed Nov  2 2022 Stefan Dirsch <sndirsch@suse.com>
- moved drirc.d config snippets from Mesa to Mea-dri package;
  radv driver specific conf was missing completely (boo#1204866)
* Fri Oct 21 2022 Fabian Vogt <fvogt@suse.com>
- Add patch to fix LLVM optimization to avoid failure on armv7
  (https://gitlab.freedesktop.org/mesa/mesa/-/merge_requests/19217,
  boo#1204267):
  * u_0001-gallivm-Fix-LLVM-optimization-with-the-new-pass-mana.patch
* Thu Oct 20 2022 Stefan Dirsch <sndirsch@suse.com>
- update to 22.2.2
  * This is the second bug fix release, back on the regular
    schedule. There's a lot here: nir, panfrost, gallium video,
    freedreno, nouveau, turnip, r300, gallium core, r600, virgl,
    core vulkan, anv, clover, d3d12, utils, radv, and plenty of
    zink.
* Tue Oct 11 2022 Stefan Dirsch <sndirsch@suse.com>
- update to 22.2.1
  * lots of stuff here: llvmpipe, lavapipe, freedreno, aco, mesa,
    turnip, virgl, r600, zink, radv, core gallium, and nir. All in
    all, lots of good fixes all over the tree.
* Mon Oct  3 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add build_orig conditional switch for video codecs define.
* Thu Sep 29 2022 Stefan Dirsch <sndirsch@suse.com>
- re-disable video codecs
  https://gitlab.freedesktop.org/mesa/mesa/-/merge_requests/15258
* Tue Sep 27 2022 Stefan Dirsch <sndirsch@suse.com>
- Pass -Dvideo-codecs=h264dec,h264enc,h265dec,h265enc,vc1dec to
  meson, keep support for hardware codecs inside vaapi, vdpau and
  vulkan. These were previously enabled automatically.
- enabled "swrast" and "amd" Vulkan drivers on riscv64, which is
  upstream default anyway ...
* Wed Sep 21 2022 Stefan Dirsch <sndirsch@suse.com>
- update to 22.2.0
  * AMD RDNA3 Prep, Intel Arc Graphics, Many Vulkan Improvements;
    more details on Phoronix:
    https://www.phoronix.com/news/Mesa-22.2-Released
- supersedes llvm15.patch
- refreshed n_no-sse2-on-ix86-except-for-intel-drivers.patch
* Wed Sep 14 2022 Andreas Schwab <schwab@suse.de>
- llvm15.patch: backport of commits 2037c34f245, 301bcbac0e5, 6983c8580a2
  to support LLVM 15
* Mon Aug 22 2022 Stefan Dirsch <sndirsch@suse.com>
- update to 22.1.7:
  * fixes and cleanups all over the tree
  * most of the fixes are for zink
  * nice batch of fixes for the gallium dx9 frontend
  * some other fixes across the board
* Wed Aug 17 2022 Dirk Müller <dmueller@suse.com>
- update to 22.1.6:
  * llvmpipe: make last_fence a screen/rast object not a context one. llvmpipe:
    keep context list and use to track resource usage.
  * Revert "pan/bi: Require ATEST coverage mask input in R60"
  * intel/dev: drop warning for unhandled hwconfig keys
  * anv: Use sampleLocationsEnable for sample locations
* Fri Aug 12 2022 Xu Zhao <i@xuzhao.net>
- Enable zink driver build on x86_64
* Sun Aug  7 2022 Dirk Müller <dmueller@suse.com>
- update to 22.1.5:
  * radv: dynamic vertex input failure
  * anv: KHR-GL46.tessellation_shader.single.xfb_captures_data_from_correct_stage fails on TGL
  * anv: GTF-GL46.gtf32.GL3Tests.packed_pixels.packed_pixels_pbo failure
  * anv: ICL hiz issue
  * Error compiling gallium-nine on i686 using musl libc
  * dEQP-VK.memory.mapping.dedicated_alloc failing on bsw and gen9atom
* Mon Aug  1 2022 Dirk Müller <dmueller@suse.com>
- update to 22.1.4:
  * anv: disable non uniform indexing of UBOs
  * anv: use the right helper to invalidate memory
  * intel/fs: ray query fix for global address
  * isl: add new helper for format component compatibility
  * radeonsi: fix random PS wave size
  * r300: Keep rc_rename_regs() from overflowing
  * aco/ra: update register file when updating phi definition
  * radv: Fix vkCmdCopyQueryResults -> vkCmdResetPool hazard
* Fri Jul 15 2022 Stefan Dirsch <sndirsch@suse.com>
- let Mesa ignore Mesa-dri as dep to resolve a build cycle
  (related to boo#1201474
* Sun Jul  3 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to 22.1.3
  * a lot of zink fixes
  * There's a bit of everything else here, including some
    performance fixes for wsi/x11.
* Mon Jun 20 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to 22.1.2
  " There's a lot of zink here, thanks to Mike for help with manually
    backporting parts of it! We've als got a bunch of fixes for panfrost,
    and some for intel, radeon, llvmpip, dzn, broadcom, nir, core gallium,
    the va state tracker, and freedren."
* Wed Jun 15 2022 Stefan Dirsch <sndirsch@suse.com>
- let Mesa-libGL-devel require libX11-devel via pkgconfig(x11)
  (boo#1200559)
* Sun Jun  5 2022 Stefan Dirsch <sndirsch@suse.com>
- removed libkms BuildRequires, since it has been dropped from
  libdrm
* Thu Jun  2 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to 22.1.1
  * first bugfix release
- supersedes U_llvmpipe-flush-resources-for-kms-swrast-path.patch
* Wed Jun  1 2022 Fabian Vogt <fvogt@suse.com>
- Add patch to fix glitches with KMS (boo#1199885):
  * U_llvmpipe-flush-resources-for-kms-swrast-path.patch
* Wed May 25 2022 Stefan Dirsch <sndirsch@suse.com>
- buildrequire DirectX-Headers only on %%{ix86} x86_64, since it's
  only relevant on these platforms
* Tue May 24 2022 Scott Bradnick <scott.bradnick@suse.com>
- Calling patch with '-p1' (as the others are) so 'git show'
  .patch output works.
* Tue May 24 2022 Scott Bradnick <scott.bradnick@suse.com>
- Generating 'n_stop-iris-flicker.patch' from 'git format-patch' vs.
  a standard diff.
* Tue May 24 2022 Scott Bradnick <scott.bradnick@suse.com>
- Fixing up 'stop-iris-flicker.patch' patch name to follow standards.
* Thu May 19 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to 22.1.0
  * lot of great featurres, including (since rc5) additional
    kopper backports for zink, and support for Intel's Alchemist
    DG2 platform.
* Sat May 14 2022 Stefan Dirsch <sndirsch@suse.com>
- autoselect libvdpau_r300/libvdpau_r600/libvdpau_radeonsi packages
  via hardware supplements on AMD GPUs
* Thu May  5 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to 22.0.3
  * bugfix release with fixes for most of the major drivers
* Tue May  3 2022 Stefan Dirsch <sndirsch@suse.com>
- _constraints:
  * raised requirements to 9 GB disk space and added aarch64
    architecture (bsc#1199040)
* Thu Apr 28 2022 Scott Bradnick <scott.bradnick@suse.com>
- Switching out 'directx-headers' for 'DirectX-Headers'.
* Fri Apr 22 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to 22.0.2
  * bugfix release with almost all nominated patches
* Thu Apr 14 2022 Scott Bradnick <scott.bradnick@suse.com>
- Adding changes I need for iris to not flicker and have d3d12
  available for use in WSL.
* Wed Apr 13 2022 Dirk Müller <dmueller@suse.com>
- use _multibuild
* Tue Mar 29 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to 22.0.1
  * fixes in lavapipe and zink, maintainer scripts and panfrost
- supersedes U_meson-restore-private-requires-to-libdrm-in-dri.pc-f.patch
* Tue Mar 22 2022 Stefan Dirsch <sndirsch@suse.com>
- get rid of Mesa-libVulkan-devel(-32bit) package, which no longer
  makes sense since Mesa 21.1.0
  * https://gitlab.freedesktop.org/mesa/mesa/-/commit/5e6db1916860ec217eac60903e0a9d10189d1c53
* Mon Mar 14 2022 Stefan Dirsch <sndirsch@suse.com>
- U_meson-restore-private-requires-to-libdrm-in-dri.pc-f.patch
  * Due to a typo the private requires to libdrm were lost in dri.pc.
    Fixed another typo (only comment).
* Sat Mar 12 2022 Stefan Dirsch <sndirsch@suse.com>
- enabled "i915" Gallium-based Intel Gen3 driver
* Fri Mar 11 2022 Stefan Dirsch <sndirsch@suse.com>
- fixed llvm/clang buildrequires for sle15-sp4/Leap 15.4
* Fri Mar 11 2022 Stefan Dirsch <sndirsch@suse.com>
- no longer try to build classic non-Gallium OpenGL drivers
  i915, i965, nouveau, r100 and r200, which have been dropped with
  Mesa 22.0.0; see also some documentation on Phoronix
  https://www.phoronix.com/scan.php?page=news_item&px=Mesa-Classic-Retired
* Thu Mar 10 2022 Aaron Stern <ukbeast89@protonmail.com>
- update to 22.0.0
  * lavapipe,radv,anv KHR_dynamic_rendering
  * radv EXT_image_view_min_lod
  * VK_KHR_synchronization2 on RADV.
  * OpenSWR has been moved to the Amber branch
  * radeonsi, zink ARB_sparse_texture
  * d3d12 GLES3.1 (shader storage buffers, images, compute, indirect draw, draw params,
    ARB_framebuffer_no_attachments, ARB_sample_shading, and GLSL400)
  * radeonsi, zink ARB_sparse_texture2
  * zink EXT_memory_object, EXT_memory_object_fd, EXT_semaphore, EXT_semaphore_fd
  * anv VK_VALVE_mutable_descriptor_type
  * Vulkan 1.3 on RADV,Anv.
  * radeonsi, zink ARB_sparse_texture_clamp
* Thu Mar  3 2022 Stefan Dirsch <sndirsch@suse.com>
- baselibs.conf: readded mistakenly removed packages
  * Mesa-libVulkan-devel
  * Mesa-vulkan-device-select
  * Mesa-vulkan-overlay
* Wed Mar  2 2022 Stefan Dirsch <sndirsch@suse.com>
- raise memory limit to 1024 in the hope of avoiding OOM on ppc64
  (boo#1196640)
* Tue Mar  1 2022 Stefan Dirsch <sndirsch@suse.com>
- autoselect libvulkan_intel package via hardware supplements on
  Intel GPUs
- autoselect libvulkan_radeon package via hardware supplements on
  AMD GPUs
- no longer install libvulkan_lvp package (lavapipe=Software
  Vulkan driver), libvulkan_broadcom and libvulkan_freedreno packages
  by default, i.e. no longer have libvulkan_intel/libvulkan_radeon
  and libvulkan_lvp packages installed at the same time (boo#1180522)
- libvulkan_intel/libvulkan_radeon/libvulkan_lvp now require
  Mesa-vulkan-device-select package, not the other way round!
  (baselibs.conf also adjusted)
* Thu Feb 24 2022 Stefan Dirsch <sndirsch@suse.com>
- update to 21.3.7
  * sixth bugfix release
* Thu Feb 10 2022 Stefan Dirsch <sndirsch@suse.com>
- update to 21.3.6
  * sixth bugfix release
* Thu Jan 27 2022 Stefan Dirsch <sndirsch@suse.com>
- update to 21.3.5
  * bugfix release: mostly Zink fixes
* Mon Jan 17 2022 Stefan Dirsch <sndirsch@suse.com>
- using memory-constraints on ppc64 for trying to avoid OOM during
  build (boo#1194739)
* Fri Jan 14 2022 Stefan Dirsch <sndirsch@suse.com>
- update to 21.3.4
  * bugfix release
* Sat Jan  8 2022 Stefan Dirsch <sndirsch@suse.com>
- rename n_no-sse2-on-ix86.patch to
  n_no-sse2-on-ix86-except-for-intel-drivers.patch
  * no longer disable sse2 support for intel drivers, since this
    breaks build, which is probably unresolvable (boo1190409)
* Fri Jan  7 2022 Scott Bradnick <scott.bradnick@suse.com>
- Adding 'stop-iris-flicker.patch'.
* Thu Jan  6 2022 Stefan Dirsch <sndirsch@suse.com>
- n_no-sse2-on-ix86.patch
  * disabled sse2 support on %%ix86 (boo#1190409)
* Fri Dec 31 2021 Aaron Stern <ukbeast89@protonmail.com>
- update to 21.3.3
  * Bug fixes
  * Assassin’s Creed Syndicate crashes with Mesa 21.3.0+ ACO
  * [21.3 regression] swr: Build failure with MSVC
  * anv: dEQP-VK.graphicsfuzz.spv-stable-pillars-volatile-nontemporal-store fails
* Wed Dec  1 2021 Stefan Dirsch <sndirsch@suse.com>
- update to 21.3.1
  * mostly AMD, Intel & Zink fixes.
* Thu Nov 18 2021 Stefan Dirsch <sndirsch@suse.com>
- n_buildfix-21.3.0.patch
  * fixes Mesa-drivers build
* Wed Nov 17 2021 Stefan Dirsch <sndirsch@suse.com>
- update to 21.3.0
  * Panfrost is now officially GLES 3.1 conformant
  * RADV has (experimental) ray tracing support
  * Iris gained threaded shader compilation
  * Zink has seen an enormous amount of work, and now supports GLES 3.2
  * Lavapipe has a bunch of new extensions, and now supports Vulkan 1.2
  * LLVMpipe got 2-3 times faster for 2D workloads, and gained support for
    the compatibility profile on GL 4.5
  * VA-API gained support for AV1 videos
  * EGL now works on Windows
  * Wayland got a workaround for games making bad assumption (alpha means
    transparency? who could have known)
  * VK_EXT_color_write_enable on lavapipe
  * GL_ARB_texture_filter_anisotropic in llvmpipe
  * Anisotropic texture filtering in lavapipe
  * VK_EXT_shader_atomic_float2 on Intel and RADV.
  * VK_EXT_vertex_input_dynamic_state on RADV.
  * VK_KHR_timeline_semaphore on lavapipe
  * VK_EXT_external_memory_host on lavapipe
  * GL_AMD_pinned_memory on llvmpipe
  * GL 4.5 compatibility on llvmpipe
  * VK_EXT_primitive_topology_list_restart on RADV and lavapipe.
  * ES 3.2 on zink
  * VK_KHR_depth_stencil_resolve on lavapipe
  * VK_KHR_shader_integer_dot_product on RADV.
  * OpenGL FP16 support on llvmpipe
  * VK_KHR_shader_float16_int8 on lavapipe
  * VK_KHR_shader_subgroup_extended_types on lavapipe
  * VK_KHR_spirv_1_4 on lavapipe
  * Experimental raytracing support on RADV
  * VK_KHR_synchronization2 on Intel
  * NGG shader based culling is now enabled by default on GFX10.3 on RADV.
  * VK_KHR_maintenance4 on RADV
  * VK_KHR_format_feature_flags2 on RADV.
  * EGL_EXT_present_opaque on wayland
* Thu Oct 28 2021 Stefan Dirsch <sndirsch@suse.com>
- update to 21.2.5
  * bit of everything: general vulkan, panfrost, and zink are the
    biggest changes.
* Fri Oct 15 2021 Stefan Dirsch <sndirsch@suse.com>
- update to 21.2.4
  * fourth bugfix release
  * 300 fixes from the new r300 maintainer! Additionally, panfrost,
    lots of crocus, some freedreno, intel, radv, core meas, gallivum,
    anv, spirv, gallim, aco, i915g, lima, and llvmpipe fixes.
- supersedes U_gallivm-add-new-wrapper-around-Module.patch,
  U_gallivm-fix-FTBFS-on-i386-with-LLVM-13.patch
* Thu Oct 14 2021 Stefan Dirsch <sndirsch@suse.com>
- u_fix-build-on-ppc64le.patch
  * fixes build on ppc64le (boo#1191569)
* Mon Oct  4 2021 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Fix build with LLVM 13:
  * U_gallivm-add-new-wrapper-around-Module.patch
  * U_gallivm-fix-FTBFS-on-i386-with-LLVM-13.patch
* Thu Sep 30 2021 Stefan Dirsch <sndirsch@suse.com>
- update to 21.2.3
  * third bugfix release
* Mon Sep 27 2021 Stefan Dirsch <sndirsch@suse.com>
- covers jira#SLE/SLE-18743
* Tue Sep 21 2021 Stefan Dirsch <sndirsch@suse.com>
- update to 21.2.2
  * second bugfix release: a ton of work went into panfrost,
    getting it closer to being conformant (it is conformant on
    21.3!); fixes for ir3, croccus, nir, utils, llvmpipe, gallivm,
    zink, glsl, v3d, vc4, intel, mesa, aco, iris, radv, and even
    osmesa.
* Sat Aug 28 2021 Stefan Dirsch <sndirsch@suse.com>
- update to 21.2.1
  * first bugfix release
* Sun Aug  8 2021 Stefan Dirsch <sndirsch@suse.com>
- fixed build on %%ix86 by removing "-flto=auto" from optflags for
  cpp
* Thu Aug  5 2021 Stefan Dirsch <sndirsch@suse.com>
- enabled build of 'crocus' Gallium3D OpenGL driver for i965 "Gen4"
  through Haswell "Gen7" graphics (alternative to classic "i965"
  OpenGL driver); use MESA_LOADER_DRIVER_OVERRIDE=crocus to use it;
  in case of issues with video hardware acceleration(vaapi driver),
  set LIBVA_DRIVER_NAME=i965
* Thu Aug  5 2021 Stefan Dirsch <sndirsch@suse.com>
- update to 21.2.0
  * new release
* Thu Jul 29 2021 Stefan Dirsch <sndirsch@suse.com>
- update to 21.1.6
  * sixth bugfix release
* Thu Jul 15 2021 Stefan Dirsch <sndirsch@suse.com>
- update to 21.1.5
  * fith bugfix release
* Thu Jul  1 2021 Stefan Dirsch <sndirsch@suse.com>
- update to 21.1.4
  * fourth bugfix release
* Tue Jun 22 2021 Stefan Dirsch <sndirsch@suse.com>
- no longer apply n_drirc-disable-rgb10-for-chromium-on-amd.patch
  on TW; no longer needed with gstreamer-plugins-vaapi 1.18.4; more
  details on
  https://gitlab.freedesktop.org/gstreamer/gstreamer-vaapi/-/merge_requests/410
* Sat Jun 19 2021 Stefan Dirsch <sndirsch@suse.com>
- update to 21.1.3
  * third bugfix
  * mostly AMD fixes
* Thu Jun  3 2021 Stefan Dirsch <sndirsch@suse.com>
- update to 21.1.2
  * second bugfix
  * mostly AMD and Intel changes as usual, but also a decent amount
    of ARM fixes and more.
* Wed Jun  2 2021 Stefan Dirsch <sndirsch@suse.com>
- no longer autoselect Mesa-dri-nouveau at all; autoselect
  libvdpau_nouveau depending on PCI ID (boo#1186721)
* Thu May 20 2021 Stefan Dirsch <sndirsch@suse.com>
- update to 21.1.1
  * bugfix release
  * mostly AMD and Intel changes as usual, but also a decent amount
    of ARM fixes and more
* Wed May 19 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add swrast to vulkan
- Enable vulkan on %%{arm} and aarch64 with: swrast, amd,
  broadcom and freedreno
* Fri May 14 2021 Stefan Dirsch <sndirsch@suse.com>
- reenabled build of device-select and overlay vulkan layers
* Thu May  6 2021 Stefan Dirsch <sndirsch@suse.com>
- adjusted filelist to removed vulkan files in Mesa 21.1.0
  (packages Mesa-libVulkan-devel, Mesa-vulkan-device-select,
  Mesa-vulkan-overlay)
* Thu May  6 2021 Stefan Dirsch <sndirsch@suse.com>
- /usr/include/vulkan/vulkan_intel.h dropped with Mesa 21.1.0, but
  let's keep the package containing an empty directory
* Thu May  6 2021 Stefan Dirsch <sndirsch@suse.com>
- update to 21.1.0
  * bunch of work here, lots of zink and softpipe, but bits and
    pieces of other things: tgsi, freddreno, nir, panfrost, intel,
    spirv, core gallium, radv, aco, r600, and core mesa.
- supersedes patches U_clover-Fix-build-with-llvm-12.patch,
  U_clover-Add-missing-include-for-llvm-12-build-fix.patch
* Wed Apr 21 2021 Stefan Dirsch <sndirsch@suse.com>
- update to 21.0.3
  * fixes in haiku, core mesa, radeonsi, lavapipe, nir, radv, anv,
    freedreno and turnip, etniviv, iris, egl, lima, core gallium,
    spriv, v3d, meson
* Sat Apr 17 2021 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Move osmesa build back to Mesa, which we can now do after
  choosing another dummy driver there.
- Use LLVM-versioned libclc runtime dependency to ensure
  bitcode compatibility. We have that in Tumbleweed and soon Leap.
- U_clover-Fix-build-with-llvm-12.patch
  * Fixes build with LLVM 12.
- U_clover-Add-missing-include-for-llvm-12-build-fix.patch
  * Fixes a missing header in the previous patch.
* Sat Apr 17 2021 Stefan Dirsch <sndirsch@suse.com>
- Mesa-devel: no longer require libOSMesa-devel, since it's now
  built in Mesa-drivers; packages should require it directly now,
  preferrably via pkconfig(osmesa) ...
* Sat Apr 17 2021 Tobias Klausmann <tobias.klausmann@freenet.de>
- Switch dummy driver for mesa package from "auto" xorg driver (i965) to
  gallium swrast driver
* Sat Apr 17 2021 Stefan Dirsch <sndirsch@suse.com>
- update to 21.0.2
  * many additions especially on the Radeon Vulkan (RADV) driver
    front where sparse memory support is in place, AMD Smart Access
    Memory / Resizable BAR optimizations, various RDNA 2
    improvements, rapid packed math for ACO, and more.
    Elsewhere in Mesa 21.0 there are continued RadeonSI
    optimizations, many Intel ANV and Iris improvements, OpenGL 3.3
    for Freedreno, DXGI Winsys was added and initial Direct3D 12
    code for WSL, OpenGL 4.1 for Zink, and more.
- moved osmesa build to Mesa-drivers since swrast driver has been
  removed from Mesa
* Tue Apr  6 2021 Andreas Schwab <schwab@suse.de>
- Enable radeon and nouveau drivers on riscv64
* Tue Mar 30 2021 Stefan Dirsch <sndirsch@suse.com>
- update to 20.3.5
  * fith bugfix release for the 20.3 branch
  * This is a quite large release with a huge number of fixes in it,
    and is the last planned release for the 20.3.x series. Radv and
    ACO dominate the changes for this release, but there are some
    other things mixed in there.
* Mon Feb  1 2021 Stefan Dirsch <sndirsch@suse.com>
- update to 20.3.4
  * fourth bugfix release for the 20.3 branch
* Wed Jan 27 2021 Stefan Dirsch <sndirsch@suse.com>
- removed no longer needed buildfix-ppc64le.patch; build failed on
  ppc64 due to this patch (bsc#1181439)
* Thu Jan 14 2021 Stefan Dirsch <sndirsch@suse.com>
- update to 20.3.3
  * third bugfix release for the 20.3 branch
* Thu Dec 31 2020 Michał Rostecki <mrostecki@suse.com>
- update to 20.3.2
  * second bugfix release for the 20.3 branch
- drm and surfaceless are not specified as platforms anymore,
  remove them from egl_platforms
* Mon Dec  7 2020 Stefan Dirsch <sndirsch@suse.com>
- update to 20.2.4
  * fourth (second to last) bugfix release for the 20.2 branch
* Tue Dec  1 2020 Stefan Dirsch <sndirsch@suse.com>
- require llvm-devel *without* any explicit version number for
  factory/TW to imply 'distro default llvm version', which we
  usually bump up when a new stable llvm comes out
* Mon Nov 30 2020 Stefan Dirsch <sndirsch@suse.com>
- use llvm11 on factory/TW and sle15-sp3/Leap 15.3
* Sun Nov 29 2020 Stefan Dirsch <sndirsch@suse.com>
- enabled build of radeonsi DRI and VDPAU driver on aarch64
  (boo#1179376)
* Mon Nov 23 2020 Stefan Dirsch <sndirsch@suse.com>
- update to 20.2.3
  * third bugfix release for the 20.2 branch
* Sat Nov  7 2020 Stefan Dirsch <sndirsch@suse.com>
- update to 20.2.2
  * second bugfix release for the 20.2 branch
* Thu Oct 15 2020 Stefan Dirsch <sndirsch@suse.com>
- reenabled U_fix-mpeg1_2-decode-mesa-20.2.patch due to regression
  reported in boo#1173185
* Wed Oct 14 2020 Stefan Dirsch <sndirsch@suse.com>
- update to 20.2.1
  * first bugfix release for the 20.2 branch
- supersedes U_fix-mpeg1_2-decode.patch
- disabled U_fix-mpeg1_2-decode-mesa-20.2.patch; likely no longer
  needed (boo#1173185)
* Wed Sep 30 2020 Stefan Dirsch <sndirsch@suse.com>
- U_fix-mpeg1_2-decode-mesa-20.2.patch
  * additional patch currently needed for Mesa 20.2 (boo#1173185)
* Tue Sep 29 2020 Stefan Dirsch <sndirsch@suse.com>
- update to 20.2.0
  * includes Intel Rocket Lake Platform Support
    (jsc#SLE/SLE-12880, jsc#SLE/SLE-12882)
- adjusted/refreshed patches:
  * n_add-Mesa-headers-again.patch
  * n_drirc-disable-rgb10-for-chromium-on-amd.patch
  * u_dep_xcb.patch
- docs now available in .rst format (html before)
* Thu Sep 24 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add U_fix-mpeg1_2-decode.patch (boo#1173185)
  * fixes colors in kaffeine on Radeon (r600 VAAPI driver)
* Fri Sep 18 2020 Stefan Dirsch <sndirsch@suse.com>
- buildfix-ppc64le.patch
  * buildfix for ppc64le (boo#1176562)
* Thu Sep 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 20.1.8:
  * mainly bugfixes, highlights:
  - Crash in ruvd_end_frame when calling vaBeginPicture/vaEndPicture without rendering anything
  - khr_debug-push-pop-group_gl: ../src/util/simple_mtx.h:86: simple_mtx_lock: Assertion `c != _SIMPLE_MTX_INVALID_VALUE&#x27; failed.
  - Amber test opt_peel_loop_initial_if: Assertion failed
  - Dirt Rally: Flickering glitches on certain foliage since Mesa 20.1.0 caused by MSAA
  - [BRW] WRC 5 asserts with gallium nine and iris.
* Thu Sep  3 2020 Stefan Dirsch <sndirsch@suse.com>
- update to 20.1.7
  * seventh bugfix release for the 20.1 branch
* Wed Sep  2 2020 Stefan Dirsch <sndirsch@suse.com>
- switched to llvm9 usage for Leap/SLE15 since llvm10 is not (yet)
  in Leap/SLE15
* Mon Aug 31 2020 Stefan Dirsch <sndirsch@suse.com>
- version 20.1.6 needed for jira#SLE/SLE-12880, jira#SLE/SLE-12882
* Mon Aug 31 2020 Stefan Dirsch <sndirsch@suse.com>
- use again /etc/OpenCL/vendors for openSUSE Leap, i.e. use
  /usr/etc/OpenCL/vendors only for Tumbleweed
* Wed Aug 26 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add vulkan device selection layer and vulkan overlay layer to
  baselibs for 32bit versions on 64bit architectures.
* Tue Aug 25 2020 Aaron Dominick <aaron.zakhrov@gmail.com>
- Add vulkan device selection layer and vulkan overlay layer
* Tue Aug 25 2020 Stefan Dirsch <sndirsch@suse.com>
- specfile/baselibs.conf cleanup
  * no longer support Mesa build without libglvnd
  * removed empty packages Mesa-libGLESv1_CM1 and Mesa-libGLESv2-2
* Sun Aug 23 2020 Stefan Dirsch <sndirsch@suse.com>
- update to 20.1.6
  * sixth bugfix release for the 20.1 branch
* Thu Aug  6 2020 Dominique Leuenberger <dimstar@opensuse.org>
- baselibs.conf:
  + Require Mesa-KHR-devel instead of Mesa-KHR-devel-<targettype>:
    KHR-devel consists only of header files there is thus no
  - <targettype> flavor being generated.
  + Do not require Mesa-libGLESv1_CM1 and Mesa-libGLESv2-2 from
    their respective -32bit devel packages: with libglvnd defined
    to 0, the native packages are being generated, but are empty.
    For baselibs, this trick does not work and empty packages are
    being skipped. So we drop the dependency (with a note in the
    .spec to enable the deps when changing the defines).
* Thu Jul 23 2020 Stefan Dirsch <sndirsch@suse.com>
- update to 20.1.4
  * fourth bugfix release for the 20.1 branch
  * just a few fixes here and there, nothing major
* Fri Jul 10 2020 Stefan Dirsch <sndirsch@suse.com>
- update to 20.1.3
  * third bugfix release for the 20.1 branch
  * lots of updates to our testing infrastructure
* Wed Jul  1 2020 Stefan Dirsch <sndirsch@suse.com>
- force valgrind support only on officially supported platforms
  (boo#1173355)
* Fri Jun 26 2020 Stefan Dirsch <sndirsch@suse.com>
- update to 20.1.2
  * second bugfix release for the 20.1 branch
  * most of the fixes here are to the AMD drivers, and the rest
    is scattered over the tree.
* Fri Jun 26 2020 Stefan Dirsch <sndirsch@suse.com>
- enable valgrind support (boo#1173355)
* Tue Jun 23 2020 Stefan Dirsch <sndirsch@suse.com>
- move mesa.icd from /usr/etc/OpenCL/vendors to
  /usr/share/OpenCL/vendors (boo#1173005)
* Thu Jun 18 2020 Stefan Dirsch <sndirsch@suse.com>
- switch to /usr/etc/OpenCL/vendors for mesa.icd OpenCL file
  location (boo#1173005)
* Mon Jun 15 2020 Stefan Dirsch <sndirsch@suse.com>
- update to 20.1.1
  * first bugfix release for the 20.1 branch
  * fixes issue affecting Unreal Engine 4 games on i965
* Wed Jun  3 2020 Stefan Dirsch <sndirsch@suse.com>
- update to 20.1.0
  * first release for the 20.1 branch
  * One already known issue is that Unreal Engine 4 has a bug in
    its usage of glDrawRangeElements() causing it to be called
    with a number of vertices in place of the `end` parameter,
    that was recently revealed. This is an annoying bug that we
    haven't worked around yet. For more details:
    https://gitlab.freedesktop.org/mesa/mesa/-/issues/2917
- supersedes U_add-lifetime-dse-fix.patch
* Tue May 19 2020 Martin Liška <mliska@suse.cz>
- Add U_add-lifetime-dse-fix.patch as a proper fix for boo#1171855.
* Tue May 19 2020 Martin Liška <mliska@suse.cz>
- Disable LTO for now as there's a known upstream bug
  that hasn't been resolved with GCC 10:
  boo#1171855.
* Fri May 15 2020 Stefan Dirsch <sndirsch@suse.com>
- update to Mesa 20.0.7
  * most fixes in Radv, but there are fixes all over the tree
* Mon May  4 2020 Michel Normand <normand@linux.vnet.ibm.com>
- avoid build error PowerPC, using gnu++14 (not gnu++11)
  https://bugzilla.opensuse.org/show_bug.cgi?id=1171045
* Thu Apr 30 2020 Stefan Dirsch <sndirsch@suse.com>
- update to Mesa 20.0.6
  * fairly small release (a little bit of everything in here)
* Sat Apr 25 2020 Stefan Dirsch <sndirsch@suse.com>
- require llvm/clang 10
* Fri Apr 24 2020 Stefan Dirsch <sndirsch@suse.com>
- update to Mesa 20.0.5
  * pretty big release with AMD and Intel drivers receiving the
    majority of the work.
- supersedes U_EGL-Add-eglSetDamageRegionKHR-to-GLVND-dispatch-list.patch
- supersedes n_opencl_dep_libclang.patch
* Thu Apr 23 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable LTO on armv6 to fix build
* Sun Apr  5 2020 Torsten Duwe <duwe@suse.com>
- U_EGL-Add-eglSetDamageRegionKHR-to-GLVND-dispatch-list.patch
  * Fix Weston launch on tumbleweed by backporting commit bfb9c08e
* Fri Apr  3 2020 Stefan Dirsch <sndirsch@suse.com>
- update to Mesa 20.0.4
  * emergency release, which reverts a serious SPIR-V regression
    in the 20.0.3 release.
- supersedes U_Revert-spirv-Implement-OpCopyObject-and-OpCopyLogica.patch
* Fri Apr  3 2020 Stefan Dirsch <sndirsch@suse.com>
- U_Revert-spirv-Implement-OpCopyObject-and-OpCopyLogica.patch
  * revert severe spirv regression; emergency release will be
    available soon ...
* Thu Apr  2 2020 Stefan Dirsch <sndirsch@suse.com>
- update to Mesa 20.0.3
  * bugfix release:  fixes all over the tree; mostly AMD (radv,
    aco), NIR and Intel (isl, anv)
* Thu Mar 19 2020 Stefan Dirsch <sndirsch@suse.com>
- update to Mesa 20.0.2
  * bugfix release: fixes all over the code base
* Mon Mar  9 2020 Stefan Dirsch <sndirsch@suse.com>
- update to Mesa 20.0.1
  * bugfix release
* Fri Mar  6 2020 Stefan Dirsch <sndirsch@suse.com>
- cleanup in specfile: get rid of is_opensuse macro, which is no
  longer needed at all (jira#PM-1623)
* Fri Feb 28 2020 Stefan Dirsch <sndirsch@suse.com>
- Loosen dependencies to allow building with newer versions of
  clang-devel, similar to llvm-devel.
* Fri Feb 21 2020 Philipp Seiler <p.seiler@linuxmail.org>
- update to mesa 20.0.0
  * changelog https://mesa3d.org/relnotes/20.0.0.html
- supersedes U_0001-gallium-Fix-a-couple-of-multiple-definition-warnings.patch
- supersedes U_0002-r600-Move-get_pic_param-to-radeon_vce.c.patch
- supersedes U_0003-radeon-Move-si_get_pic_param-to-radeon_vce.c.patch
- supersedes U_0004-radeon-Fix-multiple-definition-error-with-radeon_deb.patch
- supersedes U_0006-nouveau-nvc0-add-extern-keyword-to-nvc0_miptree_vtbl.patch
- update to patch n_add-Mesa-headers-again.patch to fit v20.0.0 sources
- update to patch n_drirc-disable-rgb10-for-chromium-on-amd.patch to fit v20.0.0 sources
* Fri Feb 21 2020 Stefan Dirsch <sndirsch@suse.com>
- use 7G disk constraints also for x86_64 and i586 (bsc#1164488)
* Tue Feb 18 2020 Stefan Dirsch <sndirsch@suse.com>
- only use 'BuildRequires:llvm-devel >= 9.0.0' for TW/factory; for
  older products still use 'BuildRequires: llvm9-devel'; fixed
  build on openSUSE Leap 15.2
* Sun Feb 16 2020 Stefan Dirsch <sndirsch@suse.com>
- Update to version 19.3.4
  * changes all over the tree, but aco and anv are leading the
    way in changes
- supersedes u_Revert_gallium_Fix_big-endian_addressing_of_non-bitmask_array_formats.patch
* Thu Feb  6 2020 Stefan Dirsch <sndirsch@suse.com>
- u_Revert_gallium_Fix_big-endian_addressing_of_non-bitmask_array_formats.patch
  * replaces U_gallium-Fix-big-endian-addressing-of-non-bitmask-arr.patch
    by an official merge request (bsc#1162252, gitlab issue#2472)
* Mon Feb  3 2020 Stefan Dirsch <sndirsch@suse.com>
- U_gallium-Fix-big-endian-addressing-of-non-bitmask-arr.patch
  * reverse apply since it caused a regression in rendering on
    s390x (bsc#1162252)
* Wed Jan 29 2020 Stefan Dirsch <sndirsch@suse.com>
- require and check for llvm-devel >= 9 instead of llvm9-devel on
  openSUSE
* Wed Jan 29 2020 Stefan Dirsch <sndirsch@suse.com>
- enabled build of gallium based llvmpipe driver for s390x
  (related to jsc#IBM-369, jsc#SLE-7452)
* Wed Jan 29 2020 Stefan Dirsch <sndirsch@suse.com>
- Update to version 19.3.3
  * There's plenty of changes here, but intel, docs, radeonsi,
    and aco are the biggest sets of changes.
- supersedes U_0005-radv-Remove-syncobj_handle-variable-in-header.patch
* Wed Jan 29 2020 Stefan Dirsch <sndirsch@suse.com>
- set optflags also for g++ compiler
* Mon Jan 27 2020 Stefan Dirsch <sndirsch@suse.com>
- require llvm9 (jsc#IBM-369, jsc#SLE-7452)
* Wed Jan 22 2020 Stefan Dirsch <sndirsch@suse.com>
- U_0001-gallium-Fix-a-couple-of-multiple-definition-warnings.patch
  U_0002-r600-Move-get_pic_param-to-radeon_vce.c.patch
  U_0003-radeon-Move-si_get_pic_param-to-radeon_vce.c.patch
  U_0004-radeon-Fix-multiple-definition-error-with-radeon_deb.patch
  U_0005-radv-Remove-syncobj_handle-variable-in-header.patch
  U_0006-nouveau-nvc0-add-extern-keyword-to-nvc0_miptree_vtbl.patch
  * fixes build with gcc10 using -fno-common as default now (boo#1160578)
* Mon Jan 13 2020 Andreas Schwab <schwab@suse.de>
- Enable LLVM support on riscv64
* Sun Jan 12 2020 Stefan Dirsch <sndirsch@suse.com>
- Update to version 19.3.2
  * Intel and AMD drivers make up the bulk of the changes, with
    a bit of nir and glsl, plus a sprinkling of other stuff in
    there.
* Sun Jan  5 2020 Stefan Dirsch <sndirsch@suse.com>
- n_drirc-disable-rgb10-for-chromium-on-amd.patch
  * fixes patch (boo#1145188)
* Sun Dec 29 2019 Stasiek Michalski <hellcp@mailbox.org>
- Update to version 19.3.1
  * Bugfixes for i965/iris, anv and radv
* Mon Dec 16 2019 Stasiek Michalski <hellcp@mailbox.org>
- Update to version 19.3.0
  * Mainly changes to the build system, i965, aco, radv and anv
  * New features, check Phoronix:
    https://www.phoronix.com/scan.php?page=article&item=mesa-193-features
* Fri Nov 22 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 19.2.6
  * fixes build on PPC
  * couple of additional stable patches
* Thu Nov 21 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 19.2.5
  * There's a little bit over everything in here, with anv and
    radeonsi standing out as the two biggest components getting
    changes, but core mesa, core gallium, llvmpipe, nir, egl,
    i965, tgsi, st/mesa, spirv, and the Intel compiler also
    fixes in this release.
- supersedes u_call-shmget-with-permission-0600-instead-of-0777.patch
* Thu Nov 14 2019 Stefan Dirsch <sndirsch@suse.com>
- u_call-shmget-with-permission-0600-instead-of-0777.patch
  * CVE-2019-5068 (bsc#1156015)
* Thu Nov 14 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 19.2.4
  * This is an emergency release, to fix a critical bug found in
    the 19.2.3 release which causes incomplete rendering on all
    mesa drivers. This release contains a single patch to fix
    that bug.
* Wed Nov 13 2019 Frederic Crozat <fcrozat@suse.com>
- Update _contraints, Mesa-drivers needs 7GB of disk to build
  safely.
* Thu Nov  7 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 19.2.3
  In this release: iris, meson, radv, anv, turnip, 965, svga,
  utils, core mesa, glsl, etanviv, and gallium/rbug
- This Mesa release includes support for latest GPUs including Intel
  (jsc#SLE-7962, jsc#SLE-8024, jsc#SLE-8022, jsc#SLE-10182, jsc#SLE-4983,
  bsc#1137515) and fixes for boo#1127672, bsc#1117365
* Tue Nov  5 2019 Martin Pluskal <mpluskal@suse.com>
- Dont conflict with vulkan-devel anymore as there is no file
  conflict
* Fri Nov  1 2019 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Use %%pkg_vcmp macro instead of llvm-config to detect LLVM 9.
* Fri Oct 25 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 19.2.2
  * assortment of fixes in this release, notably a bunch of work
    to get Solaris and illumos working with mesa, as well as more
    work fixing issues in the migration of package-config and
    headers being handled by libglvnd instead of mesa when mesa
    is built with support for glvnd.
    There's  bunch of other changes here, with radv and intel
    leading the pack, otherwise just a few things here and there.
- n_add-Mesa-headers-again.patch
  * add Mesa headers again despite of building it against libglvnd;
    those headers turned out not to be usable; in addition packaging
    headers with libglvnd make dependancies problematic ...
* Mon Oct 14 2019 Stefan Dirsch <sndirsch@suse.com>
- let Mesa-libEGL-devel require libX11 devel via "pkgconfig(x11)"
  since EGL/eglplatform.h includes X11/Xlib.h
* Wed Oct  9 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 19.2.1
  * fixes all over the tree: intel, amd, nine, nir, egl, gallium,
    scons, meson, glsl, haiku, android, and nouveau all got fixes.
* Mon Oct  7 2019 Stefan Dirsch <sndirsch@suse.com>
- pickup gl, egl, glesv1_cm and glesv2 pkgconfig files from
  libglvnd build and add them to the appropriate devel subpackages
* Mon Oct  7 2019 Stefan Dirsch <sndirsch@suse.com>
- reintroduce GL, EGL, GLES* devel subpackages since corresponding
  header and pkgconfig files from libglvnd didn't work out ...
* Mon Sep 30 2019 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Rebase n_opencl_dep_libclang.patch after update.
* Mon Sep 30 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 19.2.0 including changes to
  * release-infastructure
  * the build
  * drivers: turnip, radv, android, intel and amd common code
  * new features: check Phoronix
    https://www.phoronix.com/scan.php?page=news_item&px=Mesa-19.2-Released
- supersedes U_llvmpipe-Don-t-use-u_ringbuffer-for-lp_scene_queue.patch
- adjusted n_drirc-disable-rgb10-for-chromium-on-amd.patch
- supersedes n_glesv1_cm-glesv2.patch
* Sat Sep 28 2019 Stefan Dirsch <sndirsch@suse.com>
- no longer build
  * Mesa-libGL-devel
  * Mesa-libEGL-devel
  * Mesa-libGLESv1_CM-devel
  * Mesa-libGLESv2-devel
  * Mesa-libGLESv3-devel
  Instead of requiring these let Mesa-devel package require
  libglvnd-devel >= 1.2.0, which provides the contents of these
  packages now (header files for OpenGL, GLES, EGL, and GLX).
  Adjusted baselibs.conf accordingly.
- modified check for llvm version in a way so it works also with
  older llvm packages (by making use of "llvm-config -version"),
  where there is %%{_llvm_sonum} macro defined yet
- moved manual pages to Mesa-devel package
* Wed Sep 25 2019 Aaron Puchert <aaronpuchert@alice-dsl.net>
- n_opencl_dep_libclang.patch
  * Link OpenCL library with libclang-cpp.so instead of the
    component libraries for LLVM >= 9.
* Wed Sep 18 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 19.1.7
  * another bugfix release ....
* Mon Sep  9 2019 Michel Normand <normand@linux.vnet.ibm.com>
- Add ppc64 for radeonsi to avoid build error
* Wed Sep  4 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 19.1.6
  * bugfix release
* Mon Aug 26 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 19.1.5
  * bugfix release
* Wed Aug 14 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Build radeonsi and libvdpau_radeonsi on ppc64le
* Mon Aug 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 19.1.4:
  * Mostly, as usual, in fixes for different drivers (anv, radv,
    radeon, nv50, nvc0) as well as in backend parts (egl, spirv,
    nir, ...).
  * Of those fixes, we could highlight several ones:
  - Vulkan 24/48 bit formats are now not supported on Ivybridge.
  - R8G8B8_UNORM_SRGB is not supported on Haswell.
  - A fix for hair artifacts in Max Payne 3 on AMD/RADV.
  - Vulkan transform feedback extension is disabled on Intel
    gen7.
* Tue Jul 23 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 19.1.3:
  * Mostly fixes for ANV and RADV drivers, as well as NIR backend
    fixes.
  * Several of those patches fix crashes with the drivers, and a
    couple of them fix memory leaks.
* Mon Jul 22 2019 Stefan Dirsch <sndirsch@suse.com>
- n_drirc-disable-rgb10-for-chromium-on-amd.patch
  * added totem as another affected application (boo#1142270)
* Fri Jul 12 2019 Stefan Dirsch <sndirsch@suse.com>
- Add v3d support (VC5/V6 driver) for %%arm and aarch64
* Fri Jul 12 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add kmsro for %%arm and aarch64
* Thu Jul 11 2019 Stefan Dirsch <sndirsch@suse.com>
- U_llvmpipe-Don-t-use-u_ringbuffer-for-lp_scene_queue.patch
  * may fix crashes in llvmpipe on SMP systems with LTO enabled
    builds (boo#1133265)
* Tue Jul  9 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 19.1.2:
  * Different fixes for the Intel and AMD Vulkan drivers,
    Freedreno, the Meson build system, and some other fixes for
    other parts and/or drivers.
  * Worth to mention a fix for a crash in Wolfenstein II with the
    RADV driver, and another fix relevant for DXVK on Intel gen7
    drivers.
- Update Source urls from ftp to https.
* Thu Jun 27 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 19.1.1:
  * Mostly in fixes for different drivers (RADV, ANV, Nouveau,
    Virgl, V3D, R300g, ...).
  * Also different fixes for different parts (Meson build, GLX,
    etc).
* Wed Jun 19 2019 Stefan Dirsch <sndirsch@suse.com>
- reverted latest change in specfile; it's not needed; llvm8 is
  already been chosen on factory/TW by default ...
* Tue Jun 18 2019 Stefan Dirsch <sndirsch@suse.com>
- use llvm8 on factory/TW
* Thu Jun 13 2019 Stefan Dirsch <sndirsch@suse.com>
- n_glesv1_cm-glesv2.patch
  * reenables build of GLESv1_CM and GLESv2 ...
- readded pkgconfig files for GLESv1_CM and GLESv2 to filelists
- removed again virtual provides for
  * pkgconfig(glesv1_cm)
  * pkgconfig(glesv2)
* Wed Jun 12 2019 Stefan Dirsch <sndirsch@suse.com>
- reenable LTO with Mesa 19.1 (boo#1133265, comment#5)
- enabled new gallium drivers
  * iris (newer Intel GPUs)
  * lima, panfrost on ARM64
- virtually provide
  * pkgconfig(glesv1_cm)
  * pkgconfig(glesv2)
  in libGLESv1_CM-devel/libGLESv2-devel packages, since these files
  have been removed from Mesa via git commit #1587586
* Tue Jun 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to 19.1.0:
  * Mesa 19.1.0 implements the OpenGL 4.5 API, but the version
    reported by glGetString(GL_VERSION) or
    glGetIntegerv(GL_MAJOR_VERSION) /
    glGetIntegerv(GL_MINOR_VERSION) depends on the particular
    driver being used. Some drivers don't support all the features
    required in OpenGL 4.5. OpenGL 4.5 is only available if
    requested at context creation. Compatibility contexts may
    report a lower version depending on each driver.
  * The top highlights include:
  - GL_ARB_parallel_shader_compile for all drivers.
  - GL_EXT_gpu_shader4 on all GL 3.1 drivers.
  - GL_EXT_shader_image_load_formatted on radeonsi.
  - GL_EXT_texture_buffer_object on all GL 3.1 drivers.
  - GL_EXT_texture_compression_s3tc_srgb on Gallium and i965
    drivers (ES extension).
  - GL_NV_compute_shader_derivatives on Iris and i965 drivers.
  - GL_KHR_parallel_shader_compile on all drivers.
  - GL_INTEL_conservative_rasterization on Iris.
- Refresh patches with quilt.
- Clean-up spec files for .pc and other files no longer built.
* Wed May 22 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to 19.0.5
  * Things have slowed back down from the last release, which is
    good for this late in the series. No one area has received too
    much work, with a little bit sprinkled in here and there in
    both core code and drivers.
* Fri May 10 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to 19.0.4
  * It's been a pretty active release, especially for how late in
    the cyle we are. Radv was the busiest component, but there
    were also a few changes for intel, radeonsi, some core vulkan
    work, and a little bit of other stuff here and there.
* Fri Apr 26 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to 19.0.3
  * quiet release with just 19 patches (excluding release churn)
    since 19.0.2
  * no sub component was touched too much
  * virgl, glsl, nir, intel, radeonsi, radv, ac, and gallivm
    received a few patches
* Wed Apr 24 2019 Martin Liška <mliska@suse.cz>
- Disable LTO (boo#1133265).
* Wed Apr 17 2019 Tobias Klausmann <tobias.johannes.klausmann@mni.thm.de>
- Drop patches n_VDPAU-XVMC-libs-Replace-hardlinks-with-copies.patch
  and archlinux_0001-Fix-linkage-against-shared-glapi.patch:
  These patches only work when building mesa with autotools. As we use meson
  instead now, these patches do nothing.
* Wed Apr 17 2019 Tobias Klausmann <tobias.johannes.klausmann@mni.thm.de>
- Drop version 19.0.1 tarballs
* Thu Apr 11 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to 19.0.2
  * Just a few fixes for radeon, a few for nir, a couple for radv,
    a couple for v3d, and a few other patches here and there.
* Thu Mar 28 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to 19.0.1
  * "This is the first bug fix release of the 19.0 branch. It's
    been a pretty calm cycle, and there's not too much here. I
    think things are looking pretty good overall."
* Fri Mar 22 2019 Stefan Dirsch <sndirsch@suse.com>
- baselibs.conf: Mesa-libEGL-devel needs Mesa-KHR-devel (bsc#1117365)
* Fri Mar 22 2019 olaf@aepfle.de
- Mesa-libEGL-devel needs Mesa-KHR-devel (bsc#1117365)
* Wed Mar 20 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Remove imx from ARM drivers (dropped upstream)
* Thu Mar 14 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to 19.0.0
  * bug fixes and performance improvements
- adjusted n_drirc-disable-rgb10-for-chromium-on-amd.patch
- supersedes u_wayland_egl-Ensure-EGL-surface.patch
* Mon Mar  4 2019 Andreas Schwab <schwab@suse.de>
- Don't enable gallium_loader on ppc and s390x
- Fix configuration on non-gallium archs
- u_dep_xcb.patch: fix missing xcb dependencies
* Mon Mar  4 2019 normand@linux.vnet.ibm.com
- avoid Mesa-drivers build failure for ppc64le reported by
  (boo#1127672)
* Wed Feb 20 2019 sndirsch@suse.com
- remove n_Disable-Xshm-for-now-since-it-results-in-render-erro.patch;
  keeping that one reintroduced render errors and missing screen
  refreshes on GNOME3 in a qemu VM (cirrus emulation); the issue has
  been fixed in a different and better way since 18.3.3; this is
  related to bsc#1118149
* Tue Feb 19 2019 sndirsch@suse.com
- Update to 18.3.4
  * A fix in the XvMC state-tracker, which was causing some video attributes to
    not take affect. On the video front the VAAPI state tracker has seen
    improvements with VP9 streams while the amdgpu driver advertises all available
    profiles.
  * On Intel side we have compiler fixes and extra PCI IDs for Coffee Lake and
    Ice Lake parts. In the Broadcom drivers a couple of memory leaks were
    addressed and the NEON assembly should compile properly on armhf.
  * Other drivers such as radeonsi, nouveau and freedreno have also seen some
    love. The RADV driver has seen addressed to compile correctly with GCC9
    amongst other changes.
  * The Xlib based libGL have been addressed to work with X servers, which lacks
    the MIT-SHM extension such as XMing.
  * To top it up we have a few fixes to the meson build system.
* Mon Feb  4 2019 sndirsch@suse.com
- Update to 18.3.3
  * In this release we have:
    A memory leak fix in the etnaviv driver, better NEON assembly code in vc4 and
    couple of stability improvements to the radeonsi driver. Another memory leak
    affecting all gallium drivers have also been addressed.
  * The time required to compile GLSL shaders with large amount of uniforms, such
    as Godot, has been improved.
  * GLX and swrast have also seen some improvements.
  * On the Vulkan side, the ANV driver adjusted the number of images supported
    for gen8 and earlier to 8, while for newer hardware it remains the same 64.
    The RADV driver has seens a collection of stability improvements and fix for
    the Vulkan version advertised in some corner cases.
  * To top it all up, the meson build system has seen a steady amount of fixes:
    the DSO version for the VDPAU drivers is now included, ICC compatibility
    patches, opencl handling and relaxed handling when building osmesa.
- adjusted n_Disable-Xshm-for-now-since-it-results-in-render-erro.patch
* Mon Jan 21 2019 Tobias Klausmann <tobias.johannes.klausmann@mni.thm.de>
- Build Mesa with meson instead of automake
  + Build classic swrast with Mesa, as its a dependency for osmesa - delete it
    while installing
  + Build egl with Mesa-drivers as it demands one windowing-system -
    delete it while installing
* Fri Jan 18 2019 sndirsch@suse.com
- Update to 18.3.2
  * In this release candidate we have added more PCI IDs for AMD
    Vega devices and a number of fixes for the RADV Vulkan drivers.
  * On the Intel side we have a selection ranging from quad swizzles
    support for ICL to compiler fixes.
  * The nine state tracker has also seen some love as do the
    Broadcom drivers.
  * To top it all up, we have a healthy mount of build system fixes.
* Wed Jan  9 2019 sndirsch@suse.com
- redisabled support for tegra, since it just got disabled upstream
  in git master ...
* Sat Jan  5 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Enable the surfaceless platform, which is needed by KDE CI
  environment for testing (https://phabricator.kde.org/T10245)
* Wed Dec 19 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add etnaviv, imx and tegra supports for %%arm and arch64
* Wed Dec 12 2018 Dominique Leuenberger <dimstar@opensuse.org>
- Only BuildRequire pkgconfig(vdpau) and pass --enable-vdpau to
  configure when building the drivers. Helps us break a build
  cycle.
* Wed Dec 12 2018 sndirsch@suse.com
- Update to 18.3.1
  * This version disables the VK_EXT_pci_bus_info extension due to
    last minute issues spotted in the specification.
* Tue Dec 11 2018 sndirsch@suse.com
- n_Disable-Xshm-for-now-since-it-results-in-render-erro.patch
  * Xshm results in render errors and missing screen refreshes on GNOME3
    in a qemu VM (cirrus emulation) [bsc#1118149]
* Mon Dec 10 2018 Ismail Dönmez <idonmez@suse.com>
- Fix baselibs.conf entry for Mesa-KHR-devel (missing "-")
* Fri Dec  7 2018 sndirsch@suse.com
- Update to 18.3.0 final release
  * The top highlights include:
    + GL_AMD_depth_clamp_separate on r600, radeonsi.
    + GL_AMD_framebuffer_multisample_advanced on radeonsi.
    + GL_AMD_gpu_shader_int64 on i965, nvc0, radeonsi.
    + GL_AMD_multi_draw_indirect on all GL 4.x drivers.
    + GL_AMD_query_buffer_object on i965, nvc0, r600, radeonsi.
    + GL_EXT_disjoint_timer_query on radeonsi and most other Gallium drivers
    (ES extension)
    + GL_EXT_texture_compression_s3tc on all drivers (ES extension)
    + GL_EXT_vertex_attrib_64bit on i965, nvc0, radeonsi.
    + GL_EXT_window_rectangles on radeonsi.
    + GL_KHR_texture_compression_astc_sliced_3d on radeonsi.
    + GL_NV_fragment_shader_interlock on i965.
    + EGL_EXT_device_base for all drivers.
    + EGL_EXT_device_drm for all drivers.
    + EGL_MESA_device_software for all drivers.
  * Additional features:
    ANV
    + VK_EXT_calibrated_timestamps
    + VK_EXT_pci_bus_info
    + VK_EXT_sampler_filter_minmax
    + VK_EXT_vertex_attribute_divisor v3
    + VK_GOOGLE_decorate_string
    + VK_GOOGLE_hlsl_functionality1
    + VK_KHR_driver_properties
    RADV
    + VK_EXT_calibrated_timestamps
    + VK_EXT_conservative_rasterization
    + VK_EXT_pci_bus_info
    + VK_EXT_transform_feedback
    + VK_EXT_vertex_attribute_divisor v3
    + VK_GOOGLE_decorate_string
    + VK_GOOGLE_hlsl_functionality1
    + VK_KHR_driver_properties
- supersedes u_constify-struct-drisw_loader_funcs.patch,
  u_drisw-use-separate-drisw_loader_funcs-for-shm.patch
* Tue Dec  4 2018 bjorn.lie@gmail.com
- Add u_wayland_egl-Ensure-EGL-surface.patch: wayland/egl: Ensure
  EGL surface is resized on DRI update_buffers(). Patch is sent
  upstream already.
* Thu Nov 29 2018 sndirsch@suse.com
- Update to 18.3.0-rc5
  * fifth release candidate for Mesa 18.3.0
* Tue Nov 27 2018 sndirsch@suse.com
- added libGL-Mesa-devel split-off provides to Mesa-KHR-devel
  package, since /usr/include/KHR/khrplatform.h moved between
  these two packages (related to bsc#1117365)
* Tue Nov 27 2018 msrb@suse.com
- Place khrplatform.h into new package Mesa-KHR-devel. It is now
  required by all devel packages that need it. (bsc#1117365)
* Mon Nov 26 2018 msrb@suse.com
- Remove n_drisw-Do-not-use-drisw_put_image_shm.patch,
  add u_constify-struct-drisw_loader_funcs.patch
  and u_drisw-use-separate-drisw_loader_funcs-for-shm.patch.
  * Replace workaround with proper fix for crash in VLC and
    possibly other applications. (boo#1113533)
* Fri Nov 23 2018 Tobias Klausmann <tobias.johannes.klausmann@mni.thm.de>
- Use rpm variables for the drirc.d path
* Thu Nov 22 2018 sndirsch@suse.com
- Update to 18.3.0-rc4
  * fourth release candidate for Mesa 18.3.0
* Sat Nov 17 2018 sndirsch@suse.com
- Update to 18.3.0-rc3
  * third release candidate for Mesa 18.3.0
* Thu Nov 15 2018 sndirsch@suse.com
- moved /usr/include/KHR from libEGL-devel to libGL-devel since it's
  now being referenced by glext.h
* Thu Nov 15 2018 sndirsch@suse.com
- Update to 18.3.0-rc2
  * second release candidate for Mesa 18.3.0
- supersedes the following patches:
  * U_intel-aubinator-mark-ftruncate_res-as-MAYBE_UNUSED-i.patch
  * U_intel-decoder-mark-total_length-as-MAYBE_UNUSED-in-g.patch
  * U_python-Fix-rich-comparisons.patch
  * U_python-Use-key-functions-when-sorting-containers.patch
  * mako_4_radv.patch
- adjusted n_drirc-disable-rgb10-for-chromium-on-amd.patch
- /etc/drirc moved to /usr/share/drirc.d/00-mesa-defaults.conf
* Tue Nov 13 2018 msrb@suse.com
- n_drisw-Do-not-use-drisw_put_image_shm.patch
  * Workaround for applications that create GL context twice with
    different loaders. (boo#1113533)
* Thu Nov  1 2018 sndirsch@suse.com
- Update to 18.2.4
  * Different fixes for different drivers: freedreno, radeonsi,
    swr, anv and radv. Also there are fixes for ac, gallium,
    spirv and blorp.
* Thu Oct 25 2018 msrb@suse.com
- n_drirc-disable-rgb10-for-chromium-on-amd.patch
  * Disallow rgb10 configs for chromium with radeonsi to prevent
    broken colors in video. (boo#1113211)
* Mon Oct 22 2018 sndirsch@suse.com
- Update to 18.2.3
  * Different patches for the DirectX9 and DRI state trackers.
  * Several fixes and workarounds for different games, inlcuding
    RAGE, Yakuza and The Evil Within, Wolfenstein The Old Blood
    ARMA 3, or No Mans Sky.
  * A bunch of fixes for different drivers, including r600,
    nouveau, radeonsi, anv, radv, virgl, i965, nvc0 or nv50.
    Worth to mention a fix for GPU hangs in Radeonsi.
  * State Trackers also get different fixes and corrections.
  * Finally, fixes for GLSL and NIR are also in this queue.
* Fri Oct  5 2018 bjorn.lie@gmail.com
- Update to 18.2.2
  * Different patches for the DirectX9 and DRI state trackers.
  * A patch to implement vkAcquireNextImage2 in the Intel and AMD
    vulkan drivers, as well as a patch for adding support for
    protected memory properties in GetPhysicalDeviceProperties2()
    for the former driver.
  * RADV also gets a patch to fix some issues with reflections in
    GTA V, and a patch to fix a GPU hang in SteamVR with Vega.
  * Finally, there are more fixes for Radeonsi, nvc0, vc4, and
    vulkan code.
- Drop usage of sha1sum, use sig and keyring verification instead.
  Following this, add key from Juan A. Suarez to keyring.
- Drop u_st-dri-don-t-set-queryDmaBufFormats-queryDmaBufModif.patch
  Fixed upstream.
* Fri Sep 21 2018 Ondřej Súkup <mimi.vx@gmail.com>
- update to 18.2.1
  * Lot of fixes for Vulkan drivers.
* Tue Sep 11 2018 sndirsch@suse.com
- get rid of libwayland-egl1/libwayland-egl-devel completely; also
  for older Leap versions
* Mon Sep 10 2018 sndirsch@suse.com
- update to 18.2.0
  * This release consists of nearly 2200 commits from approximately
    130 developers.
  * The top highlights include:
  - OpenGL 4.3 on virgl.
  - OpenGL 4.4 Compatibility profile on radeonsi.
  - OpenGL ES 3.2 on radeonsi and virgl.
  - GL_ARB_ES3_2_compatibility on radeonsi.
  - GL_ARB_fragment_shader_interlock on i965.
  - GL_ARB_sample_locations and GL_NV_sample_locations on nvc0 (GM200+).
  - GL_ANDROID_extension_pack_es31a on radeonsi.
  - GL_KHR_texture_compression_astc_ldr on radeonsi.
  - GL_NV_conservative_raster and GL_NV_conservative_raster_dilate on
    nvc0 (GM200+).
  - GL_NV_conservative_raster_pre_snap_triangles on nvc0 (GP102+).
  - multisampled images on nvc0 (GM107+) (now supported on GF100+).
  * Additional features:
  - ANV Extensions:
  - VK_KHR_bind_memory2.
  - VK_KHR_external_fence.
  - VK_KHR_external_fence_capabilities.
  - VK_KHR_external_semaphore.
  - VK_KHR_external_semaphore_capabilities.
  - VK_KHR_maintenance2.
  - VK_KHR_maintenance3.
  - VK_KHR_multiview.
  - VK_KHR_relaxed_block_layout.
  - VK_KHR_sampler_ycbcr_conversion.
  - VK_KHR_8bit_storage.
  - VK_KHR_create_renderpass2.
  - VK_KHR_display.
  - VK_KHR_display_swapchain.
  - VK_KHR_external_fence_fd.
  - VK_KHR_external_semaphore_fd.
  - VK_KHR_get_display_properties2.
  - VK_KHR_image_format_list.
  - RADV Extensions:
  - VK_KHR_bind_memory2.
  - VK_KHR_external_fence.
  - VK_KHR_external_fence_capabilities.
  - VK_KHR_maintenance2.
  - VK_KHR_maintenance3.
  - VK_KHR_multiview.
  - VK_KHR_relaxed_block_layout.
  - VK_KHR_create_renderpass2.
  - VK_KHR_display.
  - VK_KHR_display_swapchain.
  - VK_KHR_draw_indirect_count.
  - VK_KHR_external_fence_fd.
  - VK_KHR_get_display_properties2.
  - VK_KHR_get_surface_capabilities2.
  - VK_KHR_image_format_list.
  - New GL extensions supported by all drivers:
  - GL_OES_EGL_image_external.
  - GL_OES_EGL_image_external_essl3.
  - freedreno:
  - GL 3.0's multisample anti-aliasing support on a5xx.
  - GL_ARB_texture_multisample support on a5xx.
  - GLES3.1's GS5 Packing/bitfield/conversion functions support on a5xx.
  - Dynamically uniform UBO array indices.
  - Packing/bitfield/conversion functions.
  - Enhanced textureGather.
  - GL_OES_texture_buffer.
  - GL_ARB_seamless_cubemap_per_texture.
  - i965:
  - GL_OES_texture_view on gen8+.
  - GL_EXT_texture_norm16.
  - nouveau:
  - GL_ARB_post_depth_coverage.
  - GL_ARB_sample_locations.
  - GL_EXT_texture_norm16.
  - r600:
  - GL_EXT_texture_norm16.
  - radeonsi:
  - GL_EXT_texture_norm16.
  - virgl:
  - GL_ARB_seamless_cubemap_per_texture.
  - GL_ARB_shader_stencil_export.
- supersedes u_r600-egd_tables.py-make-the-script-python-2-3-compat.patch,
  u_intel_anv-make-scripts-python-2-3-compat.patch
- U_intel-decoder-mark-total_length-as-MAYBE_UNUSED-in-g.patch,
  U_intel-aubinator-mark-ftruncate_res-as-MAYBE_UNUSED-i.patch,
  U_python-Fix-rich-comparisons.patch,
  U_python-Use-key-functions-when-sorting-containers.patch
  * buildfixes ...
* Mon Aug 27 2018 sndirsch@suse.com
- update to 18.1.7
  * Mesa 18.1.7 is now available for general consumption. This
    release has been rather small compared to the last few
    release, There's just a handful of fixes in total. Meson,
    radv, anv, gallium winsys, intel, i965, and r600 were the
    only recipients of fixs this go around.
* Sun Aug 26 2018 fabian@ritter-vogt.de
- Add wayland to egl_platforms for Leap 15.0+ and TW again (boo#1105798)
* Fri Aug 17 2018 sndirsch@suse.com
- update to 18.1.6
  * autotools fixes for libglvnd, libgl naming, and pkgconfig
  * meson fixed its handling of stale symlinks wrt megadrivers
  * windows relaged fixes
  * some bug fixes for clover
  * plenty of egl, wayland, glx, and dri3 fixes
  * a couple of nir fixes
  * and on the driver side, radv, intel, vc4, etnaviv, swr, r600, amd, and
    nouveau all had a few fixes
- supersedes archlinux_glvnd-fix-gl-dot-pc.patch
* Mon Aug 13 2018 sndirsch@suse.com
- disabled build of libwayland-egl for factory/sle16/Leap 16 now
  being provided by Wayland itself and probably be removed from
  Mesa soon; see also https://build.opensuse.org/request/show/613048
* Thu Aug  2 2018 mimi.vx@gmail.com
- update to 18.1.5
  * several fixes for radv
  * A few fixes for virgil, spirv, radeonsi, nir, disk cache and build
    systems
* Thu Jul 26 2018 guillaume.gardet@opensuse.org
- Enable virgl on ARM
* Mon Jul 16 2018 sndirsch@suse.com
- update to 18.1.4
  * Several fixes for i965
  * Several fixes for anv
  * A few fixes each for radeonsi, glx, the glsl compiler, the
    autotools build, nir, st/dri, and r600
* Wed Jul 11 2018 mliska@suse.cz
- Make build verbose as outlined in openSUSE:Specfile guidelines
  https://en.opensuse.org/openSUSE:Specfile_guidelines#Verbose_mode
* Sat Jun 30 2018 mimi.vx@gmail.com
- update to 18.1.3
  * numerous fixes for radv
  * some fixes for common radeon code
  * fixes for both the nir and glsl compilers
  * An i965 fix for some gpu hangs on SNB
* Sun Jun 17 2018 mimi.vx@gmail.com
- add mako_4_radv.patch - fixes Mako detection for RADV/intel
* Sun Jun 17 2018 mimi.vx@gmail.com
- update to 18.1.2
  * Fixes for libatomic checks on non-arm and non-x86 platforms
  * porting of additional libatomic checks to meson from autotools
  * numerous radv fixes
  * numerous intel fixes
  * A few fixes each for radeonsi, r300, ac, glx, and vulkan
* Sat Jun  2 2018 mimi.vx@gmail.com
- Update to 18.1.1
- drop U_dri3-Stricter-SBC-wraparound-handling.patch
  * Radv fixed one extension and several features on a per-generation basis.
  * Vulkan got fixes for a potential free of uninitialized memory
  * Tegra got modifier fixes.
  * nv30 fixed displayable formats.
  * i965 now works correctly for GLK 2x6 systems.
* Tue May 22 2018 tobias.johannes.klausmann@mni.thm.de
- Add patch U_dri3-Stricter-SBC-wraparound-handling.patch
  This fixes an error with timestamps, avoiding near infinite client
  hangs with the new X server 1.20 release and some clients, the most
  prominent being plasmashell & steam
  Bugentry: FDO#106351
* Tue May 22 2018 msrb@suse.com
- Fix python3-Mako dependency on <= Leap 42.3.
- Temporarily replace mesa-18.1.0.tar.xz.sig with
  mesa-18.1.0.tar.xz.sha1sum. The sig file uses EDDSA which is not
  supported by gpg in OBS at the moment.
* Sat May 19 2018 mimi.vx@gmail.com
- Update to 18.1.0
- refreshed archlinux_0001-Fix-linkage-against-shared-glapi.patch
- add u_intel_anv-make-scripts-python-2-3-compat.patch for build ANV
    with python
  * Vulkan 1.1 support for the ANV and RADV drivers.
  * RadeonSI and RADV have "Vega M" GPU support for Kabylake G processors
  * A simple Gallium3D HUD option as an alternative to the advanced
    heads-up display
  * There is also now Vega 12 support too.
  * For new hardware support on the Intel side are the initial
    bits for Intel Icelake.
  * The Intel driver stack has meanwhile landed more SPIR-V
    bits towards OpenGL 4.6.
  * The Intel ANV driver has received new extensions too as well as
    enabling features like MSAA fast clears.
  * VP9 VA-API support for VCN and HEVC Main for VCN - Raven Ridge CPUs.
  * DRI3 1.1/1.2 support for going with the soon-to-be-out X.Org Server 1.20.
  * Etnaviv performance counter support when paired with the latest Etnaviv
    DRM in the mainline kernel.
  * The last-year-GSoC'ed OpenMAX Tizonia H.264 encoder/decoder.
  * UVD-based HEVC video encoding.
  * OpenGL 3.1 ARB_compatibility support for the major Gallium3D drivers.
  * RadeonSI 32-bit pointers support.
  * The Intel GLSL shader cache is enabled by default.
  * Nouveau NVC0 meanwhile finally has ARB_bindless_texture support.
  * On the old hardware front, R600g is now effectively at OpenGL 4.4
    for the Radeon HD 5800/6900 series.
* Sat May 19 2018 sndirsch@suse.com
- Update to 18.0.4
  * r600 driver gets a fix for constant buffer boounds, which
    fixes rendering bugs in Trine and Witcher 1.
  * Several fixes for RADV driver: fixes around alpha channel
    in Pre-Vega, fix in multisample image copies, and fixes
    around multilayer images in compute path.
  * For the case of ANV/i965 drivers, also a couple of fixes,
    all of them around ISP. On top, there are a couple of fixes
    relative to code emission around 16-bit integers, and a a
    fix for a leak in blorp for Gen4 and Gen5.
  * Speaking of leaks, there are also fixes for
    winsys/radeon/amdgpu and pipe-loader.gets a couple of patches
    to fix a couple of leaks.
  * SPIR-V part gets a patch to apply OriginUpperLeft to FragCoord.
  * Mesa core gets a couple of patches to fix error handling in
    get_framebuffer_parameteriv, and to add missing support for
    glFogiv(GL_FOG_DISTANCE_MODE_NV).
* Tue May  8 2018 sndirsch@suse.com
- Update to 18.0.3
  * The is a fairly small release consisting of patches to fix leaks
    in RADV and Winsys, fix deadlock in internal queue, fix issues
    with ANV allocator, fix blit setup for YUV LoadImage, and some
    other patches.
* Mon Apr 30 2018 sndirsch@suse.com
- Update to 18.0.2
  * A couple of fixes for Meson that solves some problems regarding
    building tests and installation.
  * A couple of fixes in state tracker / DRI that was causing crashes
    in QtCreator and Firefox, among other problems.
  * A couple of fixes for GFX9, that solves a hang in the driver, and
    a problem with buffer views.
  * SVGA gets also a patch to fix incorrect advertizing of
    EGL_KHR_gl_colorspace extension.
  * Etnaviv gets a fix for swizzled texture formats.
  * Intel drivers get also several patches.
  * RADV gets a patch to solve a problem of lot of games complaining
    about not having enough memory.
* Thu Apr 19 2018 sndirsch@suse.com
- Update to 18.0.1
  * In this release we have:
  * On the build system to highlight Meson is get improved thorugh several patches
    that fix issues around it.
  * On the drivers part, RADV get several fixes: one for multisample regressions on
  Vega, another around GFX9 buffer views, and a couple of them more to related
  with avoiding emitting unneeded vertex state.
  * St/Nine get fixes around face register, lighting constants, math check for
    inversible matrix, implicit conversions and bad tracking of vertex textures.
  * Freedreno/a5xx get fixes around missaligned heigh for PIPE_BUFFER, and around
    page faults.
  * Several fixes are also enqueued for Intel driver: set right channel_sizes for
  MOV_INDIRECT sources, set right config registration for uploading to kernel,
  return the fourcc stored in __DRIimage when possible, fix negative sign in
  64-bit return values, fix null destination register in assembly instructions
  with 3 source operands, a fix for failed TCS/TES shader compilation
  * Queue also contains a couple of fixes around Gallium drivers, one to fix a typo
    in code that was causing wrong return value, and another one to fix an
    unitialized modifier for DRI2.
  * Mesa core gets a couple of patches to fix issues around overriding OpenGL/ES
    supported version through environment variables, and a patch to fix an issue
    with texture samples found in "The Witness" through Wine.
  * A couple of bugs around unrolling loops have also been fixed, these patches were
    applied for NIR and GLSL.
  * On top of above, NIR gets more fixes in a couple of lowering functions used:
    coalesce in lower_vec_to_movs if vec had a SSA destination, and interp_var_at
    intrinsic support in lower_indirect_derefs. It also gets a fix around
    vars_to_ssa function.
  * Finally, there are other fixes affecting Radeonsi, AC, EGL/Wayland and SPIR-V
    compiler.
* Wed Apr 18 2018 sndirsch@suse.com
- enabled opencl and that way also Mesa-gallium on 42.3 since we
  now build against llvm 6; this also fixes the requirements from
  Mesa-32bit to Mesa-gallium-32bit in baselibs.conf (reported by
  community)
* Thu Apr  5 2018 msrb@suse.com
- Remove n_Disable-AMDGPU-GFX9-Vega-on-LLVM-lessthan-6.0.0.patch.
  * Not needed since we build Mesa against LLVM 6. (bnc#1082298)
- Remove u_Fix-crash-in-swrast-when-setting-a-texture-for-a-pix.patch.
  * It was disabled for long time and does not seem to be needed.
    (bnc#1082306)
* Tue Apr  3 2018 schwab@suse.de
- Enable nine on arm/aarch64
* Wed Mar 28 2018 sndirsch@suse.com
- Update to 18.0.0 final
  * one-and-only change since 18.0.0-rc5: updated release notes
- Changes since 17.3
  * The top highlights include:
    + Cannonlake support on i965 and anv
    + GL 4.3/GLES 3.1 support  on r600/evergreen with hw fp64 support
    + Meson build system
  * ANV Extensions:
    + VK_EXT_external_memory_dma_buf
  * RADV Extensions:
    + VK_ANDROID_native_buffer
    + VK_KHR_external_fence
    + VK_KHR_external_fence_capabilities
    + VK_KHR_external_fence_fd
    + VK_KHR_get_surface_capabilities2
    + VK_EXT_discard_rectangles
    + VK_EXT_external_memory_dma_buf
    + VK_AMD_shader_info
  * EGL:
    + Support for RGBA/RGBX 1010102 formats
    + EGL_EXT_pixel_format_float
    + Final planned release to ship wayland-egl. Now provided by wayland.
  * GLX:
    + Darwin/Apple fixes
  * Mesa core
    + Support 1 binary format for GL_ARB_get_program_binary on i965
    + drirc workarounds:
    (*) Unreal 4 Editor
    (*) Observer
    (*) Steamroll
    (*) Refunct
  * drirc mesa_glthread whitelists:
    + Mount and Blade Warband
- i965:
  * Disk shader cache when MESA_GLSL_CACHE_DISABLE is set to "false"
  * GL_EXT_disjoint_timer_query on gen6+
* Wed Mar 21 2018 sndirsch@suse.com
- Update to 18.0.0-rc5
  * The fifth and final release candidate for Mesa 18.0.0. Modulo
    serious regressions, it is anticipated that it will become
    Mesa 18.0.0 this Friday (2018-03-23) around 16:00 GMT
- supersedes u_glsl-linker-error.patch
* Mon Mar 19 2018 sndirsch@suse.com
- no longer try to use non-existing python3-mako as BuildRequires
  on Leap 42.3
* Thu Mar 15 2018 msrb@suse.com
- u_st-dri-don-t-set-queryDmaBufFormats-queryDmaBufModif.patch
  * Fixes laggy mouse in Wayland. (fdo#104926)
* Thu Mar  1 2018 sndirsch@suse.com
- replaced u_r600-egd_tables.py-added-support-for-python-3.patch
  with fixed u_r600-egd_tables.py-make-the-script-python-2-3-compat.patch
  and enabled it again; removed again n_egd_tables_h.patch (boo#1082303)
* Thu Mar  1 2018 sndirsch@suse.com
- added n_egd_tables_h.patch and disabled u_mesa-python3-only.patch
  * use pregenerated egd_tables.h (via python2) instead of trying
    to generate it during buildtime with python3 using an apparently
    broken patch (boo#1082303)
* Wed Feb 28 2018 sndirsch@suse.com
- removed more unneeded buildrequires: libudev, openssl, bison,
  flex (boo#1082312)
* Tue Feb 27 2018 sndirsch@suse.com
- removed u_configure.ac-Link-to-libLLVMCodegen-to-fix-cyclic-li.patch
  which is no longer needed due to changed LLVM build (boo#1082307)
* Tue Feb 27 2018 sndirsch@suse.com
- merge content of new rpmlintrc into existing Mesa-rpmlintrc file
* Fri Feb 23 2018 sndirsch@suse.com
- no longer run ldconfig for the follwing backend (ICD) drivers,
  since it's considered wrong: xvmc, vdpau, va, opencl, and vulkan;
  required adding a rpmlintrc file with appropriate rules
  (boo#1082316)
* Fri Feb 23 2018 sndirsch@suse.com
- removed no longer needed ncurses-devel BuildRequires (boo#1082315)
* Fri Feb 23 2018 sndirsch@suse.com
- redone u_add_llvm_codegen_dependencies.patch and renamed to
  u_configure.ac-Link-to-libLLVMCodegen-to-fix-cyclic-li.patch
  (boo#1082307)
* Fri Feb 23 2018 sndirsch@suse.com
- removed u_mesa-8.0.1-fix-16bpp.patch and
  u_mesa-8.0-llvmpipe-shmget.patch, which we no longer apply since
  about 5 years (boo#1082305)
* Fri Feb 23 2018 sndirsch@suse.com
- recreated u_mesa-python3-only.patch and renamed to
  u_r600-egd_tables.py-added-support-for-python-3.patch; also
  removed first hunk (boo#1082303)
* Fri Feb 23 2018 sndirsch@suse.com
- removed n_Define-GLAPIVAR-separate-from-GLAPI.patch
  * bits moved to libGLw's n_Use-newly-introduced-GLAPIVAR-for-variables.patch
    (boo#1082297)
* Mon Feb 19 2018 schwab@suse.de
- Mesa-gallium only exists if %%{with_opencl}
- Add support for riscv64
* Fri Feb 16 2018 mstaudt@suse.com
- Split Nouveau and VC4 from the main driver package on all systems
  Fixes (boo#1081210).
* Thu Feb 15 2018 mimi.vx@gmail.com
- remove %%{release} based dependecies
  Unfortuanetly Mesa and Mesa-drivers can have different release number
  Release is Commit_Count.Build_Count and build count can be different
  because both packages have different dependencies
* Wed Feb 14 2018 mimi.vx@gmail.com
- add u_glsl-linker-error.patch
  * Fix attaching multiple shader objects for the same stage to a
    GLSL program triggers a linker error (fdo#104777, bnc#1080492)
  * Fixes issue with wine applications.
* Mon Feb 12 2018 joop.boonen@opensuse.org
- Added %%{release} so the correct package release is used
  when a package has been patched
* Fri Feb  9 2018 sndirsch@suse.com
- Update to 18.0.0-rc4
- supersedes u_mesa-st-shader_cache-restore-num_tgsi_tokens-when-loading.patch
* Tue Feb  6 2018 msrb@suse.com
- u_mesa-st-shader_cache-restore-num_tgsi_tokens-when-loading.patch
  * Fix crash when loading shader. (bnc#1079465)
* Fri Feb  2 2018 sndirsch@suse.com
- Update to 18.0.0-rc3
  * includes significant improvements for OpenGL and Vulkan support
    and performance.
- supersedes U_intel-Add-more-Coffee-Lake-PCI-IDs.patch
* Wed Jan 31 2018 msrb@suse.com
- Remove dependency on clang-devel-static. (bnc#1065464)
  * It was removed, clang-devel now again provides everything
    necessary as shared libraries.
* Tue Jan 30 2018 msrb@suse.com
- Require Mesa-dri-32bit and Mesa-gallium-32bit by Mesa-32bit. It
  mirrors the requirement of the normal packages. (bnc#1078261)
* Mon Jan 29 2018 msrb@suse.com
- Disable AMDGPU GFX9/Vega with LLVM < 6.0.0.
  * n_Disable-AMDGPU-GFX9-Vega-on-LLVM-lessthan-6.0.0.patch
  * While it is supported since LLVM 5.0.0, it was not working
    correctly (bnc#1075901). Since we do not have the resources to
    determine which fixes should be backported and LLVM 6 will be
    released relatively soon, disable the support until then. Users
    with the card will have working desktop using software
    rendering just like they did with LLVM 4.
* Mon Jan 22 2018 normand@linux.vnet.ibm.com
- in spec file move %%dir %%{_libdir}/dri to avoid ppc build failure
* Fri Jan 19 2018 msrb@suse.com
- Update to 17.3.3
  * Fixes to radv, anv, etnaviv, swrast and radeonsi drivers.
  * Fixes for DRI3.
- Make Mesa require Mesa-dri and Mesa-gallium. This makes Mesa
  usable again for users who do not install recommended packages.
  It breaks the Mesa and Mesa-drivers split, which has to be fixed
  by ignoring it in obs.
* Wed Jan 17 2018 normand@linux.vnet.ibm.com
- Add _constraints to select 6G disk for PowerPC
  to avoid cpio: write error on obs-power8-05 workers boo#1076325
* Mon Jan 15 2018 msrb@suse.com
- U_intel-Add-more-Coffee-Lake-PCI-IDs.patch
  * Add more Coffeelake PCI IDs (request by Intel)
* Wed Jan 10 2018 msrb@suse.com
- Update to 17.3.2
  * Multiple fixes in the RADV Vulkan driver, workaround when using
    slibtool and a GLSL workaround for various titles using Unreal
    Engine 4.
- Drop upstreamed u_r600-Add-support-for-B5G5R5A1.patch
- Modify u_mesa-python3-only.patch to not break python 2.
* Mon Jan  8 2018 msrb@suse.com
- Update to 17.3.1
  * Multiple fixes and improvements of the GLSL shader cache. The
    RADV driver no longer advertises VK_EXT_debug_report - there is
    no support for it.
  * The i965, radeonsi, nvc0 and freedreno drivers have received a
    few small fixes each.
  * A number of big endian fixes have been merged.
* Mon Jan  8 2018 tchvatal@suse.com
- Switch to python3 during build instead of python2
  * Add patch u_mesa-python3-only.patch
* Mon Jan  8 2018 msrb@suse.com
- Add Mesa-dri and Mesa-gallium to baselibs.conf.
- Require llvm >= 3.9.0
  * The build fails otherwise because it is required for multiple
    Mesa components.
* Fri Jan  5 2018 jengelh@inai.de
- Drop some redundant wording from descriptions.
  Drop redundant %%if guard around a %%post section.
* Wed Dec 13 2017 msrb@suse.com
- Use different form of split for faster build (bnc#1071297)
  * Mesa.spec does not use llvm and builds most of the *-devel
    subpackages.
  * Mesa-drivers.spec uses llvm and builds extra things installable
    in addition to packages from Mesa.spec. These packages are
    required for actual rendering.
* Fri Dec  8 2017 mimi.vx@gmail.com
- update to 17.3.0
- drop U_configure.ac-rework-llvm-libs-handling-for-3.9.patch
  * new major release comitng with changes in RADV, intel ANV,
    S3TC support, RadeonSI driver with RX Vega. On-disk shader cache
* Wed Dec  6 2017 msrb@suse.com
- Split Mesa into Mesa and Mesa-mini. Mesa-mini does not depend on
  llvm and its purpose is to build fast and allow other packages
  that BuildRequire Mesa to be build independently on llvm.
  Packages built against Mesa-mini should work correctly when
  installed with full Mesa package. (bsc#1071297)
* Sun Nov 26 2017 aavindraa@gmail.com
- update to 17.2.6
  * Core: fix to keep a program alive when re-linking and prevent
    an use-after-free.
  * GLSL compiler: several fixes, including one to prevent a
    SIGSEV when calling an undeclared subroutine in certain
    conditions and another to mark the xfb buffers as active only
    if a variable uses them.
  * SPIR-V compiler: fixed seveal problems involving the usage of
    separate images and texture/samplers.
  * Intel drivers: many new fixes, specially for i965. Several are
    focused on improving SIMD32 and little-core. It also includes a
    fix for a GPU hang which was detected while playing HW
    accelerated video with mpv.
  * AMD drivers: radv has seen plugged 2 memory leaks while r600
    has gotten a fix through reversing the tess factor components
    for isolines.
  * swr driver: fixes for two performance regressions (one for
    avx512 platforms and the other for the avx/avx2 platforms).
  * ddebug gallium driver: fix for an use-after-free.
  * EGL: Wayland platform of the the DRI2 drivers got a fix to
    prevent crashing in ancient systems.
  * GLX has also received corrections to prevent a couple of errors
    when creating and binding a context in DRI3 and DRISW,
    respectively.
  * Build and integration: allow building libglvnd when EGL is present
    but not GLX. Enable building targets which don't need X11, such
    as omx and va, when XCB is not present. You can now specify
    the prefix installation for the OpenCL icd file.
* Sat Nov 11 2017 aavindraa@gmail.com
- update to 17.2.5
  * In Core, a GL error related to the ARB_ES3_1_compatibility spec
    noticed with the GFXBench 5 Aztec Ruins has been corrected.
  * The GLSL compiler is not giving a linker error for mismatching
    uniform precision with GLSL ES 1.00 any more. This enables,
    specially, several Android applications which violate this rule,
    e.g., Forge of Empires.
  * The SPIR-V compiler has corrected an assert triggered when
    support for the simple memory model was claimed.
  * NIR has also received a correction related with
    gl_SubGroupG{e,t}MaskARB.
  * Intel drivers, specially i965, got several fixes, including a
    plug for a memory leak and another one in the compiler to avoid
    GPU hangs on Broxton.
  * The gallium i915g driver for Intel has seen an important fix.
  * AMD drivers (mostly radv) have received several fixes, including a
    correction for a DCC corruption that was visible with Rust,
    breaking an endless loop in r600, avoiding a GPU hang with vulkan
    dota2 in VR mode and a plug for a memory leak.
  * Broadcom's vc4 gotten a fix to exclude some code that shouldn't
    be there in release builds.
* Tue Oct 31 2017 aavindraa@gmail.com
- update to 17.2.4
  * Mesa Core includes a change to prevent KOTOR from breaking when
  in combination with the ATI fragment shader extension.
  * Additionally, NIR has also received a correction.
  * Mesa's state tracker has gotten a patch to avoid leaks in
  certain situations such as resizing a window.
  * Intel drivers have received fixes. The compiler has
  gotten a couple, while anv also received one.
  * i965 got a patch to avoid VA-API, Beignet and other contexts
  in the system to break when in combination with previous versions of Mesa 17.2.x.
  * AMD's compiler received fixes. `radv` has also
  received another couple, including one to avoid a hang due to
  overflow on huge textures.
  * Broadcom's vc4 has corrected a problem when compiling with
  Android's clang.
  * Clover compilation issue fixed (affecting a specific clang revision)
  * Fixed Vulkan's WSI memory leak in X11.
* Mon Oct 23 2017 sndirsch@suse.com
- update to 17.2.3
  * The Vulkan drivers ANV and RADV have multiple small fixes.
  * The EGL code has improved handling of the new wl_dmabuf codepath.
  * SWR no longer crashes when checking environment variables.
  * Other gallium drivers have also seen updates - freedreno, nouveau and
    radeonsi. The gallivm module, used by llvmpipe et al. has gained little
    endian PPC64 fixes.
  * The VA and VDPAU state-trackers have seems improvements handling
    interlaced videos.
  * We're using python3 compatible constructs which gives us SCons 3.0
    support.
* Tue Oct 17 2017 msrb@suse.com
- U_configure.ac-rework-llvm-libs-handling-for-3.9.patch
  * llvm-config 3.9 and higher works properly, use its values
    instead of guessing. Fixes build against llvm built as single
    shared library.
* Thu Oct 12 2017 schwab@suse.de
- svga is x86-only
- u_svga-Fix-build-on-ppc64le.patch: Remove
* Wed Oct 11 2017 msrb@suse.com
- Add build dependency on clang-devel-static.
  * Required with new llvm4 build mode (bnc#1049703).
  * Also rename dependency llvm-clang-devel to clang-devel. The
    llvm-clang-devel is old name kept around for compatibility.
* Wed Oct  4 2017 sndirsch@suse.com
- update to 17.2.2
  * several Vulkan ANV/RADV driver fixes including Wayland WSI
    improvements, RadeonSI / i965 / VC4 OpenGL fixes among other
    work, some fixes to common Gallium3D code, support for LLVM 5.0
    in Gallium3D when using the SCons build system, and a range of
    other fixes/improvements.
* Sat Sep 30 2017 stefan.bruens@rwth-aachen.de
- Drop gallium svga driver for arm/aarch64. The svga driver is a vmware
  guest driver, thus only usable on x86(_64) platforms
- Also enable OpenCL on arm (32bit), llvm4 has reached Factory
* Mon Sep 18 2017 mimi.vx@gmail.com
- update to 17.2.1
  * drop upstreamed patches
    n_force-xlocale-funcs.patch
    u_gallivm-correct-channel-shift-logic-on-big-endian.patch
    u_llvmpipe-lp_build_gather_elem_vec-BE-fix-for-3x16-lo.patch
  * fdo#100613 - Regression in Mesa 17 on s390x (zSystems)
  * fdo#101709 - [llvmpipe] piglit gl-1.0-scissor-offscreen regression
  * fdo#102454 - glibc 2.26 doesn't provide anymore xlocale.h
  * fdo#102467 - [src/mesa/state_tracker/st_cb_readpixels.c:178]: (warning)
    Redundant assignment
  * fdo#102502 - [bisected] Kodi crashes since commit 707d2e8b - gallium:
    fold u_trim_pipe_prim call from st/mesa to drivers
  * many fixes for RADV a glsl
* Thu Sep  7 2017 sndirsch@suse.com
- u_svga-Fix-build-on-ppc64le.patch
  * This let us compile the code on ppc64le, but it no-ops the log
    function.
* Tue Sep  5 2017 sndirsch@suse.com
- update to 17.2.0
  * many RADV/ANV Vulkan driver improvements
  * Vulkan and OpenGL performance improvements
  * more work towards OpenGL 4.6 compliance
  * a wealth of other open-source driver improvements
  * initial Raven Ridge support (used on Vega-class graphics)
  * Intel Cannonlake Support
- adjusted archlinux_0001-Fix-linkage-against-shared-glapi.patch
* Mon Aug 28 2017 mimi.vx@gmail.com
- update to 17.1.8
  * fdo#101334 - AMD SI cards: Some vulkan apps freeze the system
  * fdo#101766 - Assertion `!&quot;invalid type&quot;' failed when constant
    expression involves literal of different type<
  * fdo#102024 - FORMAT_FEATURE_SAMPLED_IMAGE_BIT not supported for D16_UNORM
    and D32_SFLOAT
  * fdo#102148 - Crash when running qopenglwidget example on mesa llvmpipe win32
  * fdo#102241 - gallium/wgl: SwapBuffers freezing regularly with swap
    interval enabled
  * fdo#101910 - [BYT]
    ES31-CTS.functional.copy_image.non_compressed.viewclass_96_bits.rgb32f_rgb32f
  * fdo#102308 - segfault in glCompressedTextureSubImage3D
* Mon Aug 28 2017 fvogt@suse.com
- Add patch to fix strtod on non-EN locale (boo#1055929):
  * n_force-xlocale-funcs.patch
* Wed Aug 23 2017 sndirsch@suse.com
- u_llvmpipe-lp_build_gather_elem_vec-BE-fix-for-3x16-lo.patch
  updated; fixes three of the four regressions observed (PPC64, S390)
  [fdo#100613, comment#42]
* Mon Aug 14 2017 jberry@suse.com
- Replace uses of arch directive with targettype within a package
  declaration to resolve incorrect dependencies placed on -32bit
  packages.
* Mon Aug 14 2017 msrb@suse.com
- Removed n_glesv2.pc-Add-lGL-for-libglvnd-builds-boo-1052776.patch
  * The issue was in libglvnd which is fixed now. (boo#1052776)
* Tue Aug  8 2017 sndirsch@suse.com
- n_glesv2.pc-Add-lGL-for-libglvnd-builds-boo-1052776.patch
  glesv2.pc: Add "-lGL" for libglvnd builds (boo#1052776)
* Mon Aug  7 2017 mimi.vx@gmail.com
- update to 17.1.6
  * fdo#97957 - Awful screen tearing in a separate X server with DRI3
  * fdo#101683 - Some games hang while loading when compositing is shut
    off or absent
  * fdo#101867 - Launch options window renders black in Feral Games
    in current Mesa trunk
  * and some other fixes as usualy
* Mon Jul 17 2017 msrb@suse.com
- u_r600-Add-support-for-B5G5R5A1.patch
  * Fixes rendercheck tests when X server accelerates using glamor.
    (bnc#1047154)
* Sun Jul 16 2017 mimi.vx@gmail.com
- update to 17.1.5
  * fdo#100242 - radeon buffer allocation failure during startup of Factorio
  * fdo#101657 - strtod.c:32:10: fatal error: xlocale.h: No such file or directory
  * fdo#101666 - bitfieldExtract is marked as a built-in function
    on OpenGL ES 3.0, but was added in OpenGL ES 3.1
  * fdo#101703 - No stencil buffer allocated when requested by GLUT
  * and other bugfixes
* Sat Jul  1 2017 mimi.vx@gmail.com
- update to 17.1.4
  * fdo#77240 - khrplatform.h not installed if EGL is disabled
  * fdo#95530 - Stellaris - colored overlay of sectors doesn't render on i965
  * fdo#96958 - [SKL] Improper rendering in Europa Universalis IV
  * fdo#99467 - [radv] DOOM 2016 + wine. Green screen everywhere
  * fdo#101071 - compiling glsl fails with undefined reference to `pthread_create'
  * fdo#101252 - eglGetDisplay() is not thread safe
  * fdo#101294 - radeonsi minecraft forge splash freeze since 17.1
  * fdo#101451 - [G33] ES2-CTS.functional.clipping.polygon regression
  * and some other fixes as usualy
* Mon Jun 19 2017 mimi.vx@gmail.com
- update to 17.1.3
  * fdo#100988 - glXGetCurrentDisplay() no longer works for FakeGLX contexts?
  * fixes for radv, radeonsi, i965
* Sat Jun 17 2017 mimi.vx@gmail.com
- Fix baselibs.conf -> boo#1044813
* Fri Jun 16 2017 sndirsch@suse.com
- added "Requires: libclc" to Mesa-libOpenCL packages (boo#1044646)
* Wed Jun  7 2017 sndirsch@suse.com
- specfile: Remove requires to vulkan libs from baselibs.conf on
  platforms where vulkan build is disabled; ugly ... (bsc#1042900)
* Tue Jun  6 2017 mimi.vx@gmail.com
- update to 17.1.2
  * fdo#98833 - [REGRESSION, bisected] Wayland revert commit breaks
    non-Vsync fullscreen frame updates
  * fdo#100741 - Chromium - Memory leak
  * fdo#100877 - vulkan/tests/block_pool_no_free regression
  * fdo#101110 - Build failure in GNOME Continuous
  * many ANV, RADV, vulkan, i965 and egl fixes
* Wed May 31 2017 sndirsch@suse.com
- u_llvmpipe-lp_build_gather_elem_vec-BE-fix-for-3x16-lo.patch
  * Fix loading of a 3x16 vector as a single 48-bit load on
    big-endian systems (PPC64, S390). [fdo#100613]
* Thu May 25 2017 mimi.vx@gmail.com
- update to 17.1.1
- dropped patch:
    fedora_0001-glxglvnddispatch-Add-missing-dispatch-for-GetDriverC.patch
  * fdo#100854 - YUV to RGB Color Space Conversion result is not precise
  * fdo#100925 - [HSW/BSW/BDW/SKL] Google Earth is not resolving
    all the details in the map correctly
  * radeonsi: add new vega10 pci ids
  * gbm/dri: Fix sign-extension in modifier query
  * radeon: automake: remove unneeded elf Cflags/Libs
  * egl: add g_egldispatchstubs.h to the release tarball
  * renderonly: Initialize fields of struct winsys_handle
  * vc4: Don't allocate new BOs to avoid synchronization when they're shared
  * anv: fix possible stack corruption
  * anv: don't leak DRM devices
  * glxglvnddispatch: Add missing dispatch for GetDriverConfig
  * nvc0/ir: SHLADD's middle source must be an immediate
  * nir/lower_tex: Fix minor error in YUV color conversion matrix
  * amd/addrlib: import Raven support
  * radeonsi/gfx9: add support for Raven
  * anv/formats: Update the three-channel BC1 mappings
  * 965/formats: Update the three-channel DXT1 mapping
  * radeonsi: mark fast-cleared textures as compressed when dirtying
  * radeonsi: fix primitive ID in fragment shader when using tessellation
  * radeonsi: fix gl_PrimitiveID in tessellation with instanced draws on SI
  * radeonsi: fix gl_PrimitiveIDIn in geometry shader when using tessellation
  * intel/isl/gen7: Use stencil vertical alignment of 8 instead of 4
  * mesa/st: fix yuv EGLImage's
  * virgl: fix virgl_bo_transfer_{put, get} box struct cop
  * 965/vec4/gs: restore the uniform values which was overwritten by failed
    vec4_gs_visitor execution
  * i965/vec4: fix swizzle and writemask when loading an uniform with constant offset
  * i965/vec4: load dvec3/4 uniforms first in the push constant buffer
  * gallivm: Make sure module has the correct data layout when pass manager runs
* Sun May 21 2017 sndirsch@suse.com
- specfile: libglvnd0 -> libglvnd; missed the package name
  change in libglvnd package (boo#1038619, comment#5)
* Thu May 11 2017 sndirsch@suse.com
- baselibs.conf: libglvnd0 -> libglvnd; missed the package name
  change in libglvnd package (boo#1038619)
* Wed May 10 2017 mimi.vx@gmail.com
- update to 17.1.0
- drop upstreamed patches:
    archlinux_0002-fixup-EGL-Implement-the-libglvnd-interface-for-EGL-v.patch
    archlinux_0001-EGL-Implement-the-libglvnd-interface-for-EGL-v2.patch
    archlinux_glapi-Link-with-glapi-when-built-shared.patch
  + New major release with:
  + OpenGL 4.2 support for Intel Ivy Bridge chips.
  + The RADV driver passes the Khronos CTS
  + Shader on-disk cache. Improving the startup and shader compilation
    times in some games.
  + This release includes significant performance improvements for games by
    Feral Interactive.
  * for full list of changes please check docs/relnotes/17.1.0.html
* Sat Apr 29 2017 mimi.vx@gmail.com
- update to 17.0.5
  * fdo#97524 - Samplers referring to the same texture unit with different
    types should raise GL_INVALID_OPERATION
  * nvc0/ir: Properly handle a "split form" of predicate destination
  * nir: Destination component count of shader_clock intrinsic is 2
  * winsys/sw/dri: don't use GNU void pointer arithmetic
  * st/clover: add space between &lt; and ::
  * configure.ac: check require_basic_egl only if egl enabled
  * st/mesa: automake: honour the vdpau header install location
  * intel/fs: Use regs_written() in spilling cost heuristic for improved accuracy
  * intel/fs: Take into account amount of data read in spilling cost heuristic.
  * radv: report timestampPeriod correctly
  * anv/blorp: Flush the texture cache in UpdateBuffer
  * anv/cmd_buffer: Flush the VF cache at the top of all primaries
  * anv/cmd_buffer: Always set up a null surface state
  * anv/cmd_buffer: Use the null surface state for ATTACHMENT_UNUSED
  * anv/blorp: Properly handle VK_ATTACHMENT_UNUSED
  * i965/vec4: Avoid reswizzling MACH instructions in opt_register_coalesce()
  * st/mesa: invalidate the readpix cache in st_indirect_draw_vbo
  * anv/cmd_buffer: Disable CCS on BDW input attachments
  * mesa: fix remaining xfb prims check for GLES with multiple instances
  * mesa: validate sampler type across the whole program
  * vbo: fix gl_DrawID handling in glMultiDrawArrays
  * util/queue: don't hang at exit
  * mesa: fix remaining xfb prims check for GLES with multiple instances
  * mesa: extract need_xfb_remaining_prims_check
  * mesa: move glMultiDrawArrays to vbo and fix error handling
  + update Mesa.keyring to both upstream release managers
* Fri Apr 28 2017 sndirsch@suse.com
- u_gallivm-correct-channel-shift-logic-on-big-endian.patch:
  * instead of reverse applying a change on s390x
    ("U_draw-use-SoA-fetch-not-AoS-one.patch") address the
    issue by a real fix (bsc#1032272, fdo#100613)
* Thu Apr 27 2017 sndirsch@suse.com
- baselibs.conf: added libvulkan_intel-32bit as a requirement for
  Mesa-libd3d (boo#1036282)
* Tue Apr 25 2017 schwab@linux-m68k.org
- No OpenCL on ppc
* Fri Apr 21 2017 sndirsch@suse.com
- let Mesa require Mesa-libEGL1 for a libglvnd build;
  xf86-video-amdgpu driver needs it for 2D support via glamor
  (boo#1034832)
* Thu Apr 20 2017 idonmez@suse.com
- Add u_add_llvm_codegen_dependencies.patch to link to
  libLLVMCodegen to fix cyclic linking problems. bsc#981975
* Tue Apr 18 2017 afaerber@suse.de
- Enable OpenCL for aarch64, ppc64 and ppc64le now, too.
  %%arm is still left out, waiting for llvm4 to build.
* Mon Apr 17 2017 mimi.vx@gmail.com
- update to 17.0.4
  * fdo#100391 - SachaWillems deferredmultisampling asserts
  * fdo#100452 - push_constants host memory leak when resetting command buffer
  * fdo#100582 - piglit.spec.arb_stencil_texturing.glblitframebuffer corrupts
    state.gl_texture* assertions
  * radeonsi: add new polaris10 pci ids
  * fixes for anv, radv, i965 and nouveau drivers
* Wed Apr 12 2017 sndirsch@suse.com
- only reverse-apply 'U_draw-use-SoA-fetch-not-AoS-one.patch' on
  s390x (bsc#1032272)
* Wed Apr 12 2017 sndirsch@suse.com
- build wayland on Leap >= 42.3
- separate package 'Mesa-dri-nouveau' on Leap
* Wed Apr 12 2017 sndirsch@suse.com
- removed broken locking patches for nouveau DRI driver
  * N_01-WIP-nouveau-add-locking.patch
  * N_02-nouveau-more-locking-make-sure-that-fence-work-is-always-done-with-the-push-mutex-acquired.patch
  * N_03-nv30-locking-fixes.patch
  * N_04-nv50-Fix-double-lock-in-nv50_hw_sm_get_query_result.patch
  * N_05-Use-nv50_render_condition-in-nv50_blitctx_post_blit.patch
* Wed Apr 12 2017 sndirsch@suse.com
- let Mesa require Mesa-libGL1 for a libglvnd build (bsc#1033708)
* Fri Apr  7 2017 sndirsch@suse.com
- U_draw-use-SoA-fetch-not-AoS-one.patch
  * reverse-apply this patch to fix OpenGL support on s390x
    (bsc#1032272)
* Wed Apr  5 2017 afaerber@suse.de
- Prepare building OpenCL for non-x86 architectures, too
  * s390x can build it right away (swrast)
  * %%arm aarch64 ppc64 ppc64le depend on LLVM amdgpu target for r600
- Fix typo in specfile comment
* Sat Apr  1 2017 mimi.vx@gmail.com
- update to 17.0.3
- change Mesa.keyring to new release manager key
  * fdo#96743 [BYT, HSW, SKL, BXT, KBL] GPU hangs with GfxBench 4.0 CarChase
  * fdo#99246 [d3dadapter+radeonsi] EVE-Online : hang on wormhole sight
  * fdo#100061 LODQ instruction generated with invalid dst mask
  * fdo#100182 Flickering in The Talos Principle on Sky Lake GT4
  * radeonsi: add new polaris12 pci id
  * many fixes for RADV, ANV, i915, radeonsi and freedreno drivers
* Wed Mar 29 2017 sndirsch@suse.com
- specfile: Remove requires to libglvnd0/libglvnd-devel from
  baselibs.conf when libglvnd build has been disabled; ugly ...
* Wed Mar 29 2017 sndirsch@suse.com
- specfile: only require libglvnd0/libglvnd-devel, if libglvnd build
  is enabled
- baselibs.conf: added requires to libglvnd0/libglvnd-devel where
  needed
* Mon Mar 27 2017 sndirsch@suse.com
- disable libglvnd for openSUSE Leap 42.x and sle12
* Fri Mar 24 2017 sndirsch@suse.com
- update to 17.0.2
  * fdo#97988 [radeonsi] playing back videos with VDPAU exhibits
    deinterlacing/anti-aliasing issues not visible with VA-API
  * fdo#99484 Crusader Kings 2 - Loading bars, siege bars, morale bars, etc.
    do not render correctly
  * fdo#100049 ralloc: Make sure ralloc() allocations match malloc()'s
    alignment. causes seg fault in 32bit build
  * many fixes for ANV, RADV, Vulkan and i965 + radeonsi drivers
* Thu Mar 23 2017 sndirsch@suse.com
- fedora_0001-glxglvnddispatch-Add-missing-dispatch-for-GetDriverC.patch
  * Fix glXGetDriverConfig not working with glvnd
  (https://bugzilla.redhat.com/show_bug.cgi?id=1429894)
- Fix indirect rendering, add libGLX_indirect.so.0 symlink
  (https://bugzilla.redhat.com/show_bug.cgi?id=1427174)
- added Requires to libglvnd0/libglvnd-devel where still needed
- patches picked from fedora:
  http://pkgs.fedoraproject.org/cgit/rpms/mesa.git/tree/
* Wed Mar 22 2017 sndirsch@suse.com
- re-enabled GLES build with libglvnd build, just not package GLES
  libs and require libglvnd0/libglvnd-devel instead
* Tue Mar 21 2017 sndirsch@suse.com
- archlinux_0001-Fix-linkage-against-shared-glapi.patch
  * fixes libglvnd support for osmesa
- archlinux_glvnd-fix-gl-dot-pc.patch
  * fixes libglvnd support in pkgconfig file
- archlinux_0001-EGL-Implement-the-libglvnd-interface-for-EGL-v2.patch/
  archlinux_0002-fixup-EGL-Implement-the-libglvnd-interface-for-EGL-v.patch
  * adds libglvnd support for EGL
- patches picked from archlinux:
  https://git.archlinux.org/svntogit/packages.git/tree/trunk?h=packages/mesa
* Fri Mar 17 2017 sndirsch@suse.com
- archlinux_glapi-Link-with-glapi-when-built-shared.patch
  * currently needed for libglvnd support; picked from archlinux
    https://git.archlinux.org/svntogit/packages.git/tree/trunk?h=packages/mesa
- fixed typo in Requires to libglvnd
* Thu Mar  9 2017 sndirsch@suse.com
- build with libglvnd support enabled (can be easily disabled via
  specfile define); requires libglvnd runtime and development
  packages; disabled build of GLESv1/v2 libs/packages provided now
  via libglvnd
* Sat Mar  4 2017 mimi.vx@gmail.com
- update to 17.0.1
  * radv: Never try to create more than max_sets descriptor sets.
  * radv: Reset emitted compute pipeline when calling secondary cmd buffer.
  * radv: Only use PKT3_OCCLUSION_QUERY when it doesn't hang.
  * radv: Use correct size for availability flag.
  * gallivm: Reenable PPC VSX (v3)
  * gallivm: Improve debug output (V2)
  * gallivm: Override getHostCPUName() "generic" w/ "pwr8" (v4)
  * egl/dri3: implement query surface hook
  * etnaviv: move pctx initialisation to avoid a null dereference
  * etnaviv: remove number of pixel pipes validation
  * anv: fix Get*MemoryRequirements for !LLC
  * egl/wayland: Don't use DRM format codes for SHM
  * tgsi: fix memory leak in tgsi sanity check
  * radv: change base aligmment for allocated memory.
  * radv: fix cik macroModeIndex.
  * radv: adopt some init config workarounds from radeonsi.
  * radv: fix depth format in blit2d.
  * radv: fix txs for sampler buffers
  * bin/get-extra-pick-list: use git merge-base to get the branchpoint
  * bin/get-extra-pick-list: rework to use already_picked list
  * bin/get-typod-pick-list.sh: limit `git grep ...' to only as needed
  * bin/get-pick-list.sh: limit `git grep ...' only as needed
  * bin/get-pick-list.sh: remove ancient way of nominating patches
  * bin/get-fixes-pick-list.sh: add new script
  * vc4: Avoid emitting small immediates for UBO indirect load address guards.
  * r300g: only allow byteswapped formats on big endian
  * gallium/u_queue: fix a crash with atexit handlers
  * gallium/u_queue: set num_threads correctly if not all threads start
  * glx/glvnd: Fix GLXdispatchIndex sorting
  * gm107/ir: fix address offset bitfield for ATOMS
  * nvc0: set the render condition in the compute object
  * st/mesa: don't pass compare mode for stencil-sampled textures
  * nvc0: disable linked tsc mode in compute launch descriptor
  * i965/sampler_state: Clamp min/max LOD to 14 on gen7+
  * i965/sampler_state: Pass texObj into update_sampler_state
  * i965/sampler_state: Set the "Base Mip Level" field on Sandy Bridge
  * intel/blorp: Swizzle clear colors on the CPU
  * i965/fs: Fix the inline nir_op_pack_double optimization
  * anv: Add an invalidate_range helper
  * anv/query: clflush the bo map on non-LLC platforms
  * genxml: Make MI_STORE_DATA_IMM more consistent
  * anv/query: Perform CmdResetQueryPool on the GPU
  * intel/blorp: Explicitly flush all allocated state
  * glsl: non-last member unsized array on SSBO must fail
  * mesa: Do (TCS && !TES) draw time validation in ES as well.
  * configure.ac: check require_basic_egl only if egl enabled
  * anv: wsi: report presentation error per image request
  * i965/fs: fix uninitialized memory access
  * radeonsi: fix UNSIGNED_BYTE index buffer fallback with non-zero start (v2)
  * gallium/util: remove unused u_index_modify helpers
  * gallium/u_index_modify: don't add PIPE_TRANSFER_UNSYNCHRONIZED
  * unconditionally
  * gallium/u_queue: fix random crashes when the app calls exit()
  * radeonsi: fix broken tessellation on Carrizo and Stoney
  * amd/common: fix ASICREV_IS_POLARIS11_M for Polaris12
  * android: radeonsi: fix sid_table.h generated header include path
  * android: glsl: build shader cache sources
  * configure.ac: Drop LLVM compiler flags more radically
  * winsys/amdgpu: reduce max_alloc_size based on GTT limits
  * radeonsi: handle MultiDrawIndirect in si_get_draw_start_count
  * radeonsi: fix UINT/SINT clamping for 10-bit formats on <= CIK
  * glsl: fix heap-use-after-free in ast_declarator_list::hir()
  * android: fix droid_create_image_from_prime_fd_yuv for YV12
* Tue Feb 21 2017 schwab@linux-m68k.org
- Use --enable-gallium-llvm only if llvm is available
* Tue Feb 21 2017 dimstar@opensuse.org
- Provide libwayland-egl1 as -32bit compat library, required by
  libgtk-3-0.
* Tue Feb 14 2017 jengelh@inai.de
- Some %%if around %%post do not match with %%if around %%package;
  drop them altogether since they are not needed except around
  %%files.
- Rename wrongly-named libOSMesa9 to libOSMesa8
* Mon Feb 13 2017 mimi.vx@gmail.com
- update to 17.0.0
- removed n_Fixed-build-against-wayland-1.2.1.patch , version requirement
  bumped up by upstream.
  * Vulkan drivers:
  + Correctly return (and implement) VK_INCOMPLETE on multiple WSI queries
  + Support for the VK_KHR_sampler_mirror_clamp_to_edge extension
  + We now use the Khoronos vk.xml file to generate the entrypoints
  * ANV:
  + HiZ and performance improvements
  + Float64 support and tessellation shader support.
  * RADV:
  + Support multiple devices
  + Support for the VK_AMD_draw_indirect_count extension
  + Support for the VK_AMD_negative_viewport_height extension
  * Mesa core:
  + Noticeable refactoring en route to GLSL Shader Cache
  + Groundwork for int64
  * i965:
  + OpenGL 4.5 support on Haswell hardware
  + Reuse the same BLORP and ISL code as the ANV driver
  * Gallium:
  + HUD: A number of race issues and memory leaks were resolved.
  * freedreno
  + Support for a5xx
  * nouveau:
  + OpenGL 4.3 support on Maxwell hardware
  + Improved performance due to instruction pipelining (Maxwell)
  * r600/radeonsi
  + VCE: Handle H.264 level 5.2
  + Polaris12 support
  + Dozens of performance improvements
  * Clover:
  + Implement clGetExtensionFunctionAddressForPlatform.
  + Add missing clGetDeviceInfo CL1.2 queries
  * VDPAU:
  + Use dri3 to directly send the buffer to X
  * Build:
  + Building RADV requires --enable-gallium-llvm
  + Compatibility fixes for building mesa as part of ARC
  + The vulkan headers vk_platform.h and vulkan.h are no longer installed
  + A couple of configure options (--with-sha1 and --disable-shader-cache) are
    removed alongside their respective library requirements.
* Sat Feb  4 2017 schwab@linux-m68k.org
- specfile: fix build configuration for arm, ppc and s390 platforms
* Thu Feb  2 2017 sndirsch@suse.com
- update to 13.0.4
  * Multiple fixes for the i965 and radeonsi drivers. An odd glitch
    in glxgears when using the freedreno driver was also addressed.
  * The ANV driver being the prime source of patches - from
    compatibility improvements with newer Vulkan loaders,
    smoketesting and various rendering and compliance fixes.
  * A couple of longstanding issues in the VA state tracker have
    also been resolved.
* Mon Jan 30 2017 sndirsch@suse.com
- baselibs.conf: replaced definition of packages, which default is
  not set to be built in specfile to
    arch aarch64 ppc64 ppc64le s390x x86_64 package <package>
  in order to make "osc service localrun source_validator" happy :-(
* Fri Jan 27 2017 mimi.vx@gmail.com
- Update baselibs.conf to ship i386 vulkan json files on x86_64
* Thu Jan 19 2017 mimi.vx@gmail.com
- Updated baselibs.conf to reflect libvulkan_radeon
* Thu Jan 19 2017 mimi.vx@gmail.com
- Enabled RADV vulkan driver for AMD GPU cards
* Thu Jan  5 2017 mimi.vx@gmail.com
- update to 13.0.3
  + dropped U_cso-don-t-release-sampler-states-that-are-bound.patch
  * fdo#77662 Fail to render to different faces of depth-stencil cube map
  * fdo#92234 [BDW] GPU hang in Shogun2
  * fdo#98329 dEQP-EGL.functional.image.render_multiple_contexts.gles2_renderbuffer_depth16_depth_buffer
  * fdo#99038 dEQP-EGL.functional.negative_api.create_pixmap_surface crashes
  * many radeonsi and i965 bugfixes
* Thu Dec 15 2016 dmueller@suse.com
- clean up configuration settings to be uniform accross all
  architectures except for list of dri and gallium drivers
* Mon Dec 12 2016 mstaudt@suse.com
- U_cso-don-t-release-sampler-states-that-are-bound.patch:
  This avoids Radeon hangs due to a use-after-free bug in Gallium.
  Fixes (boo#1015012), (fdo#93649)
* Mon Nov 28 2016 mimi.vx@gmail.com
- update to 13.0.2
  * fdo#97321 Query INFO_LOG_LENGTH for empty info log should return 0
  * fdo#97420  &quot;#version 0&quot; crashes glsl_compiler
  * i965: Add some APL and KBL SKU strings
  * i965: Reorder PCI ID list to match release order
  * i965/glk: Add basic Geminilake support
  * wsi: fix VK_INCOMPLETE for vkGetSwapchainImagesKHR
  * ac/nir/llvm: fix channel in texture gather lowering code.
  * vulkan/wsi/x11: handle timeouts properly in next image acquire (v1.1)
  * vulkan/wsi: store present mode in swapchain base class
  * vulkan/wsi/x11: add support for IMMEDIATE present mode
  * vulkan/wsi/x11: Fix behavior of vkGetPhysicalDeviceSurfaceFormatsKHR
  * vulkan/wsi/x11: Fix behavior of vkGetPhysicalDeviceSurfacePresentModesKHR
  * cherry-ignore: add reverted LLVM_LIBDIR patch
  * anv: fix enumeration of properties
  * vc4: Don't abort when a shader compile fails.
  * vc4: Clamp the shadow comparison value.
  * vc4: Fix register class handling of DDX/DDY arguments.
  * util/disk_cache: close a previously opened handle in disk_cache_put (v2)
  * anv: Fix unintentional integer overflow in anv_CreateDmaBufImageINTEL
  * anv/format: handle unsupported formats properly
  * glcpp: Handle '#version 0' and other invalid values
  * glsl: Parse 0 as a preprocessor INTCONSTANT
  * anv/gen8: Stall when needed in Cmd(Set|Reset)Event
  * anv/wsi: Set the fence to signaled in AcquireNextImageKHR
  * anv: Rework fences
  * vulkan/wsi/wayland: Include pthread.h
  * vulkan/wsi/wayland: Clean up some error handling paths
  * vulkan/wsi: Report the correct min/maxImageCount
  * i965/gs: Allow primitive id to be a system value
  * anv: Handle null in all destructors
  * anv/fence: Handle ANV_FENCE_CREATE_SIGNALED_BIT
  * nir/spirv: Fix handling of gl_PrimitiveId
  * anv/blorp: Ignore clears for attachments first used as resolve destinations
  * anv: Implement a depth stall restriction on gen7
  * anv/cmd_buffer: Handle running out of binding tables in compute shaders
  * anv/cmd_buffer: Emit a CS stall before setting a CS pipeline
  * vulkan/wsi/x11: Implement FIFO mode.
  * isl: Fix height calculation in isl_msaa_interleaved_scale_px_to_sa
  * i965/hsw: Set integer mode in sampling state for stencil texturing
  * intel: Set min_ds_entries on Broxton.
  * i965: Fix compute shader crash.
  * mesa: Drop PATH_MAX usage.
  * i965: Fix GS push inputs with enhanced layouts.
  * vulkan/wsi: Add a thread-safe queue implementation
  * anv: fix multi level clears with VK_REMAINING_MIP_LEVELS
  * gbm: request correct version of the DRI2_FENCE extension
  * radeonsi: store group_size_variable in struct si_compute
  * glsl/lower_output_reads: fix geometry shader output handling with conditional emit
  * Fix races during _mesa_HashWalk().
  * mesa: fix empty program log length
* Mon Nov 21 2016 sndirsch@suse.com
- baselibs.conf: enabled build of 32bit Mesa-dri-nouveau package,
  e.g. required for Steam (bnc#1011156)
* Mon Nov 14 2016 mimi.vx@gmail.com
- update to 13.0.1
  * fdo#97715 [ILK,G45,G965] piglit.spec.arb_separate_shader_objects.misc
    api error checks
  * fdo#98012 [IVB] Segfault when running Dolphin twice with Vulkan
  * fdo#98512 radeon r600 vdpau: Invalid command stream: texture bo too small
  * i965: Fix GPU hang related to multiple render targets and alpha testing
  * Revert "st/vdpau: use linear layout for output surfaces"
  * ac/nir: add support for discard_if intrinsic (v2)
  * nir: add conditional discard optimisation (v4)
  * amd/addrlib: limit fastcall/regparm to GCC i386
  * anv: use correct .specVersion for extensions
  * vc4: Use Newton-Raphson on the 1/W write to fix glmark2 terrain.
  * ir: Flip gl_SamplePosition in nir_lower_wpos_ytransform().
  * anv/device: Return DEVICE_LOST if execbuf2 fails
  * vulkan/wsi/x11: Better handle wsi_x11_connection_create failure
  * vulkan/wsi/x11: Clean up connections in finish_wsi
  * anv: Better handle return codes from anv_physical_device_init
  * intel/blorp: Use wm_prog_data instead of hand-rolling our own
  * intel/blorp: Pass a brw_stage_prog_data to upload_shader
  * anv/pipeline: Put actual pointers in anv_shader_bin
  * anv/pipeline: Properly cache prog_data::param
  * intel/blorp: Emit all the binding tables
  * anv/device: Add an execbuf wrapper
  * anv: Add a cmd_buffer_execbuf helper
  * anv: Don't presume to know what address is in a surface relocation
  * anv: Add a new bo_pool_init helper
  * anv/allocator: Simplify anv_scratch_pool
  * anv: Initialize anv_bo::offset to -1
  * anv/batch_chain: Improve write_reloc
  * anv: Add an anv_execbuf helper struct
  * anv/batch: Move last_ss_pool_bo_offset to the command buffer
  * anv: Move relocation handling from EndCommandBuffer to QueueSubmit
  * anv/cmd_buffer: Take a command buffer instead of a batch in two helpers
  * anv/cmd_buffer: Enable a CS stall workaround for Sky Lake gt4
  * glsl: Update deref types when resizing implicitly sized arrays.
  * mesa: Fix pixel shader scratch space allocation on Gen9+ platforms.
  * anv: Do relocations in userspace before execbuf ioctl
  * egl: use util/macros.h
  * egl: make interop ABI visible again
  * glx: make interop ABI visible again
  * radeonsi: fix an assertion failure in si_decompress_sampler_color_textures
  * radeonsi: fix BFE/BFI lowering for GLSL semantics
  * glsl: fix lowering of UBO references of named blocks
  * st/glsl_to_tgsi: fix dvec[34] loads from SSBO
  * st/mesa: fix the layer of VDPAU surface samplers
  * gallium/hud: fix a problem where objects are free'd while in use.
  * gallium/hud: close a previously opened handle
  * gallium/hud: protect against and initialization race
  * mesa/glsl: delete previously linked shaders earlier when linking
* Mon Nov  7 2016 schwab@suse.de
- Build Mesa-dri-nouveau only where available
* Wed Nov  2 2016 zaitor@opensuse.org
- Drop u_Mesa_i965-import-prime-buffers.patch: Upstream fixed the
  bug in a different way, and we should not keep the now obsolete
  patch (boo#991638, fdo#71759).
* Tue Nov  1 2016 mimi.vx@gmail.com
- update to 13.0.0
- openGL 4.5 with i965 driver on intel bbroadwell and newer hw
- openGL ES for haswell supports 3.1, skylake 3.2
- fixes for intel vulkan driver
- early support fot GP100
- better radeonSI performace
- dropped U_r300g-Set-R300_VAP_CNTL-on-RSxxx-to-avoid-triangle-flickering.patch
- refreshed u_Mesa_i965-import-prime-buffers.patch
* Tue Oct 25 2016 sndirsch@suse.com
- let Mesa-dri-nouveau supplement xf86-video-nouveau, so it  gets
  preselected as well once hardware supplements for Mesa-dri-nouveau
  match (bnc#1005323)
* Mon Oct 17 2016 mstaudt@suse.com
- Mesa.spec: %%ifdef'd out patches by mistake
* Mon Oct 17 2016 mstaudt@suse.com
- Split off nouveau*_dri.so into Mesa-dri-nouveau.
  Nouveau's 3D support is too unstable to enable by default.
* Mon Oct 17 2016 mstaudt@suse.com
- Mesa.spec: Disable Nouveau locking patches by default
* Fri Oct 14 2016 mstaudt@suse.com
- U_r300g-Set-R300_VAP_CNTL-on-RSxxx-to-avoid-triangle-flickering.patch:
  Initialize RSxxx chipsets correctly (bsc#985650)
* Fri Oct 14 2016 mstaudt@suse.com
- N_01-WIP-nouveau-add-locking.patch
  N_02-nouveau-more-locking-make-sure-that-fence-work-is-always-done-with-the-push-mutex-acquired.patch
  N_03-nv30-locking-fixes.patch
  N_04-nv50-Fix-double-lock-in-nv50_hw_sm_get_query_result.patch
  N_05-Use-nv50_render_condition-in-nv50_blitctx_post_blit.patch
  Backport nouveau locking workaround to enable multithreading.
  Source: https://github.com/imirkin/mesa/commits/locking
  According to the author, crashes may still happen, but much more rarely.
  Tested on GK107.
  N_04-* and N_05-* include untested fixes for nv50.
  Fixes (boo#997171) as suggested in (fdo#91632).
* Mon Sep 19 2016 zaitor@opensuse.org
- Add u_Mesa_i965-import-prime-buffers.patch: i965: import prime
  buffers in the current context, not screen (fdo#71759,
  boo#991638).
* Sat Sep 17 2016 mimi.vx@gmail.com
- update to 12.0.3
  * fdo#97781 - [HSW, BYT, IVB] es2-cts.gtf.gl2extensiontests.depth_texture_cube_map.depth_texture_cube_map
  * Revert "i965/miptree: Stop multiplying cube depth by 6 in HiZ calculations"
* Mon Sep  5 2016 mimi.vx@gmail.com
- update to 12.0.2
  * fdo#69622 - eglTerminate then eglMakeCurrent crahes
  * fdo#89599 - symbol 'x86_64_entry_start' is already defined when building
    with LLVM/clang
  * fdo#91342 - Very dark textures on some objects in indoors environments in
    Postal 2
  * fdo#92306 - GL Excess demo renders incorrectly on nv43
  * fdo#94148 - Framebuffer considered invalid when a draw call is done
    before glCheckFramebufferStatus
  * fdo#96274 - [NVC0] Failure when compiling compute shader: Assertion
    `bb-<getFirst()-<serial >= bb-<getExit()-<serial' failed
  * fdo#96358 - SSO: wrong interface validation between GS and VS (regresion
    due to latest gles 3.1)
  * fdo#96381 - Texture artifacts with immutable texture storage and mipmaps
  * fdo#96762 - [radeonsi,apitrace] Firewatch: nothing rendered
    in scrollable (text) areas
  * fdo#96835 - "gallium: Force blend color to 16-byte alignment" crash with
    "-march=native -O3" causes some 32bit games to crash
  * fdo#96850 - Crucible tests fail for 32bit mesa
  * fdo#96908 - [radeonsi] MSAA causes graphical artifacts
  * fdo#96911 - webgl2 conformance2/textures/misc/tex-mipmap-levels.html
    crashes 12.1 Intel driver
  * fdo#96971 - invariant qualifier is not valid for shader inputs
  * fdo#97039 - The Talos Principle and Serious Sam 3 GPU faults
  * fdo#97207 - [IVY BRIDGE] Fragment shader discard writing to depth
  * fdo#97214 - X not running with error &quot;Failed to make EGL context current
  * fdo#97225 - [i965 on HD4600 Haswell] xcom switch to ingame cinematics cause
    segmentation fault
  * fdo#97231 - GL_DEPTH_CLAMP doesn't clamp to the far plane
  * fdo#97307 - glsl/glcpp/tests/glcpp-test regression
  * fdo#97331 - glDrawElementsBaseVertex doesn't work in display list on i915
  * fdo#97351 - DrawElementsBaseVertex with VBO ignores base vertex on
    Intel GMA 9xx in some cases
  * fdo#97426 - glScissor gives vertically inverted result
  * fdo#97476 - Shader binaries should not be stored in the PipelineCache
  * fdo#97567 - [SNB, ILK] ctl, piglit regressions in mesa 12.0.2rc1
  + many other fixes from 12.0.1
* Sat Jul  9 2016 mimi.vx@gmail.com
- update to 12.0.1
  * Vulkan driver for Intel hardware from Ivy Bridge onward.
  * OpenGL 4.3 for nvc0, radeonsi and i965 (Gen8+)
  * OpenGL ES 3.1 on nvc0 and radeonsi
  * DRI3 enablement for VDPAU, OMX and VAAPI
* Tue Jul  5 2016 toddrme2178@gmail.com
- Fix Group tag.
* Tue Jun 21 2016 mimi.vx@gmail.com
- update to 12.0.0-rc4 final RC
* Fri Jun 17 2016 sndirsch@suse.com
- moved libxatracker package definition to the end to get rid of
  issues related to the special version of this package
* Fri Jun 17 2016 sndirsch@suse.com
- let Mesa-libVulkan-devel conflict with vulkan-devel due to file
  conflics in both packages
* Wed Jun 15 2016 sndirsch@suse.com
- Update to version 12.0.0-rc2
  * Bug fixes and performance improvements
- supersedes patches:
  u_st-va-hardlink-driver-instances-to-gallium_drv_video.patch,
  U_anv-add-the-X-related-and-Wayland-CFLAGS-to-VULKAN.patch
- removed option for build in verbose log mode
- improved Group tag for libVulkan-devel
* Sun Jun 12 2016 sndirsch@suse.com
- fixed 'osc service localrun download_files' run by removing
  rc release from version define
* Thu Jun  9 2016 mimi.vx@gmail.com
- fix vulkan naming scheme, add supplement for xf86-video-intel
* Wed Jun  8 2016 tobias.johannes.klausmann@mni.thm.de
- Fix Requirement for Mesa-libVulkan-devel, not Mesa-libvulkan, but
  Mesa-libVulkan
* Wed Jun  8 2016 jslaby@suse.com
- x86: enable virgl gallium driver
* Tue Jun  7 2016 tobias.johannes.klausmann@mni.thm.de
- Update to version 12.0.0-rc2:
- New features:
  + OpenGL 4.3 on nvc0, radeonsi, i965 (Gen8+)
  + OpenGL ES 3.1 on nvc0, radeonsi
  + GL_ARB_ES3_1_compatibility on nvc0, radeonsi
  + GL_ARB_compute_shader on nvc0, radeonsi, softpipe
  + GL_ARB_cull_distance on i965/gen6+, nv50, nvc0, llvmpipe, softpipe
  + GL_ARB_framebuffer_no_attachments on nvc0, r600, radeonsi, softpipe
  + GL_ARB_internalformat_query2 on all drivers
  + GL_ARB_query_buffer_object on i965/hsw+
  + GL_ARB_robust_buffer_access_behavior on i965, nvc0, radeonsi
  + GL_ARB_shader_atomic_counters on radeonsi, softpipe
  + GL_ARB_shader_atomic_counter_ops on nvc0, radeonsi, softpipe
  + GL_ARB_shader_image_load_store on nvc0, radeonsi, softpipe
  + GL_ARB_shader_image_size on nvc0, radeonsi, softpipe
  + GL_ARB_shader_storage_buffer_objects on radeonsi, softpipe
  + GL_ATI_fragment_shader on all Gallium drivers
  + GL_EXT_base_instance on all drivers that support GL_ARB_base_instance
  + GL_EXT_clip_cull_distance on all drivers that support GL_ARB_cull_distance
  + GL_KHR_robustness on i965
  + GL_OES_copy_image on i965 (Baytrail and Gen8+)
  + GL_OES_draw_buffers_indexed and GL_EXT_draw_buffers_indexed on all drivers
    that support GL_ARB_draw_buffers_blend
  +GL_OES_gpu_shader5 and GL_EXT_gpu_shader5 on all drivers that support
  GL_ARB_gpu_shader5
  +GL_OES_sample_shading on i965, nvc0, r600, radeonsi
  +GL_OES_sample_variables on i965, nvc0, r600, radeonsi
  +GL_OES_shader_image_atomic on all drivers that support
  GL_ARB_shader_image_load_store
  +GL_OES_shader_io_blocks on i965, nvc0, radeonsi
  +GL_OES_shader_multisample_interpolation on i965, nvc0, r600, radeonsi
  + GL_OES_texture_border_clamp and GL_EXT_texture_border_clamp on all drivers
    that support +GL_ARB_texture_border_clamp
  + GL_OES_texture_buffer and GL_EXT_texture_buffer on i965, nvc0, radeonsi
  + EGL_KHR_reusable_sync on all drivers
  + GL_ARB_stencil_texture8 and GL_OES_stencil_texture8 on i965/gen8+
- Enable build of the Intel Vulkan driver (anv):
  + Introduce new packages: libVulkan and libVulkan-devel
- Remove upstreamed patches:
  + u_glxcmds-glXGetFBConfigs-fix-screen-bounds.patch
  + U_gallivm-disable-avx512-features.patch
- Upstream Patches:
  + U_anv-add-the-X-related-and-Wayland-CFLAGS-to-VULKAN.patch
  * Otherwise we might fail to find the headers in some scenarios.
- drop docs/COPYING: No GPL licensed code in Mesa resident (upstream change)
* Wed Jun  1 2016 eich@suse.com
- U_gallivm-disable-avx512-features.patch:
  Fix crashes on some Skykake CPUs by disabling avx512 features
  (bsc#980557, bsc#981532).
* Wed May 25 2016 dmueller@suse.com
- enable vc4 and freedreno on aarch64 as well
* Wed May 18 2016 eich@suse.com
- u_glxcmds-glXGetFBConfigs-fix-screen-bounds.patch:
  Fix crash due to oud of founds screen (boo#980382).
* Mon May  9 2016 mimi.vx@gmail.com
- update to 11.2.2
- removed upstreamed patches:
    + u_dri2-Check-for-dummyContext-to-see-if-the-glx_context-is-valid.patch
    + u_dri3-Check-for-dummyContext-to-see-if-the-glx_contex.patch
  * fdo#92850 - Segfault loading War Thunder
  * fdo#93767 - Glitches with soft shadows and MSAA in Knights of the Old Republic 2
  * fdo#94955 - Uninitialized variables leads to random segfaults (valgrind log,
  apitrace attached)
  * fdo#94994 -  OSMesaGetProcAdress always fails on mangled OSMesa
  * fdo#95026 - Alien Isolation segfault after initial loading screen/video
  * fdo#95133 - X-COM Enemy Within crashes when entering tactical mission with Bonaire
  * fdo#95164 - GLSL compiler (linker I think) emits assertion upon call to
  glAttachShader
  * fdo#95251 - vdpau decoder capabilities: not supported
  * radeon/uvd: alignment fix for decode message buffer
  * st/mesa: fix sampler view leak in st_DrawAtlasBitmaps()
  * gallium/util: initialize pipe_framebuffer_state to zeros
  * dri: Fix robust context creation via EGL attribute
  * dri2: Check for dummyContext to see if the glx_context is valid
  * cherry-ignore: remove duplicate commit
  * cherry-ignore: ignore the GetSamplerParameterIuiv{EXT,OES} fixups
  * vc4: Fix subimage accesses to LT textures.
  * vc4: Add support for rendering to cube map surfaces.
  * vc4: Fix tests for format supported with nr_samples == 1.
  * vc4: Make sure we recompile when sample_mask changes.
  * glapi: fix _glapi_get_proc_address() for mangled function names
  * nvc0: fix retrieving query results into buffer for timestamps
  * nouveau/video: properly detect the decoder class for availability checks
  * i965/fs: Properly report regs_written from SAMPLEINFO
  * egl/x11: authenticate before doing chipset id ioctls
  * winsys/sw/xlib: use correct free function for xlib_dt-&gt;data
  * i965: Fix clear code for ignoring colormask for XRGB formats on Gen9+.
  * glsl: Convert lower_vec_index_to_swizzle to a rvalue visitor.
  * glsl: Lower vector_extracts to swizzles after lower_vector_derefs.
  * radeon/uvd: fix tonga feedback buffer size
  * st/mesa: fix blit-based GetTexImage for non-finalized textures
  * gallium/radeon: handle failure when mapping staging buffer
  * st/glsl_to_tgsi: reduce stack explosion in recursive expression visitor
  * gallium/radeon: fix crash in r600_set_streamout_targets
  * radeonsi: correct NULL-pointer check in si_upload_const_buffer
  * radeonsi: work around an MSAA fast stencil clear problem
  * r600g/radeonsi: send endian info to format translation functions
  * r600g: set endianess of 16/32-bit buffers according to do_endian_swap
  * r600g: use do_endian_swap in color swapping functions
  * r600g: use do_endian_swap in texture swapping function
  * r600g: fix and optimize tgsi_cmp when using ABS and NEG modifier
  * llvmpipe: (trivial) initialize src1_alpha var to NULL
  * gallivm: fix bogus argument order to lp_build_sample_mipmap function
  * gallivm: make sampling more robust against bogus coordinates
  * gk110/ir: do not overwrite def value with zero for EXCH ops
  * gk110/ir: make use of IMUL32I for all immediates
  * nvc0/ir: fix wrong emission of (a OP b) OP c
  * gk110/ir: add emission for (a OP b) OP c
  * nvc0: reduce GL_MAX_3D_TEXTURE_SIZE to 2048 on Kepler+
  * st/glsl_to_tgsi: fix potential crash when allocating temporaries
  * dri3: Check for dummyContext to see if the glx_context is valid
  * i965/blorp/gen7: Prepare re-using for gen8
  * i965/blorp: Use 8k chunk size for urb allocation
  * tgsi: initialize stack allocated struct
  * winsys/sw/dri: use correct free function for dri_sw_dt-&gt;data
  * android: enable dlopen() on all architectures
* Thu Apr 21 2016 sndirsch@suse.com
- u_dri3-Check-for-dummyContext-to-see-if-the-glx_contex.patch
  * dri3: Check for dummyContext to see if the glx_context is valid
    According to the comments in src/glx/glxcurrent.c
    __glXGetCurrentContext() always returns a valid pointer. If no
    context is made current, it will contain dummyContext. Thus a
    test for NULL will always fail.
* Sun Apr 17 2016 mimi.vx@gmail.com
- update to 11.2.1
  * It fixes crashes in VAAPI, some build problems in Nine has been addressed,
    adds a drirc workaround for Warsow and resolves issues in the nouveau,
    radeonsi and i965 drivers.
  * fdo#93962 ES2-CTS.gtf.GL2FixedTests.scissor.scissor - segfault/asserts
* Mon Apr  4 2016 mimi.vx@gmail.com
- update to 11.2.0
- dropped U_clover-Fix-build-against-LLVM-3.8.patch
- dropped U_llvmpipe-Do-not-use-barriers-if-not-using-threads.patch
- New Features:
  * GL_ARB_arrays_of_arrays on all gallium drivers that provide GLSL 1.30
  * GL_ARB_base_instance on freedreno/a4xx
  * GL_ARB_compute_shader on i965
  * GL_ARB_copy_image on r600
  * GL_ARB_indirect_parameters on nvc0
  * GL_ARB_query_buffer_object on nvc0
  * GL_ARB_shader_atomic_counters on nvc0
  * GL_ARB_shader_draw_parameters on i965, nvc0
  * GL_ARB_shader_storage_buffer_object on nvc0
  * GL_ARB_tessellation_shader on i965 and r600 (evergreen/cayman only)
  * GL_ARB_texture_buffer_object_rgb32 on freedreno/a4xx
  * GL_ARB_texture_buffer_range on freedreno/a4xx
  * GL_ARB_texture_query_lod on freedreno/a4xx
  * GL_ARB_texture_rgb10_a2ui on freedreno/a4xx
  * GL_ARB_texture_view on freedreno/a4xx
  * GL_ARB_vertex_type_10f_11f_11f_rev on freedreno/a4xx
  * GL_KHR_texture_compression_astc_ldr on freedreno/a4xx
  * GL_AMD_performance_monitor on radeonsi (CIK+ only)
  * GL_ATI_meminfo on r600, radeonsi
  * GL_NVX_gpu_memory_info on r600, radeonsi
  * New OSMesaCreateContextAttribs() function (for creating core profile contexts)
  + Many bugfixes, for more info see relnotes/11.2.0.html
* Wed Mar 16 2016 eich@suse.com
- n_Define-GLAPIVAR-separate-from-GLAPI.patch:
  Add separate definition GLAPIVAR as GLAPI
  doesn't have the an 'extern' for some compiler
  versions. This is needed for GLw (bsc#970725).
* Wed Mar 16 2016 sndirsch@suse.com
- U_llvmpipe-Do-not-use-barriers-if-not-using-threads.patch
  * llvmpipe: Do not use barriers if not using threads; triggers
    on single cpu machines (like KVM in openQA) with gcc6 and
    latest glibc(bnc#971350)
* Mon Mar 14 2016 dmueller@suse.com
- enable llvmpipe for aarch64 (fate#320649)
* Thu Feb 11 2016 mimi.vx@gmail.com
-  update to 11.1.2
  * Bugfix release:
  + fdo#93648 - Random lines being rendered when playing Dolphin (geometry shaders
    elated, w/ apitrace)
  + fdo#93650 - GL_ARB_separate_shader_objects is buggy (PCSX2)
  + fdo#93717 - Meta mipmap generation can corrupt texture state
  + fdo#93722 - Segfault when compiling shader with a subroutine that takes a parameter
  + fdo#93731 - glUniformSubroutinesuiv segfaults when subroutine uniform is bound
    to a specific location
  + fdo#93761 - A conditional discard in a fragment shader causes no depth
    writing at all
  + Some bugfixes in i965,nv50,radeonsi,r600g,vc4 drivers
* Thu Jan 28 2016 idonmez@suse.com
- Add U_clover-Fix-build-against-LLVM-3.8.patch to fix build
  against llvm 3.8
* Wed Jan 20 2016 eich@suse.com
- u_dri2-Check-for-dummyContext-to-see-if-the-glx_context-is-valid.patch
  Check for dummyContext to see if the glx_context is valid (boo#962609).
* Wed Jan 20 2016 sndirsch@suse.com
- n_VDPAU-XVMC-libs-Replace-hardlinks-with-copies.patch
  * Since these are packaged separately in (open)SUSE anyway, one
    can use copies as well. This makes debug packages possible
    again. (bnc #962609)
* Wed Jan 13 2016 mimi.vx@gmail.com
- update to 11.1.1
  * Bugfix release and adding KB Lake PCI id's
  + fdo#91806 - configure does not test whether assembler supports sse4.1
  + fdo#92229 - [APITRACE] SOMA have serious graphical errors
  + fdo#92233 - Unigine Heaven 4.0 silhuette run
  + fdo#93004 - Guild Wars 2 crash on nouveau DX11 cards
  + fdo#93215 - [Regression bisected] Ogles1conform Automatic mipmap
    generation test is fail
  + fdo#93257 - [SKL, bisected] ASTC dEQP tests segfault
  + fixes for r600,nv*,glx,glsl,radeonsi and i965
* Wed Jan  6 2016 schwab@suse.de
- Enable swrast gallium driver on s390/aarch64
- Exclude Mesa-libva on s390/s390x/aarch64
* Sun Dec 20 2015 jimmy@boombatower.com
- Apply patch: st/va: hardlink driver instances to
  gallium_drv_video.so
  + u_st-va-hardlink-driver-instances-to-gallium_drv_video.patch
* Thu Dec 17 2015 jimmy@boombatower.com
- Add Mesa-libva.
* Tue Dec 15 2015 mimi.vx@gmail.com
- update to 11.1.0, new stable release
  * New features:
  + Note: some of the new features are only available with certain drivers.
  + OpenGL 3.1 support on freedreno (a3xx, a4xx)
  + OpenGL 3.3 support for VMware guest VM driver (supported by Workstation 12
    and Fusion 8).
  + GL_AMD_performance_monitor on nv50
  + GL_ARB_arrays_of_arrays on i965
  + GL_ARB_blend_func_extended on freedreno (a3xx)
  + GL_ARB_clear_texture on nv50, nvc0
  + GL_ARB_clip_control on freedreno/a4xx
  + GL_ARB_copy_image on nv50, nvc0, radeonsi
  + GL_ARB_depth_clamp on freedreno/a4xx
  + GL_ARB_fragment_layer_viewport on i965 (gen6+)
  + GL_ARB_gpu_shader_fp64 on r600 for Cypress/Cayman/Aruba chips
  + GL_ARB_gpu_shader5 on r600 for Evergreen and later chips
  + GL_ARB_seamless_cubemap_per_texture on freedreno/a4xx
  + GL_ARB_shader_clock on i965 (gen7+)
  + GL_ARB_shader_stencil_export on i965 (gen9+)
  + GL_ARB_shader_storage_buffer_object on i965
  + GL_ARB_shader_texture_image_samples on i965, nv50, nvc0, r600, radeonsi
  + GL_ARB_texture_barrier / GL_NV_texture_barrier on i965
  + GL_ARB_texture_buffer_range on freedreno/a3xx
  + GL_ARB_texture_compression_bptc on freedreno/a4xx
  + GL_ARB_texture_query_lod on softpipe
  + GL_ARB_texture_view on radeonsi and r600 (for evergeen and newer)
  + GL_ARB_vertex_type_2_10_10_10_rev on freedreno (a3xx, a4xx)
  + GL_EXT_blend_func_extended on all drivers that support the ARB version
  + GL_EXT_buffer_storage implemented for when ES 3.1 support is gained
  + GL_EXT_draw_elements_base_vertex on all drivers
  + GL_EXT_texture_compression_rgtc / latc on freedreno (a3xx & a4xx)
  + GL_KHR_debug (GLES)
  + GL_NV_conditional_render on freedreno
  + GL_OES_draw_elements_base_vertex on all drivers
  + EGL_KHR_create_context on softpipe, llvmpipe
  + EGL_KHR_gl_colorspace on softpipe, llvmpipe
  + new virgl gallium driver for qemu virtio-gpu
  + 16x multisampling on i965 (gen9+)
  + GL_EXT_shader_samples_identical on i965.
  * +many bugfixes, please see relnotes
* Wed Dec  9 2015 mimi.vx@gmail.com
- Update to version 11.0.7
    + bugfixes release for bugs found since 11.0.6
    fdo#90348 - Spilling failure of b96 merged value
    fdo#92363 - [BSW/BDW] ogles1conform Gets test fails
    fdo#92438 - Segfault in pushbuf_kref when running the android
    emulator (qemu) on nv50
    fdo#93110 - [NVE4] textureSize() and textureQueryLevels() uses a texture
    bound during the previous draw call
    fdo#93126> - wrongly claim supporting GL_EXT_texture_rg
    + plus fixes for r600g,llvmpipe,i955,egl,gles2
* Tue Dec  1 2015 jimmy@boombatower.com
- Add Mesa-libOpenCL.
* Sun Nov 22 2015 zaitor@opensuse.org
- Update to version 11.0.6:
  + This release brings driver fixes for i965, r600, radeonsi,
    nouveau, vc4, and llvmpipe including a serious regression for
    r100/r200 era hardware.
  + Additional patches cover glsl, nir, mesa/meta and VC-1
    decoding.
* Wed Nov 11 2015 mimi.vx@gmail.com
- update to 11.0.5
  * With this release we have some driver patches for i965 and nouveau, a couple
    of llvm 3.7 related fixes and a some bugfixes in the VA state-tracker.
  * Additionally we have a few new PCI ids for i965 and radeonsi.
* Sun Oct 25 2015 mimi.vx@gmail.com
- update to 11.0.4
  * bug fix release which fixes bugs found since the 11.0.3 release
  * droped patches - merged by upstream:
    U_gallium-add-PIPE_SHADER_CAP_MAX_UNROLL_ITERATIONS_HI.patch
    U_i965-Remove-early-release-of-DRI2-miptree.patch
* Thu Oct 22 2015 sndirsch@suse.com
- U_gallium-add-PIPE_SHADER_CAP_MAX_UNROLL_ITERATIONS_HI.patch
  * This avoids a serious r600g bug leading to a GPU hang (bnc#951298)
* Tue Oct 20 2015 sndirsch@suse.com
- Update to 11.0.3
  * bug fix release which fixes bugs found since the 11.0.2 release
* Thu Oct  1 2015 sndirsch@suse.com
- Update to 11.0.2
  * This is a emergency release which covers the final dEQP
    regressions introduced in the 11.0 development cycle.
* Wed Sep 30 2015 jslaby@suse.com
- update upstream status:
  * remove n_i965-Remove-early-release-of-DRI2-miptree.patch
  * add U_i965-Remove-early-release-of-DRI2-miptree.patch
* Sat Sep 26 2015 mpluskal@suse.com
- Update to 11.0.1
  * i965/vec4: Fix saturation errors when coalescing registers
  * i965/vec4_nir: Load constants as integers
  * meta: Abort meta pbo path if TexSubImage need signed unsigned
    conversion
  * docs: add sha256 checksums for 11.0.0
  * Update version to 11.0.1
  * docs: add release notes for 11.0.1
  * mesa: Fix GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE for default
    framebuffer.
  * t_dd_dmatmp: Make "count" actually be the count
  * t_dd_dmatmp: Clean up improper code formatting from previous
    patch
  * t_dd_dmatmp: Use '& 3' instead of '%% 4' everywhere
  * t_dd_dmatmp: Pull out common 'count -= count & 3' code
  * t_dd_dmatmp: Use addition instead of subtraction in loop
    bounds
  * st/mesa: avoid integer overflows with buffers >= 512MB
  * nv50, nvc0: fix max texture buffer size to 128M elements
  * freedreno/a3xx: fix blending of L8 format
  * nv50,nvc0: detect underlying resource changes and update tic
  * nv50,nvc0: flush texture cache in presence of coherent bufs
  * radeonsi: load fmask ptr relative to the resources array
  * nir: Fix a bunch of ralloc parenting errors
  * i965/vec4: Don't reswizzle hardware registers
  * configure.ac: Add support to enable read-only text segment on
    x86.
  * gbm: convert gbm bo format to fourcc format on dma-buf import
  * mesa: fix errors when reading depth with glReadPixels
  * i965: fix textureGrad for cubemaps
  * mesa: Fix texture compression on big-endian systems
* Mon Sep 14 2015 jslaby@suse.com
- add n_i965-Remove-early-release-of-DRI2-miptree.patch (bnc#945444)
* Mon Sep 14 2015 sndirsch@suse.com
- marked Mesa.keyring and mesa-11.0.0.tar.xz.sig as source in
  specfile in order to make factory checkin policy happy
* Sat Sep 12 2015 mimi.vx@gmail.com
- Update to version 11.0.0
  * Mesa 11.0 brings core Mesa support for OpenGL 4.2, RadeonSI and Nouveau NVC0
  OpenGL 4.1 support (the other hardware drivers remain at OpenGL 3.3), AMDGPU
  kernel driver support along with initial R9 Fury/Fiji support, EGL 1.5 support,
  ongoing OpenGL ES 3.1 work, OpenCL compute image support, HEVC video decode
  support for RadeonSI via VDPAU, OpenGL ES 3.0 for Freedreno, and many fixes.
  + drop U_mesa-llvm37-rename-r600-to-amdgpu.patch and U_mesa-llvm37.patch
* Fri Sep 11 2015 mimi.vx@gmail.com
- Update to version 10.6.7
  + add gpg verification of source package
  * fdo#90751 Revert "i965: Momentarily pretend to support
  ARB_texture_stencil8 for blits."
  * mesa/teximage: use correct extension for accept stencil texture.
* Mon Sep  7 2015 zaitor@opensuse.org
- Update to version 10.6.6:
  * This release includes patches for mesa core, i965 (regression
    fixes), r600 (assertions and crash fixes in the sb backend),
    radeonsi (workaround for GPU hang in Unigine Heaven) and
    nouveau (piglit tests).
- Replace libXvMC-devel and libexpat-devel for pkgconfig(xvmc) and
  pkgconfig(expat) BuildRequires.
* Mon Sep  7 2015 alarrosa@suse.com
- Add U_mesa-llvm37-rename-r600-to-amdgpu.patch to fix build with llvm 3.7
  due to rename of llvm target R600 to AMDGPU
* Sat Sep  5 2015 idonmez@suse.com
- Add U_mesa-llvm37.patch to fix build with llvm 3.7
* Sat Aug 22 2015 zaitor@opensuse.org
- Update to version 10.6.5:
  * Apart from the usual nouveau, i965 and radeon driver fixes,
    this time around we have a nouveau_vieux fix for a regression
    introduced with mesa 10.6.0 and a few even older big endian
    related bug-fixes.
- Replace libvdpau-devel for pkgconfig(vdpau) BuildRequires.
* Wed Aug 12 2015 sndirsch@suse.com
- update to 10.6.4
  * In this release we have a few GL specific fixes (in both dri
    drivers and the EGL loader), an updated mesa.icd file and a
    crashfix for the standalone glcpp tool.
* Wed Jul 29 2015 mimi.vx@gmail.com
- update to 10.6.3
  * fdo#90728 - dvd playback with vlc and vdpau causes segmentation fault
  * fdo#91337 - OSMesaGetProcAdress(&quot;OSMesaPixelStore&quot;) returns nil
  * osmesa: fix OSMesaPixelsStore typo
  * vl: cleanup video buffer private when the decoder is destroyed
  * st/vdpau: fix mixer size checks
  * auxiliary/vl: use the correct screen index
  * i965/gen9: Use custom MOCS entries set up by the kernel.
  * nv50, nvc0: enable at least one color RT if alphatest is enabled
  * nvc0/ir: fix txq on indirect samplers
  * nvc0/ir: don't worry about sampler in txq handling
  * gm107/ir: fix indirect txq emission
  * nv50: fix max level clamping on G80
  * program: Allow redundant OPTION ARB_fog_* directives.
  * xa: don't leak fences
* Sun Jul 12 2015 mimi.vx@gmail.com
- update to 10.6.2
  * fdo#73528 - Deferred lighting in Second Life causes system hiccups and screen flickering
  * fdo#80500 - Flickering shadows in unreleased title trace
  * fdo#82186 - [r600g] BARTS GPU lockup with minecraft shaders
  * fdo#84225 - Allow constant-index-expression sampler array indexing with GLSL-ES < 300
  * fdo#90537 - radeonsi bo/va conflict on RADEON_GEM_VA (rscreen->ws->buffer_from_handle returns NULL)
  * fdo#90873 - Kernel hang, TearFree On, Mate desktop environment
  * fdo#91022 - [g45 g965 bisected] assertions generated from textureGrad cube samplers fix
  * fdo#91047 - [SNB Bisected] Messed up Fog in Super Smash Bros. Melee in Dolphin
  * fdo#91056 - The Bard's Tale (2005, native) has rendering issues
  * fdo#91117 - Nimbus (running in wine) has rendering issues, objects are semi-transparent
  * fdo#91124 - Civilization V (in Wine) has rendering issues: text missing, menu bar corrupted
  * fdo#91173 - Oddworld: Stranger's Wrath HD: disfigured models in wrong colors
  * fdo#91226 - Crash in glLinkProgram (NEW)
  * fdo#91231 - [NV92] Psychonauts (native) segfaults on start when DRI3 enabled
  * loader: Look for any version of currently linked libudev.so
  * nv50/ir: propagate modifier to right arg when const-folding mad
  * nv50/ir: fix emission of address reg in 3rd source
  * nv50/ir: copy joinAt when splitting both before and after
  * mesa: reset the source packing when creating temp transfer image
  * nv50/ir: don't emit src2 in immediate form
  * mesa/prog: relative offsets into constbufs are not constant
  * nv50/ir: UCMP arguments are float, so make sure modifiers are applied
  * nvc0: turn sample counts off during blit
  * i965/fs: Fix ir_txs in emit_texture_gen4_simd16().
  * i965: Reserve more batch space to accomodate Gen6 perfmonitors.
  * i965/vs: Fix matNxM vertex attributes where M != 4.
  * Revert "glsl: clone inputs and outputs during linking"
  * Revert "i965: Delete linked GLSL IR when using NIR."
  * r600g: disable single-sample fast color clear due to hangs
  * radeonsi: fix a hang with DrawTransformFeedback on 4 SE chips
  * st/dri: don't set PIPE_BIND_SCANOUT for MSAA surfaces
  * nouveau: Use dup fd as key in drm-winsys hash table to fix ZaphodHeads.
  * winsys/radeon: Use dup fd as key in drm-winsys hash table to fix ZaphodHeads.
  * i965/fs: Don't mess up stride for uniform integer multiplication.
  * winsys/radeon: Unmap GPU VM address range when destroying BO
  * meta: Only change and restore viewport 0 in mesa meta mode
  * i965: allocate at least 1 BLEND_STATE element
  * i965/skl: Set the pulls bary bit in 3DSTATE_PS_EXTRA
  * glsl: Add missing check for whether an expression is an add operation
  * glsl: Make sure not to dereference NULL
  * i965: Don't try to print the GLSL IR if it has been freed
  * glsl: clone inputs and outputs during linking
  * i965: Delete linked GLSL IR when using NIR.
  * glsl: Allow dynamic sampler array indexing with GLSL ES < 3.00
  * mesa/glsl: new compiler option EmitNoIndirectSampler
  * i965: use EmitNoIndirectSampler for gen < 7
  * i915: use EmitNoIndirectSampler
  * mesa/st: use EmitNoIndirectSampler if !ARB_gpu_shader5
  * glsl: validate sampler array indexing for 'constant-index-expression'
* Mon Jun 29 2015 mimi.vx@gmail.com
- adjust libdrm dependencies
* Mon Jun 29 2015 sndirsch@suse.com
- Update to version 10.6.1
  * This release includes core mesa and glsl patches (amonst which
    a Dota2 Reborn bugfix) affecting all dri drivers, nouveau specific
    fixes and a selection of shared-glapi commits - from build fixes, to
    ones ensuring that the dri modules can be loaded.
* Tue Jun 23 2015 sndirsch@suse.com
- n_Fixed-build-against-wayland-1.2.1.patch
  * required to fix build with wayland on openSUSE 13.1
* Mon Jun 15 2015 tobias.johannes.klausmann@mni.thm.de
- Update to version 10.6.0:
- New GL/EGL Features:
  + GL_AMD_pinned_memory on r600, radeonsi
  + GL_ARB_clip_control on i965
  + GL_ARB_depth_buffer_float on freedreno
  + GL_ARB_depth_clamp on freedreno
  + GL_ARB_direct_state_access on all drivers for Core GL contexts.
  + GL_ARB_draw_indirect, GL_ARB_multi_draw_indirect on r600
  + GL_ARB_draw_instanced on freedreno
  + GL_ARB_gpu_shader_fp64 on nvc0, softpipe
  + GL_ARB_gpu_shader5 on i965/gen8+
  + GL_ARB_instanced_arrays on freedreno
  + GL_ARB_pipeline_statistics_query on i965, nv50, nvc0, r600, radeonsi, softpipe
  + GL_ARB_program_interface_query (all drivers)
  + GL_ARB_texture_stencil8 on nv50, nvc0, r600, radeonsi, softpipe
  + GL_ARB_texture_view on llvmpipe, softpipe
  + GL_ARB_uniform_buffer_object on freedreno
  + GL_ARB_vertex_attrib_64bit on nvc0, softpipe
  + GL_ARB_viewport_array, GL_AMD_vertex_shader_viewport_index on i965/gen6
  + GL_EXT_draw_buffers2 on freedreno
  + GL_OES_EGL_sync on all drivers
  + EGL_KHR_fence_sync on i965, freedreno, nv50, nvc0, r600, radeonsi
  + EGL_KHR_wait_sync on i965, freedreno, nv50, nvc0, r600, radeonsi
  + EGL_KHR_cl_event2 on freedreno, nv50, nvc0, r600, radeonsi
  + GL_AMD_performance_monitor on nvc0
- Changes to package:
  + add --enable-shader-cache to configure options
  + remove Patch100: U_0001_gallium_include_util_macros.patch
  + remove Patch101: U_0002_st_nine_mark_end_of_non_void_function_unreachable.patch
  + remove Patch102: U_0003_fix_build_after_macro_include.patch
* Mon Jun  8 2015 zaitor@opensuse.org
- Update to version 10.5.7:
  + i965: Emit 3DSTATE_MULTISAMPLE before WM_HZ_OP (gen8+)
  + docs: Add sha256sums for the 10.5.6 release
  + get-pick-list.sh: Require explicit "10.5" for nominating stable patches
  + cherry-ignore: add clover build fix not applicable for 10.5
  + Add release notes for the 10.5.7 release
  + nvc0/ir: set ftz when sources are floats, not just destinations
  + nv50/ir: guess that the constant offset is the starting slot of array
  + nvc0/ir: LOAD's can't be used for shader inputs
  + nvc0: a geometry shader can have up to 1024 vertices output
  + nv50/ir: avoid messing up arg1 of PFETCH
  + nv30: don't leak fragprog consts
  + nv30: avoid leaking render state and draw shaders
  + nv30: fix clip plane uploads and enable changes
  + nv30/draw: avoid leaving stale pointers in draw state
  + nv30/draw: draw expects constbuf size in bytes, not vec4 units
  + st/mesa: don't leak glsl_to_tgsi object on link failure
  + glsl: avoid leaking linked gl_shader when there's a late linker error
  + nv30/draw: fix indexed draws with swtnl path and a resource index buffer
  + nv30/draw: only use the DMA1 object (GART) if the bo is not in VRAM
  + nv30/draw: allocate vertex buffers in gart
  + nv30/draw: switch varying hookup logic to know about texcoords
  + nv30: falling back to draw path for edgeflag does no good
  + nv30: avoid doing extra work on clear and hitting unexpected states
  + i965/fs: Fix implied_mrf_writes for scratch writes
  + st/dri: fix postprocessing crash when there's no depth buffer
* Mon May 25 2015 mimi.vx@gmail.com
- update to 10.5.6
  * fdo#86792 - [NVC0] Portal 2 Crashes in Wi* ne
  * fdo#90350 - [G96] Portal's portal are incorrectly rendered
  * fdo#90363 - [nv50] HW state is not reset correctly when using a new GL context
  * radeonsi: add new bonaire pci id
  * egl/wayland: properly destroy wayland objects
  * glx/dri3: Add additional check for gpu offloading case
  * egl/main: fix EGL_KHR_get_all_proc_addresses
  * targets/osmesa: drop the -module tag from LDFLAGS
  * clover: Refactor event::trigger and ::abort to prevent deadlock and reentrancy issues.
  * clover: Wrap event::_status in a method to prevent unlocked access.<
  * clover: Implement locking of the wait_count, _chain and _status members of event.
  * i965: Fix PBO cache coherency issue after _mesa_meta_pbo_GetTexSubImage().
  * main: Require that the texture exists in framebuffer_texture
  * mesa: Generate GL_INVALID_VALUE in framebuffer_texture when layer <0
  * nv50/ir: only propagate saturate up if some actual folding took place
  * nv50: keep track of PGRAPH state in nv50_screen
  * nvc0: keep track of PGRAPH state in nvc0_screen
  * nvc0: reset the instanced elements state when doing blit using 3d engine
  * nv50/ir: only enable mul saturate on G200+
  * st/mesa: make sure to create a "clean" bool when doing i2b
  * nvc0: switch mechanism for shader eviction to be a while loop
  * swrast: Build fix for darwin
  * main: Fix an error generated by FramebufferTexture</li>
  * main: Complete error conditions for glInvalidate*Framebuffer.
  * main: glGetIntegeri_v fails for GL_VERTEX_BINDING_STRIDE
  * freedreno: enable a306
  * freedreno: fix bug in tile/slot calculation
  * draw: (trivial) fix out-of-bounds vector initialization
  * mesa: fix shininess check for ffvertex_prog v2
  * clover: Add a mutex to guard queue::queued_events
  * clover: Fix a bug with multi-threaded events v2
* Sat May 16 2015 mimi.vx@gmail.com
- Update to 10.5.5
  * fdo#88521 - GLBenchmark 2.7 TRex renders with artifacts on Gen8 with !UXA
  * fdo#89455 - [NVC0/Gallium] Unigine Heaven black and white boxes
  * fdo#89689 - [Regression] Weston on DRM backend won't start with new version of mesa
  * fdo#90130 - gl_PrimitiveId seems to reset at 340
  * i965: Add XRGB8888 format to intel_screen_make_configs
  * r300: do not link against libdrm_intel
  * nvc0/ir: flush denorms to zero in non-compute shaders
  * gk110/ir: fix set with a register dest to not auto-set the abs flag
  * nvc0/ir: fix predicated PFETCH emission
  * nv50/ir: fix asFlow() const helper for OP_JOIN
  * i965: Make intel_emit_linear_blit handle Gen8+ alignment restrictions.
  * i965: Disallow linear blits that are not cacheline aligned.
  * draw: fix prim ids when there's no gs
* Mon May 11 2015 fstrba@suse.com
- BuildIgnore python so that it is not sucked in by coincidence
  * The python-base provides enough python functionalities
    necessary for build.
* Mon Apr 27 2015 sndirsch@suse.com
- Update to 10.5.4
  * This release includes fixes for the mesa state-tracker used by
    all the gallium drivers, a drirc workaround for Second Life,
    plus i965 fixes. For the Android users out there, this release
    includes many compilation fixes with more to come shortly.
* Thu Apr 16 2015 mimi.vx@gmail.com
- Update to 10.5.3
  + fdo#83962 - [HSW/BYT]Piglit spec_ARB_gpu_shader5_arb_gpu_shader5-emitstreamvertex_nodraw fails
  + fdo#89679 - [NV50] Portal/Half-Life 2 will not start (native Steam)
  + fdo#89746 - Mesa and LLVM 3.6+ break opengl for genymotion
  + fdo#89754 - vertexAttrib fails WebGL Conformance test with mesa drivers
  + fdo#89758 - pow WebGL Conformance test with mesa drivers
  + fdo#89759 - WebGL OGL ES GLSL conformance test with mesa drivers fails
  + fdo#89905 - scons build broken on 10.5.2 due to activated vega st
  + st_glsl_to_tgsi: only do mov copy propagation on temps (v2)
  + xmlpool: don't forget to ship the MOS
  + configure.ac: error out if python/mako is not found when required
  + dist: add the VG depedencies into the tarball
  + i965: Do not render primitives in non-zero streams then TF is disabled
  + st/mesa: update arrays when the current attrib has been updated
  + nv50/ir: take postFactor into account when doing peephole optimizations
  + nv50/ir/gk110: fix offset flag position for TXD opcode
  + freedreno/a3xx: fix 3d texture layout
  + freedreno/a3xx: point size should not be divided by 2
  + nv50: allocate more offset space for occlusion queries
  + nv50,nvc0: limit the y-tiling of 3d textures to the first level's tiling
  + i965: Fix instanced geometry shaders on Gen8+.
  + i965: Add forgotten multi-stream code to Gen8 SOL state.
  + nouveau: synchronize "scratch runout" destruction with the command stream
  + radeonsi: Cache LLVMTargetMachineRef in context instead of in screen
  + clover: Return CL_BUILD_ERROR for CL_PROGRAM_BUILD_STATUS when compilation fails v2
  + i965: Fix URB size for CHV
* Sun Mar 29 2015 mimi.vx@gmail.com
- Update to  10.5.2
  + fdo#88534 - include/c11/threads_posix.h PTHREAD_MUTEX_RECURSIVE_NP not defined
  + fdo#89328 - python required to build Mesa release tarballs
  + fdo#89530 - FTBFS in loader: missing fstat
  + fdo#89590 - Crash in glLinkProgram with shaders with multiple constant arrays
  + fdo#89680 - Hard link exist in Mesa 10.5.1 sources
  + glsl: Generate link error for non-matching gl_FragCoord redeclarations
  + docs: Add sha256 sums for the 10.5.1 release
  + automake: add missing egl files to the tarball
  + st/egl: don't ship the dri2.c link at the tarball
  + loader: include <sys/stat.h> for non-sysfs builds
  + auxiliary/os: fix the android build - s/drm_munmap/os_munmap/
  + cherry-ignore: add commit non applicable for 10.5
  + c11/threads: Use PTHREAD_MUTEX_RECURSIVE by default
  + i965: Set nr_params to the number of uniform components in the VS/GS path.
  + freedreno/a3xx: use the same layer size for all slices
  + freedreno: fix slice pitch calculations
  + radeonsi: increase coords array size for radeon_llvm_emit_prepare_cube_coords
  + glx: Handle out-of-sequence swap completion events correctly. (v2)
  + mapi: Make private copies of name strings provided by client.
  + freedreno: update generated headers
  + glsl: optimize (0 cmp x + y) into (-x cmp y).
  + glsl: fix names in lower_constant_arrays_to_uniforms
  + clover: Return 0 as storage size for local kernel args that are not set v2
* Sat Mar 14 2015 mimi.vx@gmail.com
- Update  to 10.5.1
  + fdo#79202 - valgrind errors in glsl-fs-uniform-array-loop-unroll.shader_test; random code generation
  + fdo#84613 - [G965, bisected] piglit regressions : glslparsertest.glsl2
  + fdo#86747 - Noise in Football Manager 2014 textures
  + fdo#86974 - INTEL_DEBUG=shader_time always asserts in fs_generator::generate_code() when Mesa is built with --enable-debug (= with asserts)
  + fdo#88246 - Commit 2881b12 causes 43 DrawElements test regressions
  + fdo#88793 - [BDW/BSW Bisected]Piglit/shaders_glsl-max-varyings fails
  + fdo#88883 - ir-a2xx.c: variable changed in assert statement
  + fdo#88885 - Transform feedback uses incorrect interleaving if a previous draw did not write gl_Position
  + fdo#89095 - [SNB/IVB/BYT Bisected]Webglc conformance/glsl/functions/glsl-function-mix-float.html fails
  + fdo#89156 - r300g: GL_COMPRESSED_RED_RGTC1 / ATI1N support broken
  + fdo#89224 - Incorrect rendering of Unigine Valley running in VM on VMware Workstation
  + fdo#89292 - [regression,bisected] incomplete screenshots in some cases
  + fdo#89311 - [regression, bisected] dEQP: Added entry points for glCompressedTextureSubImage*D.
  + fdo#89312 - [regression, bisected] main: Added entry points for CopyTextureSubImage*D. (d6b7c40cecfe01)
  + fdo#89315 - [HSW, regression, bisected] i965/fs: Emit MAD instructions when possible.
  + fdo#89317 - [HSW, regression, bisected] i965: Add LINTERP/CINTERP to can_do_cmod() (d91390634)
  + fdo#89416 - UE4Editor crash after load project
  + fdo#89430 - [g965][bisected] arb_copy_image-targets gl_texture* tests fail
  + i965/vec4: Don't lose the saturate modifier in copy propagation.
  + i965/gs: Check newly-generated GS-out VUE map against correct stage
  + egl: Take alpha bits into account when selecting GBM formats
  + docs: Add sha256 sums for the 10.5.0 release
  + egl/main: no longer export internal function
  + cherry-ignore: ignore a few more commits picked without -x
  + mapi: fix commit 90411b56f6bc817e229d8801ac0adad6d4e3fb7a
  + intel: fix EGLImage renderbuffer _BaseFormat
  + i965: Fix out-of-bounds accesses into pull_constant_loc array
  + i965/fs/nir: Use emit_math for nir_op_fpow
  + freedreno: move fb state copy after checking for size change
  + freedreno/ir3: fix array count returned by TXQ
  + freedreno/ir3: get the # of miplevels from getinfo
  + meta/TexSubImage: Stash everything other than PIXEL_TRANSFER/store in meta_begin
  + main/base_tex_format: Properly handle STENCIL_INDEX1/4/16
  + i965: Split Gen4-5 BlitFramebuffer code; prefer BLT over Meta.
  + glsl: Mark array access when copying to a temporary for the ?: operator.
  + i965/fs: Set force_writemask_all on shader_time instructions.
  + i965/fs: Set smear on shader_time diff register.
  + i965/fs: Make emit_shader_time_write return rather than emit.
  + i965/fs: Make get_timestamp() pass back the MOV rather than emitting it.
  + i965/fs: Make emit_shader_time_end() insert before EOT.
  + i965/fs: Don't issue FB writes for bound but unwritten color targets.
  + main: Fix target checking for CompressedTexSubImage*D.
  + main: Fix target checking for CopyTexSubImage*D.
  + gallium/auxiliary/indices: fix start param
  + r300g: fix RGTC1 and LATC1 SNORM formats
  + r300g: fix a crash when resolving into an sRGB texture
  + r300g: fix sRGB->sRGB blits
  + i965/vec4: Fix implementation of i2b.
  + mesa: Indent break statements and add a missing one.
  + mesa: Free memory allocated for luminance in readpixels.
  + mesa: Correct backwards NULL check.
  + i965: Consider scratch writes to have side effects.
  + i965/fs: Don't use backend_visitor::instructions after creating the CFG.
  + r300g: Use PATH_MAX instead of limiting ourselves to 100 chars.
  + r300g: Check return value of snprintf().
  + i965/fs: Don't propagate cmod to inst with different type.
  + i965: Tell intel_get_memcpy() which direction the memcpy() is going.
  + Revert SHA1 additions.
  + i965: Avoid applying negate to wrong MAD source.
  + meta: In pbo_{Get,}TexSubImage don't repeatedly rebind the source tex
  + Revert "common: Fix PBOs for 1D_ARRAY."
  + meta: Allow GL_UN/PACK_IMAGE_HEIGHT in _mesa_meta_pbo_Get/TexSubImage
  + meta: Fix the y offset for 1D_ARRAY in _mesa_meta_pbo_TexSubImage
  + freedreno/ir3: fix silly typo for binning pass shaders
  + freedreno/a2xx: fix increment in assert
  + freedreno/a4xx: bit of cleanup
  + freedreno: update generated headers
  + freedreno/a4xx: set PC_PRIM_VTX_CNTL.VAROUT properly
  + freedreno: update generated headers
  + freedreno/a4xx: aniso filtering
  + freedreno/ir3: fix up cat6 instruction encodings
  + freedreno/ir3: add support for memory (cat6) instructions
  + freedreno/ir3: handle flat bypass for a4xx
  + freedreno/ir3: fix failed assert in grouping
  + r300g: Fix the ATI1N swizzle (RGTC1 and LATC1)
* Sat Mar  7 2015 tobias.johannes.klausmann@mni.thm.de
- Update to version 10.5.0:
  + Initial support for the new Intel Skylake GPUs and Adreno 4xx
    GPUs.
  + Experimental EGL support for Haiku.
  + The new IR - NIR. A flat, typeless IR, supporting SSA.
  + GLX/DRI3 fixes and improvements.
  + A lot of preparation work for GL_ARB_direct_state_access.
  + The usual amount of piglit and drawElements Quality Program
    (dEQP) fixes.
  + Building mesa with GCC 4.1 or earlier is no longer supported.
  + The distribution tarball has been renamed and now contains all
    the generated sources.
- New GL features:
  + GL_ARB_framebuffer_sRGB on freedreno
  + GL_ARB_texture_rg on freedreno
  + GL_EXT_packed_float on freedreno
  + GL_EXT_polygon_offset_clamp on i965, nv50, nvc0, r600, radeonsi,
    llvmpipe
  + GL_EXT_texture_shared_exponent on freedreno
  + GL_EXT_texture_snorm on freedreno
- Changes to Package:
  + switch to xz compressed sources
  + remove Patch16: u_gallivm_Update_for_RTDyldMemoryManager_unique_ptr.patch
  + add Patch100: U_0001_gallium_include_util_macros.patch
  + add Patch101: U_0002_st_nine_mark_end_of_non_void_function_unreachable.patch
  + add Patch102: U_0003_fix_build_after_macro_include.patch
* Mon Mar  2 2015 idonmez@suse.com
- Add u_gallivm_Update_for_RTDyldMemoryManager_unique_ptr.patch to
  fix build with llvm 3.6 (fdo#86958)
* Tue Feb 24 2015 tobias.johannes.klausmann@mni.thm.de
- Fix file permissions for the Gallium Nine files
* Mon Feb 23 2015 sndirsch@suse.com
- specfile/baselibs.conf: Manually provide d3d library (bnc#918294)
* Tue Feb 10 2015 zaitor@opensuse.org
- Drop pkgconfig(libva) BuildRequires for now, as it introduces a
  build-cycle.
* Sun Feb  8 2015 zaitor@opensuse.org
- Update to version 10.4.4:
  + mesa: fix display list 8-byte alignment issue.
  + docs: Add sha256 sums for the 10.4.3 release.
  + egl: Pass the correct X visual depth to xcb_put_image().
  + glx/dri3: Request non-vsynced Present for swapinterval zero.
  + gallium/util: Don't use __builtin_clrsb in util_last_bit().
  + configure: Link against all LLVM targets when building clover.
  + st/osmesa: Fix osbuffer->textures indexing.
  + i965: Fix max_wm_threads for CHV.
  + Bugs fixed: fdo#88662, fdo#88930.
- Add pkgconfig(libva) BuildRequires: Build VA API support.
* Mon Feb  2 2015 sndirsch@suse.com
- baselibs.conf: enabled build of 32bit Mesa-libd3d package
  (bnc#910109)
* Thu Jan 29 2015 sndirsch@suse.com
- moved definition of Mesa-libd3d package above definition of
  libxatracker packages in order to fix version requires
* Wed Jan 28 2015 sndirsch@suse.com
- fixed Requires for libd3d-devel
* Tue Jan 27 2015 sndirsch@suse.com
- enabled build of Direct3D 9 (Gallium3D Nine) state tracker (bnc#910109)
- removed obsolete patch u_be_assert_include.patch, addressed by
  upstream commit 2a13ff9 "gallium/util: add missing u_debug include"
  (bnc#910109)
* Tue Jan 27 2015 schwab@suse.de
- Set xvmc_support also on ppc
* Sun Jan 25 2015 mimi.vx@gmail.com
- Version bump to 10.4.3 (bugfix release):
  * Bug 80568 - [gen4] GPU Crash During Google Chrome Operation
  * Bug 85367 - [gen4] GPU hang in glmark-es2
  * Bug 85696 - r600g+nine: Bioshock shader failure after 7b1c0cbc90d456384b0950ad21faa3c61a6b43ff
  * Bug 88219 - include/c11/threads_posix.h:197: undefined reference to `pthread_mutex_lock'
  * mesa: Fix clamping to -1.0 in snorm_to_float
  * glsl: Link glsl_test with pthreads library.
  * i965: Respect the no_8 flag on Gen6, not just Gen7+.
  * i965: Work around mysterious Gen4 GPU hangs with minimal state changes.
* Fri Jan 16 2015 tchvatal@suse.com
- Clean up with the spec-cleaner
- Drop obsolete obsoletes comming from fix for sle10
- Reduce llvm_r600 conditional as it is equal to ifarch x86 x86_64
- Put vdpau_radeon and vdpau_nouveau under same case as they have
  same requisites
- Fix empty post/postun warning
- Various other rpmlint issues silenced.
* Fri Jan 16 2015 tchvatal@suse.com
- Version bump to 10.4.2 (bugfix release):
  * Bug 85529 - Surfaces not drawn in Unvanquished
  * Bug 87619 - Changes to state such as render targets change fragment shader without marking it dirty.
  * Bug 87658 - [llvmpipe] SEGV in sse2_has_daz on ancient Pentium4-M
  * Bug 87913 - CPU cacheline size of 0 can be returned by CPUID leaf 0x80000006 in some virtual machines
  * i965: Use safer pointer arithmetic in intel_texsubimage_tiled_memcpy()
  * i965: Use safer pointer arithmetic in gather_oa_results()
  * Revert "r600g/sb: fix issues cause by GLSL switching to loops for switch"
  * r600g: fix regression since UCMP change
  * r600g/sb: implement r600 gpr index workaround. (v3.1)
  * docs: Add sha256 sums for the 10.4.1 release
  * Update version to 10.4.2
  * nv50,nvc0: set vertex id base to index_bias
  * nv50/ir: fix texture offsets in release builds
  * i965: Add missing BRW_NEW_*_PROG_DATA to texture/renderbuffer atoms.
  * i965: Fix start/base_vertex_location for >1 prims but !BRW_NEW_VERTICES.
  * gallium/util: make sure cache line size is not zero
  * glsl_to_tgsi: fix a bug in copy propagation
  * vbo: ignore primitive restart if FixedIndex is enabled in DrawArrays
  * st/mesa: fix GL_PRIMITIVE_RESTART_FIXED_INDEX
  * radeonsi: fix VertexID for OpenGL
  * radeonsi: Don't modify PA_SC_RASTER_CONFIG register value if rb_mask == 0
  * gallium/util: fix crash with daz detection on x86
  * nv50,nvc0: implement half_pixel_center
  * r600g/sb: fix issues with loops created for switch
- Use download url fully in Source line
* Sun Dec 14 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 10.4.0 (10.4 Final):
- New features:
  + GL_ARB_conditional_render_inverted on nv50
  + GL_ARB_sample_shading on r600
  + GL_ARB_texture_view on nv50, nvc0
  + GL_ARB_clip_control on nv50, nvc0, r300, r600, radeonsi, llvmpipe, softpipe
  + GL_KHR_context_flush_control on all drivers
- Changes:
  + Removed patch17: u_Suppress-any-libGL-.-warnings-when-LIBGL_DEBUG-is-se.patch
    This patch was upstreamed
  + Build without "--enable-gallium-egl"
    This buildoption was removed upstream
  + Add subpackage libvdpau_r300
* Sun Nov 16 2014 afaerber@suse.de
- Enable VideoCore IV (vc4) support for ARM
* Fri Nov 14 2014 tobias.johannes.klausmann@mni.thm.de
- Cleanup Spec:
  + smaller cleanups
  + Remove all traces of talloc, Mesa uses ralloc
* Fri Nov 14 2014 seanpwatson@live.com
- Update to 10.3.3
  + fdo#82921 layout(location=0) emits error
  >= MAX_UNIFORM_LOCATIONS due to integer underflow
  + fdo#83574 [llvmpipe] [softpipe] piglit
  arb_explicit_uniform_location-use-of-unused-loc regression
  + fdo#85454 Unigine Sanctuary with Wine crashes on Mesa Git
  + fdo#70410 egl-static/Makefile: linking fails with llvm >= 3.4
* Tue Nov  4 2014 seanpwatson@live.com
- Update to 10.3.2
  + (fdo#54372) GLX_INTEL_swap_event crashes driver when swapping
  window buffers
  + (fdo#81680) [r600g] Firefox crashes with hardware acceleration
  turned on
  + (fdo#84140) mplayer crashes playing some files using vdpau
  output
  + (fdo#84662) Long pauses with Unreal demo Elemental on R9270X
  since : Always flush the HDP cache before submitting a
    CS to the GPU
  + (fdo#85267) vlc crashes with vdpau (Radeon 3850HD) [r600]
* Thu Oct 30 2014 jengelh@inai.de
- Update descriptions and Requires for GLES3
* Sat Oct 25 2014 josua.mayer97@gmail.com
- add Mesa-devel-dri package:
  This way dri.pc will no longer pull in all of Mesa, just as
  packages requiring dri do not have to require Mesa-devel anymore
* Mon Oct 13 2014 seanpwatson@live.com
- Update to 10.3.1
  + [NVC0/Codegen] Shader compilation falis in spill logic
  + [SNB+ Bisected]Ogles3conform ES3-CTS.shaders.
    indexing.vector_subscript.vec3_static_loop_subscript_write_
    direct_read_vertex fails
  + [UBO] row_major layout ignored inside structures
  + [UBO] nested structures don't get appropriate padding
  + Glyphy demo throws unhandled Integer division by zero exception
  + [UBO] row_major layout partially ignored for arrays of structures
  + Big glamor regression in Xorg server 1.6.99.1 GIT: x11perf 1.5
    Test: PutImage XY 500x500 Square
* Thu Sep 25 2014 dvaleev@suse.com
- Fix ppc64 build (bnc#893275 bnc#871128)
  u_be_assert_include.patch
  Add ncurses-devel as build dependency to build with -ltinfo
- Enable llvm on ppc64le (llvm3.5 got ppc64le support)
- Enable shared on ppc64 and ppc64le
* Sat Sep 20 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 10.3.0 (10.3 Final):
- New features:
  + GL_ARB_ES3_compatibility on nv50, nvc0, r600, radeonsi, softpipe, llvmpipe
  + GL_ARB_clear_texture on i965
  + GL_ARB_compressed_texture_pixel_storage on all drivers
  + GL_ARB_conditional_render_inverted on i965, nvc0, softpipe, llvmpipe
  + GL_ARB_derivative_control on i965, nv50, nvc0, r600
  + GL_ARB_draw_indirect on nvc0, radeonsi
  + GL_ARB_explicit_uniform_location (all drivers that support GLSL)
  + GL_ARB_fragment_layer_viewport on nv50, nvc0, llvmpipe, r600
  + GL_ARB_gpu_shader5 on i965/gen7, nvc0
  + GL_ARB_multi_draw_indirect on nvc0, radeonsi
  + GL_ARB_sample_shading on radeonsi
  + GL_ARB_seamless_cubemap_per_texture on i965, llvmpipe, nvc0, r600, radeonsi, softpipe
  + GL_ARB_stencil_texturing on nv50, nvc0, r600, and radeonsi
  + GL_ARB_texture_barrier on nv50, nvc0, r300, r600, radeonsi
  + GL_ARB_texture_compression_bptc on i965/gen7+, nvc0, r600/evergreen+, radeonsi
  + GL_ARB_texture_cube_map_array on radeonsi
  + GL_ARB_texture_gather on r600, radeonsi
  + GL_ARB_texture_query_levels on nv50, nvc0, llvmpipe, r600, radeonsi, softpipe
  + GL_ARB_texture_query_lod on r600, radeonsi
  + GL_ARB_viewport_array on nvc0
  + GL_AMD_vertex_shader_viewport_index on i965/gen7+, r600
  + GL_OES_compressed_ETC1_RGB8_texture on nv30, nv50, nvc0, r300, r600, radeonsi, softpipe, llvmpipe
  + GLX_MESA_query_renderer on nv30, nv50, nvc0, r300, r600, radeonsi, softpipe, llvmpipe
  + A new software rasterizer driver (kms_swrast_dri.so) that works with DRM drivers that don't have a full-fledged GEM (such as qxl or simpledrm)
- Changes:
  Building of gallium-pipe disabled for now by upstream, see:
  http://cgit.freedesktop.org/mesa/mesa/commit/?h=10.3&id=07426ad1029c3505b809dc9eec104007fb623983
  Nevertheless keep it around as it may get enabled again.
* Mon Aug 25 2014 sndirsch@suse.com
- Update to version 10.3.0-RC1
  * Mesa 10.3 brings many performance improvements, more
    OpenGL 4.x functionality, the VC4 Gallium3D driver,
    and much more.
  * supersedes U_mesa-glx-Reduce-error-log-level.patch
* Sun Aug 24 2014 dvlaeev@suse.com
- Package vdpau_r600 for ppc64le as well (bnc#893275)
* Fri Aug 22 2014 sndirsch@suse.com
- u_Suppress-any-libGL-.-warnings-when-LIBGL_DEBUG-is-se.patch
  Suppress any "libGL:..." warnings when LIBGL_DEBUG == "quiet"
  (bnc#892896)
* Fri Aug 15 2014 sndirsch@suse.com
- no longer add /usr/%%{_lib}/dri/updates to DRI driver search path
  (FATE#317822)
* Thu Aug  7 2014 sndirsch@suse.com
- Update to version 10.2.5
  * Mesa 10.2.5 is a bug fix release which fixes bugs fixed since
    the 10.2.4 release
* Tue Jul 29 2014 tiwai@suse.de
- Reduce error log level for annoying dlopen messages (bnc#889391)
  U_mesa-glx-Reduce-error-log-level.patch
* Mon Jul 21 2014 sndirsch@suse.com
- Update to version 10.2.4
  * Mesa 10.2.4 is a bug fix release which fixes bugs fixed since
    the 10.2.3 release
* Wed Jul  9 2014 sndirsch@suse.com
- Update to version 10.2.3
  * Mesa 10.2.3 is a bug fix release which fixes bugs fixed since
    the 10.2.2 release
- obsoletes u_mesa-gallium-llvmpipe-fix-SIGFPE.patch
* Sun Jun  8 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 10.2.1
- Mesa 10.2.1 is an emergency release to fix a build failure added
  to 10.2 between 10.2-rc5 and the final release.
- Mesa 10.2 is a feature release that includes many updates and
  enhancements. The full list is available in the release notes
  file in docs/relnotes/10.2.html.
* Wed Jun  4 2014 sndirsch@suse.com
- Update to version 10.2-rc5
  Another round of bugfixes towards the final 10.2
* Tue May 27 2014 tiwai@suse.de
- Fix zero-division with empty height (bnc#879462)
  u_mesa-gallium-llvmpipe-fix-SIGFPE.patch
* Mon May 26 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 10.2-rc4:
  Another round of bugfixes towards the final 10.2
* Mon May 19 2014 tobias.johannes.klausmann@mni.thm.de
- Update to 10.2-rc3
  Even more bugfixes
* Mon May 12 2014 schwab@suse.de
- no shared llvm libs on ppc64
- vdpau no longer enabled by default
- xa or gallium-gbm implies gallium-loader
* Sat May 10 2014 tobias.johannes.klausmann@mni.thm.de
- Update to 10.2-rc2:
  More bugfixes
* Sat May  3 2014 tobias.johannes.klausmann@mni.thm.de
- Update to 10.2-rc1:
- Remove U_gallium_util_add_missing_u_math_include.patch (patch27)
- Remove U_nouveau_create_only_one_shared_screen.patch (patch28)
- Remove U_nouveau_add_valid_range_tracking.patch (patch29)
- Remove U_nouveau_fix_fence_waiting_logic.patch (patch30)
* Fri Apr 25 2014 tobias.johannes.klausmann@mni.thm.de
- Add missing BuildRequires, remove old xorg-x11-*-devel packages
* Mon Apr  7 2014 schwab@suse.de
- Include XA tracker sub packages on s390x
* Mon Mar 31 2014 schwab@suse.de
- Clean up specfile
- Turn negative arch checks into positive ones for non-default configure
  settings
- libxsmfence is also available on ppc64le
- Don't enable gallium-egl on ppc64 for now to work around llvm bug
* Thu Mar 13 2014 tobias.johannes.klausmann@mni.thm.de
- Add U_gallium_util_add_missing_u_math_include.patch (patch27)
- Add U_nouveau_create_only_one_shared_screen.patch (patch28)
- Add U_nouveau_add_valid_range_tracking.patch (patch29)
- Add U_nouveau_fix_fence_waiting_logic.patch (patch30)
  + https://bugzilla.novell.com/show_bug.cgi?id=866445
  + https://bugs.freedesktop.org/show_bug.cgi?id=75279
* Wed Mar  5 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 10.1:
- New features:
  + GL_ARB_draw_indirect on i965.
  + GL_ARB_clear_buffer_object
  + GL_ARB_viewport_array on i965.
  + GL_ARB_map_buffer_alignment on all drivers that did not previously
    support it.
  + GL_AMD_shader_trinary_minmax.
  + GL_EXT_framebuffer_blit on r200 and radeon.
  + Reduced memory usage for display lists.
  + OpenGL 3.3 support on nv50, nvc0, r600 and radeonsi
- Changes:
  + Removed support for the GL_MESA_texture_array extension.
* Tue Feb  4 2014 sndirsch@suse.com
- Update to version 10.0.3
  * Mesa 10.0.3 is a bug fix release which fixes bugs fixed since
    the 10.0.2 release
* Wed Jan 15 2014 afaerber@suse.de
- Enable freedreno gallium driver (Qualcomm Adreno)
* Mon Jan 13 2014 sndirsch@suse.com
- Update to version 10.0.2
  * Mesa 10.0.2 is a bug fix release which fixes bugs fixed since
  the 10.0.1 release.
* Tue Dec 17 2013 schwab@suse.de
- Make proper use of %%build and %%install
- Use verbose make rules
* Mon Dec 16 2013 schwab@suse.de
- Fix filelist: /etc/drirc is now always installed
* Sat Dec 14 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 10.0.1:
  This version of Mesa fixes the regression that Mesa 10.0 could not
  be loaded by any released version of the X server.
* Fri Dec  6 2013 adrian@suse.de
- disable llvm support for ppc64le, llvm does not support ppc64le
* Mon Dec  2 2013 sndirsch@suse.com
- disable the build of egl-wayland support on openSUSE 12.3, since
  Mesa 10.0 requires a higher wayland version than we have on
  openSUSE 12.3
* Wed Nov 27 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 10.0.0:
  Mesa 10.0 has been released! Mesa 10.0 is a feature release that
  includes many updates and enhancements. The full list is available in
  the release notes file in docs/relnotes/10.0.html.
- Remove libXvMC_{r300,softpipe} packages
- Remove libvdpau_{r300,softpipe} packages
- Bump libxatracker package version
* Sat Nov 16 2013 hrvoje.senjan@gmail.com
- Update to version 9.2.3
  * st/mesa: move out of memory check in st_draw_vbo()
  * osmesa: fix broken triangle/line drawing when using float
  color buffer
  * Remove error when calling glGenQueries/glDeleteQueries while
  a query is active
  * Bump version to 9.2.3
  * i965: CS writes/reads should use I915_GEM_INSTRUCTION
  * i965: Fix texture buffer rendering after a whole buffer
  replacement.
  * i965: Emit post-sync non-zero flush before
  3DSTATE_GS_SVB_INDEX.
  * i965: Emit post-sync non-zero flush before
  3DSTATE_DRAWING_RECTANGLE.
  * i965: Also guard 3DSTATE_DRAWING_RECTANGLE with a
  flush in blorp.
  * i965: Move post-sync non-zero flush for 3DSTATE_MULTISAMPLE.
  * i965: Also emit HIER_DEPTH and STENCIL packets when
  disabling depth.
  * i965: Also emit HiZ and Stencil packets when
  disabling depth on Gen6.
  * wayland: Don't rely on static variable for
  identifying wl_drm buffers
  * radeonsi: fix blitting the last 2 mipmap levels of
  compressed textures
  * meta: enable vertex attributes in the context of the
  newly created array object
  * mesa: fixes for MSVC 2013
* Tue Nov 12 2013 schwab@suse.de
- Add support for m68k
* Fri Oct 25 2013 sndirsch@suse.com
- no longer install install libvdpau_r300 subpackage by default and
  update descriptions of libvdpau_{nouveau,r600,radeonsi,softpipe}
  subpackages (bnc#847269)
* Thu Oct 24 2013 sndirsch@suse.com
- install libvdpau_{nouveau,r300,r600,radeonsi} package on
  appropriate hardware by default (bnc#847269)
* Sat Oct 19 2013 hrvoje.senjan@gmail.com
- Update to version 9.2.2
  * Valgrind error in program_resource_visitor::recursion, (fdo#69449)
  * glInvalidateFramebuffer fails with GL_INVALID_ENUM (fdo#70411)
  * svga: fix incorrect memcpy src in svga_buffer_upload_piecewise()
  * mesa: consolidate cube width=height error checking
  * mesa: Add missing switch break in invalidate_framebuffer_storage()
  * i965: Don't forget the cube map padding on gen5+.
  * mesa: Fix compiler warnings when ALIGN's alignment is "1 << value".
  * i965: Fix 3D texture layout by more literally copying from the spec.
  * glsl: Fix usage of the wrong union member in
  program_resource_visitor::recursion.
  * radeonsi: Use 'SI' as the LLVM processor for CIK on LLVM <= 3.3
* Sat Oct  5 2013 hrvoje.senjan@gmail.com
- Update to version 9.2.1
  * Use of uninitialized stack variable with brw_search_cache()
  (fdo#66779)
  * Valgrind errors in mesa (fdo#68233)
  * Automatic mipmap generation with texture compression produces
  borders that fade to black (fdo#68250)
  * Unigine demo crash (fdo#68637)
  * GLSL ES: structs members can't have precision qualifiers
  anymore in 9.2 (fdo#68753)
  * Piglit tex-shadow2drect fails (fdo#69525)
- Dropped U_radeon-winsys-pad-IBs-to-a-multiple-of-8-DWs.patch,
  U_wayland-egl-pc-require-wayland.patch and
  u_gallium-egl-gbm-use-wayland-cflags.patch they are included in
  this release
* Mon Sep 23 2013 idonmez@suse.com
- Enable llvmpipe on PPC64
* Fri Sep 20 2013 sndirsch@suse.com
- Disable u_mesa-8.0-llvmpipe-shmget.patch,
  u_mesa-8.0.1-fix-16bpp.patch since these are considered wrong by
  the author
- remove libIndirectGL (packages), since it is most likely no
  longer used by anyone ...
- use --enable-osmesa, since we no longer have this extra build
  for libIndirectGL
* Tue Sep 17 2013 hrvoje.senjan@gmail.com
- Added U_radeon-winsys-pad-IBs-to-a-multiple-of-8-DWs.patch from
  upstream -- aligns the gfx, compute, and dma IBs to 8 DW boundries.
  Additionally, r6xx hardware requires at least 4
  DW alignment to avoid a hw bug.  This also aligns the DMA
  IBs to 8 DW which is required for the DMA engine.
* Mon Sep 16 2013 sndirsch@suse.com
- updated to latest available version of
  * u_mesa-8.0-llvmpipe-shmget.patch
  * u_mesa-8.0.1-fix-16bpp.patch
  and applying it now in the opposite order.
* Fri Sep 13 2013 duwe@suse.com
- wayland-egl-pc-require-wayland is now mainline
* Thu Sep 12 2013 schwab@suse.de
- drirc is only installed if there are hardware DRI drivers
* Tue Sep 10 2013 tobias.johannes.klausmann@mni.thm.de
- Remove custom drirc, ship the upstream drirc
* Tue Sep 10 2013 tobias.johannes.klausmann@mni.thm.de
- Drop upstreamed patches as proposed by Johannes Obermayr:
  + Patch14: u_mesa-glapi_dispatch.patch
    Upstream: http://cgit.freedesktop.org/mesa/mesa/commit/?id=5ea43e6
  + Patch17: u_mesa-9.0-i965-Make-sure-we-do-render-between-two-hiz-flushes.patch
    Upstream: http://cgit.freedesktop.org/mesa/mesa/commit/?id=1dfea55
* Mon Sep  9 2013 duwe@suse.com
- u_wayland-egl-pc-require-wayland.patch: after finding wayland
  for egl, make sure its pkconfig is used as well.
* Fri Aug 30 2013 idonmez@suse.com
- Enable llvmpipe and xa on s390x
* Tue Aug 27 2013 tobias.johannes.klausmann@mni.thm.de
- Update to final version 9.2:
  Mesa 9.2 has been released! Mesa 9.2 is a feature release that includes
  many updates and enhancements.
- New features:
  + GL_ARB_shading_language_420pack in all drivers that support GLSL 1.30.
  + GL_ARB_texture_buffer_range
  + GL_ARB_texture_multisample
  + GL_ARB_texture_storage_multisample
  + GL_ARB_texture_query_lod
  + Enable GL_ARB_texture_storage on radeon, r200, and nouveau
  + GL_EXT_discard_framebuffer in all OpenGL ES (all versions) drivers
  + GL_EXT_framebuffer_multisample_blit_scaled on i965
  + Added new freedreno gallium driver
  + OSMesa interface for gallium llvmpipe/softpipe drivers
  + Gallium Heads-Up Display (HUD) feature for performance monitoring
  + Added support for UVD (2.2 and 3.0) video decoding on r600g and radeonsi
    through VDPAU (requires Kernel 3.10 or later)
- Changes:
  + Removed d3d1x state tracker (unused, unmaintained and broken)
  + Removed GL_EXT_clip_volume_hint because no driver had enabled it since 2007.
  + Removed GL_MESA_resize_buffers because it was only really implemented by the
    (unsupported) GDI driver.
  + GL_EXT_separate_shader_objects has been removed from all Gallium drivers,
    because it disallows a critical GLSL shader optimization.
    GL_ARB_separate_shader_objects doesn't have this issue.
  + i965 Gen6+ requires Kernel 3.6 or later. (92d2f5a)
* Fri Aug 23 2013 hrvoje.senjan@gmail.com
- Stop versioning libgbm1/devel and libwayland-egl/devel by itself,
  they now follow general Mesa version
* Fri Aug 23 2013 hrvoje.senjan@gmail.com
- Fix baselibs from previous change (there is no Mesa-libEGL1-devel),
  but Mesa-libEGL-devel
* Fri Aug 23 2013 hrvoje.senjan@gmail.com
- Update to 9.2 rc2
  * Documentation, glsl and buildsystem fixes since rc1
- baselibs.conf cleanup: adjusted to current spec
* Tue Aug 20 2013 hrvoje.senjan@gmail.com
- Update to 9.2 rc1
  * bugfixes over previous snapshot
* Tue Aug 13 2013 dmueller@suse.com
- fix build on armv7
* Mon Aug 12 2013 hrvoje.senjan@gmail.com
- Update to new snapshot from 9.2 branch:
  * various bugfixes since the previous snapshot
  * i965 Gen6+ requires Kernel 3.6 or later
  * Added support for UVD (2.2 and 3.0) video decoding on r600g and
  radeonsi through VDPAU (requires Kernel 3.10 or later)
* Thu Aug  8 2013 schwab@suse.de
- Don't enable gallium-egl without Gallium
- Enable llvm_r600 only on %%ix86 x86_64
* Mon Jul 29 2013 sndirsch@suse.com
- Make a symlink to libGL.so.1.2 for compatibility (bnc#809359,
  bnc#831306)
- u_mesa-9.0-i965-Make-sure-we-do-render-between-two-hiz-flushes.patch
  * Prevent hangs with rc6. (bnc#804910, bnc#831306)
* Thu Jul 25 2013 dvaleev@suse.com
- adjust filelist so powerpc build could succeed
- disable llvm_r600 for powerpc for now.
* Wed Jul 17 2013 sndirsch@suse.com
- The llvm with the R600 backend is finally in Factory, lets use it :)
* Fri Jul  5 2013 hrvoje.senjan@gmail.com
- Update to 9.2 snapshot:
  * New features:
  * Mesa 9.2 implements the OpenGL 3.1 API - OpenGL 3.1 is only
  available if requested at context creation because
  GL_ARB_compatibility is not supported
  * GL_ARB_texture_buffer_range
  * GL_ARB_texture_multisample
  * GL_ARB_texture_storage_multisample
  * GL_ARB_texture_query_lod
  * Enable GL_ARB_texture_storage on radeon, r200, and nouveau
  * Added new freedreno gallium driver
  * OSMesa interface for gallium llvmpipe/softpipe drivers
  * Gallium Heads-Up Display (HUD) feature for performance monitoring
  * Changes:
  * Removed d3d1x state tracker (unused, unmaintained and broken)
  * Removed GL_EXT_clip_volume_hint because no driver had enabled
  it since 2007.
  * Removed GL_MESA_resize_buffers because it was only really
  implemented by the (unsupported) GDI driver.
  * GL_EXT_separate_shader_objects has been removed from all Gallium
  drivers, because it disallows a critical GLSL shader optimization.
  GL_ARB_separate_shader_objects doesn't have this issue.
- Unlock radeonsi libvdpau
- Enable gallium egl
- added U_gallium-egl-gbm-use-wayland-cflags.patch, needed so gbm
  uses pkgconfig flags, instead of relying on "common" wayland dir
- Added llvm_r600 define, for enableing llvm shared-libs and
  r600-llvm-compiler. Off for now, until we have fixed llvm
* Tue Jul  2 2013 hrvoje.senjan@gmail.com
- Update to Mesa 9.1.4:
  * [bisected i965] Bus error (core dumped) on oglc texdecaltile
  (fdo#37871)
  * egl/opengles1/tri_x11 renders wrong (fdo#42182)
  * [SNB IVB HSW] mesa demo test texleak bus error (fdo#44958)
  * [snb] crash in texsubimage to a large atlas in clutter
  (fdo#53494)
  * glDrawElements segfault when compiled into display list
  (fdo#60518)
  * src/mesa/drivers/dri/common/xmlpool.h:96:29: fatal error:
  xmlpool/options.h (fdo#61821)
  * r300g regression (RV380): Strange rendering of light sources in
  Penumbra (bisected) (fdo#63520)
  * [HSW] support new haswell graphics [8086:0a2e] (fdo#63701)
  * [gm45, bisected] some piglit glsl 1.10 built-in-functions tests
  crash (fdo#64727)
  * [llvmpipe] SIGSEGV src/gallium/state_trackers/glx/xlib/glx_api.c:1374
  (fdo#64745)
  * [llvmpipe] SIGSEGV src/gallium/state_trackers/glx/xlib/glx_api.c:1363
  (fdo#64934)
  * segfault in _mesa_get_format_datatype and _mesa_get_color_read_type
  when state dumping with glretrace (fdo#65173)
- Droped llvm-3.3.patch, it's included in this release
* Tue May 28 2013 mhrusecky@suse.com
- fixed compilation against latest lvm: llvm-3.3.patch
* Tue May 21 2013 hrvoje.senjan@gmail.com
- update to Mesa 9.1.3:
  * Second Life viewers from release 2.7.4.235167 to the last
  3.4.0.264911 crash on start. (fdo#39251)
  * [wine] GLX_DONT_CARE does not work for GLX_DRAWABLE_TYPE or
  GLX_RENDER_TYPE (fdo#47478)
  * [SNB bisected] SNB hang with rc6 and hiz on glxgears
  (and other GL apps) immediately after xinit. (fdo#56416)
  * [GLSL1.40 IVB/HSW]Piglit spec/glsl-1.40/compiler_built-in-functions/inverse-mat2.frag
  fails (fdo#57436)
  * [ivb] Mesa 9.1 performance regression on KWin's Lanczos
  shader (fdo#61554)
  * abort is an incredibly not-smart way to handle IR validation
  (fdo#61773)
  * solaris build broken with missing ffsll (fdo#62868)
  * glXChooseFBConfig with GLX_DRAWABLE_TYPE, GLX_DONT_CARE fails
  (fdo#62999)
  * EGL X11 Regression: Maximum swap interval is 0 (worked with 9.0)
  (fdo#63078)
  * [i965 Bisected]Ogles1conform/Ogles2conform/Ogles3conform cases
  segfault (fdo#63447)
  * [SNB 9.1 Bisected]Ogles2conform GL2ExtensionTests/depth_texture_cube_map/depth_texture_cube_map.test
  fail (fdo#64662)
* Thu May  2 2013 hrvoje.senjan@gmail.com
- update to Mesa 9.1.2:
  * [965gm] green artifacts when using GLSL in XBMC (fdo#44567)
  * many new symbols in libxatracker after recent automake work
  (fdo#59238)
  * [SNB/IVB/HSW Bisected]Oglc draw-buffers2(advanced.blending.none)
  segfault (fdo#59445)
  * [i965 Bisected]Oglc fbblit(advanced.blitFb-3d-cube.mirror.both)
  fails (fdo#59495)
  * [r300g] Unigine Heaven 3.0: all objects are black (fdo#60503)
  * Firefox 18.0.2 Crash On Nvidia GeForce2 (fdo#60510)
  * [SNB Bisected] kwin_gles screen corruption (fdo#61197)
  * [IVB] corrupt rendering with UBOs (fdo#61317)
  * glEdgeFlag can't be set to false (fdo#61395)
  * nullpointer dereference causes xorg-server segfault when nouveau
  DRI driver is loaded (fdo#61947)
  * llvmpipe: Fragment Shader with "return" in main causes back
  output (fdo#62357)
  * other bugfixes
- Drop u_remove-os-abi-tag.patch, fdo#26663 is fixed with this release
* Wed Apr  3 2013 dmueller@suse.com
- do not build x86* specific drivers on ARM, only enable
  nouveau,swrast,svga for ARM platforms
* Wed Apr  3 2013 coolo@suse.com
- fix baselibs.conf
* Thu Mar 21 2013 dvaleev@suse.com
- Don't enable xa on ppc and ppc64
- Fix glapi_dispatch #bfo56710 (u_mesa-glapi_dispatch.patch)
* Wed Mar 20 2013 hrvoje.senjan@gmail.com
- update to Mesa 9.1.1: a bugfix release
  * [GM45] mesa demos spriteblast render incorrectly (fdo#30232)
  * [gles2] Ironlake: gl_PointCoord takes no effect for point sprites
  (fdo#32429)
  * Mesa 7.11-devel implementation error: Unexpected program target
  in destroy_program_variants_cb() (fdo#38086)
  * [snb] corrupted GLSL built-in function results when using Uniform
  Buffer contents as arguments (fdo#57121)
  * Garbled UI in Team Fortress 2 and Counter-Strike: Source
  (fdo#58042)
  * Texture flicker with fragment shader (fdo#58960)
  * [i965]Oglc fbblit(advanced.blitFb-3d-cube.mirror.both) fails
  (fdo#59495)
  * [IVB] 3DMMES2.0 Taiji performance reduced by ~13%% with
  gnome-session enable compositing (fdo#59783)
  * build - libvdpau_softpipe fails at runtime. (fdo#60121)
  * gbm_dri_bo_create fails to initialize bo->base.base.format
  (fdo#60143)
  * Corruption with DMA ring on cayman (fdo#60802)
  * r600g: add htile support cause gpu lockup in Dishonored wine.
  (fdo#60848)
  * [softpipe] piglit interpolation-noperspective-gl_BackColor-flat-fixed
  regression (fdo#60938)
  * alloc_layout_array tx * ty assertion failure when making pbuffer
  current (fdo#61012)
  * Segfault in glBitmap when called with PBO source (fdo#61026)
* Mon Mar 18 2013 mmeister@suse.com
- Added Download Link to Source section in spec file
* Sat Mar  2 2013 tobias.johannes.klausmann@mni.thm.de
- Update to Mesa 9.1:
  Mesa 9.1 implements the OpenGL 3.1 API, but the version reported by
  glGetString(GL_VERSION) or glGetIntegerv(GL_MAJOR_VERSION) /
  glGetIntegerv(GL_MINOR_VERSION) depends on the particular driver
  being used. Some drivers don't support all the features required
  in OpenGL 3.1. OpenGL 3.1 is only available if requested at context
  creation because GL_ARB_compatibility is not supported.
- New features:
  + GL_ARB_map_buffer_alignment
  + GL_ARB_texture_cube_map_array
- Changes:
  + Removed VAAPI state tracker (unmaintained and broken)
  + Removed i965's broken hardware implementation of GL_NV_vertex_program
  + Removed swrast support for GL_NV_vertex_program
  + Removed swrast support for GL_NV_fragment_program
  + Removed OpenVMS support (unmaintained and broken)
- Changes to package(s):
  + Rename libwayland-egl1-devel -> libwayland-egl-devel
  + Add a GLES3 Development package
  + Removed patches:
  Mesa-nodate.diff (patch1)
    No dates are put into the build anymore
  U_glx-fix-glGetTexLevelParameteriv-for-indirect-render.patch (patch18)
    Included in this release
  + Remove BuildRequires we dont need:
    http://cgit.freedesktop.org/mesa/mesa/commit/?id=
    af6aeae4e1286a8858e040602db338de6a1367dc
  + Update Required package versions
* Thu Feb 28 2013 dmueller@suse.com
- only enable swrast for aarch64 for now
* Tue Feb 26 2013 stefan.bruens@rwth-aachen.de
- fix_glx_indirect_reply_bfo#59876.diff
  * GLX replies are parsed incorrectly when using libxcb and AIGLX,
    happens for most replies where data is embedded in the header.
    (bfo#59876, bnc#802718)
* Thu Feb 21 2013 hrvoje.senjan@gmail.com
- update to Mesa 9.0.3: a bugfix release
  * Pink artifacts on objects in the distance in ETQW/Quake 4
  (fdo#25201)
  * configure: Doesn't check for python libxml2 (fdo#31598)
  * [softpipe] piglit glsl-max-varyings regression (fdo#40404)
  * [bisected] Oglc pxconv-gettex(basic.allCases) regressed (fdo#47220)
  * [bisected i965]Oglc shad-compiler(advanced.TestLessThani)
  regressed(fdo#48629)
  * [swrast] piglit fbo-generatemipmap-filtering regression
  (fdo#54240)
  * [sandybridge][uxa] graphics very glitchy and always flickering
  (fdo#56920)
  * [GM45] Chrome experiment "Stars" crash: brw_fs_emit.cpp:708:
  brw_reg brw_reg_from_fs_reg(fs_reg*): Assertion „!"not reached"“
  failed. (fdo#57166)
  * build test failure: nouveau_fbo.c:198:3: error: too few arguments to
  function 'nouveau_renderbuffer_del' (fdo#57746)
  * [swrast] Mesa 9.1-devel implementation error: Unable to
  delete renderbuffer, no context (fdo#57754)
  * [IVB] Graphical glitches in 0 A.D (fdo#58680)
  * [softpipe] util/u_tile.c:795:pipe_put_tile_z: Assertion `0' failed.
  (fdo#58972)
  * [bisected] Mesa build fails: clientattrib.c:33:22: fatal error: indirect.h:
  No such file or directory (fdo#59364)
  * [ILK/SNB/IVB Bisected]Oglc vertexshader(advanced.TestLightsTwoSided)
  causes GPU hung (fdo#59700)
  * [swrast] piglit ext_framebuffer_multisample-interpolation 0
  centroid-edges regression (fdo#59873)
  * [Bisected]Piglit glx_extension_string_sanity fail (fdo#60052)
  * Planeshift: triangles where grass would be (fdo#60172)
* Mon Feb  4 2013 duwe@suse.com
- enable build of subpackage libwayland-egl1
* Thu Jan 24 2013 sndirsch@suse.com
- update to Mesa 9.0.2: a bugfix release
  * [KMS] mesa demo spectex broken on rv280 (fdo#22576)
  * KMS/R200: Bad shading in NWN since Mesa rewrite (fdo#26809)
  * [bisected regression] Oglc fbo(negative.invalidParams3)
  Segmentation fault (fdo#45877)
  * st_glsl_to_tgsi.cpp:4006:dst_register: Assertion
  `index < VERT_RESULT_MAX' failed (fdo#54402)
  * Memoryleak with glPopAttrib only on Intel GM45 (fdo#55175)
  * glcpp accepts junk after #else/#elif/#endif tokens (fdo#56442)
  * EGL sets error to EGL_SUCCESS when DRI driver fails to create
  context (fdo#56706)
  * Webgl conformance shader-with-non-reserved-words crash. (fdo#57622)
  * r200: Culling is broken when rendering to an FBO (fdo#57842)
  * r300g: blend sfactor=GL_DST_COLOR fails with FBOs (fdo#57984)
  * [llvmpipe] src/gallium/auxiliary/gallivm/lp_bld_tgsi_info.c:75:analyse_src: Assertion `src->Index < (sizeof(ctx->imm)/sizeof((ctx->imm)[0]))' failed. (fdo#58545)
  * src/glsl/tests/Makefile.am missing $(top_srcdir)/include (fdo#59383)
* Wed Jan 23 2013 sndirsch@suse.com
- reverted removing Libs.private/Requires.private in pkgconfig
  files
* Sat Jan 19 2013 dmueller@suse.com
- enable llvm backend also for ARM
* Fri Jan 18 2013 rbrownccb@opensuse.org
- Add requires for Mesa to Mesa-libGL1 in baselibs.conf
  * Mesa required for many applications in wine
  * wine-32bit pulls through Mesa-libGL1-32bit without Mesa-32bit
* Sat Jan  5 2013 crrodriguez@opensuse.org
- Remove Requires.private and Libs.private from *.pc files
  * Both are needed only for static linking
  * This package provides only shared libraries
  * the rpm pkgconfig dependency generator considers "Requires.private"
  a valid dependency even though there are no static libraries in the
  packages
  * This cause bloat and hides broken "buildRequires" in other packages.
* Fri Dec 14 2012 tobias.johannes.klausmann@mni.thm.de
- Remove unrecognized configure option "--disable-glu"
* Mon Dec 10 2012 sndirsch@suse.com
- Update to Version 9.0.1
  * bug fix release
* Tue Oct 16 2012 sndirsch@suse.com
- improved packages descriptions
* Mon Oct  8 2012 tobias.johannes.klausmann@mni.thm.de
- Update to version 9.0:
  Mesa 9.0 has been released.  Mesa 9.0 is a feature release.
  "The" big feature is the availability of OpenGL 3.1 on some
  supported hardware.
  + Remove the Git Commit ID
* Tue Sep 25 2012 tobias.johannes.klausmann@mni.thm.de
- Update the Mesa 9.0 Git Snapshot
  + Add the Git CommitID to the buildscript
  + Minor cleanup of the buildscript
* Mon Sep 24 2012 sndirsch@suse.com
- removed any .la file
- moved libglapi.so from Mesa-devel to Mesa-libglapi-devel package;
  Mesa-devel requires Mesa-libglapi-devel package anyway
* Fri Sep 21 2012 sndirsch@suse.com
- fixed libOSMesa packaging (only a dangling symlink has been
  packaged)
* Fri Sep 21 2012 coolo@suse.com
- fix baselibs.conf after package split
* Thu Sep 20 2012 sndirsch@suse.com
- instead of using "make install" for installing libIndirectGL/
  libOSMesa, do install these libs manually, so we no longer end
  up with linking *everything* against libIndirectGL (instead of
  having it correctly linked against GL!)
* Fri Aug 24 2012 tobias.johannes.klausmann@mni.thm.de
- Update to 8.1 prerelease:
  + Added radeonsi to the dri drivers for x86/x86_64
  + Rewrite the configuration parts of the spec file
  + Changed u_Fix-crash-in-swrast-when-setting-a-texture-for-a-pix.patch
    to apply!
  + Changed u_remove-os-abi-tag.patch to apply! (Removed parts of it)
  + Changed u_mesa-8.0.1-fix-16bpp.patch to apply! (Removed parts of it)
  + Remove upstreamed patches: (double checked)
  - upstream-llvm-patch.diff
  - U_i965-gen7-Reduce-GT1-WM-thread-count-according-to-up.patch
* Thu Aug 23 2012 fcrozat@suse.com
- Add u_mesa-8.0-llvmpipe-shmget.patch (Fedora): use shmget under
  llvmpipe, if available (bnc#766498).
- Update u_mesa-8.0.1-fix-16bpp.patch to work with shmget patch.
* Wed Aug  8 2012 tiwai@suse.de
- U_i965-gen7-Reduce-GT1-WM-thread-count-according-to-up.patch
  * Fix GPU hang with IVB GT1 desktop (bnc#775048)
* Tue Jul 10 2012 tobias.johannes.klausmann@mni.thm.de
- Update to Version 8.0.4 (minor bugfix release)
- Back to bz2 tarballs
* Sat Jun 16 2012 coolo@suse.com
- remove buildrequire on vim, it creates a pretty big cycle for
  no (obvious) benefit
* Tue Jun 12 2012 sndirsch@suse.com
- enabled build of XvMC/VDPAU state trackers for Nouveau, R300,
  R600, Softpipe (Software implementation)
* Tue Jun 12 2012 sndirsch@suse.com
- u_remove-os-abi-tag.patch
  * Remove OS ABI tag from libGL, so it is no longer preferred over
    libGLs without OS ABI tag (bnc#765294, fdo#26663)
* Fri Jun  8 2012 sndirsch@suse.com
- let libGL1-Mesa require Mesa, since that package includes the DRI
  drivers (including the "swrast" DRI driver for software rendering)
  (bnc#765241)
* Wed May 30 2012 fcrozat@suse.com
- Add u_mesa-8.0.1-fix-16bpp.patch (Fedora): fix 16bpp mode under
  llvmpipe.
* Sat May 26 2012 sndirsch@suse.com
- added configure options "--enable-gbm --enable-glx-tls" (required
  for glamor support)
* Fri May 25 2012 meissner@suse.com
- libxatracker is also not built on ppc*.
* Mon May 21 2012 sndirsch@suse.com
- Trivial change to Version 8.0.3; tarball from here:
  http://cgit.freedesktop.org/mesa/mesa/snapshot/mesa-8.0.3.tar.gz
* Wed May 16 2012 adrian@suse.de
- fix build on platforms without gallium (s390 & arm)
* Wed Apr 25 2012 tittiatcoke@gmail.com
- Added patches from upstream Master to enable building with
  llvm 3.1
* Wed Apr 25 2012 sndirsch@suse.com
- For full OpenGL 3.0 compliance, it is necessary to
  have floating-point textures, so Mesa is now compiled with
  "--enable-texture-float" parameter to have OpenGL 3.0 support.
- disabling glut/glw no longer required since it's no longer
  shipped with Mesa
* Mon Apr 23 2012 vljn@ovi.com
- Enable xa state tracker and svga gallium drivers (vmwgfx stack)
* Sun Apr 15 2012 ro@suse.de
- use same dri drivers on ia64 as on ppc (no drm_intel)
* Wed Mar 21 2012 ryanbach@adelphia.net
-- Updated software rasterizer to use llvmpipe the advanced,
-  multithreaded,software rasterizer if availaible for that
-  archetecture (ie. X86/X86-64).
* Wed Mar 21 2012 jengelh@medozas.de
- Adjust baselibs.conf for OSMesa soname change
* Wed Mar 21 2012 sndirsch@suse.com
- U_gallium-rtasm-properly-detect-SSE-and-SSE2.patch
  * gallium/rtasm: properly detect SSE and SSE2;  this should fix
    crashes on ancient processors. (bnc#728737)
* Thu Mar  1 2012 coolo@suse.com
- fix baselibs.conf after update of libOSMesa
- do not put the date in generated code, this breaks build-compare
  for little to no gain as we know the build date from rpm header
* Fri Feb 24 2012 sndirsch@suse.com
- Switch software rasterizer to llvmpipe (gallium driver now)
  * Performance improvement especially on multicore system.
- minimal specfile cleanup
* Fri Feb 24 2012 meissner@suse.de
- only require drm_intel on intel.
* Thu Feb 23 2012 sndirsch@suse.com
- Update to Mesa 8.0.1
  * Removed all DRI drivers that did not support DRI2.
    Specifically, i810, mach64, mga, r128, savage, sis, tdfx, and
    unichrome were removed.
  * Removed all remnants of paletted texture support. As required
    by desktop OpenGL, GL_COLOR_INDEX data can still be uploaded
    to a color (e.g., RGBA) texture. However, the data cannot be
    stored internally as color-index.
  * Removed support for GL_APPLE_client_storage extension.
  * Removed the classic Mesa r300 and r600 drivers, which are
    superseded by the gallium drivers for this hardware.
  * Removed the dead Gallium i965, cell and failover drivers,
    which were either broken and with nobody in sight to fix
    the situation or deprecated.
- obsoletes u_GLX-SWrast-Make-GLX-with-SWrast-enabled-work-on-olde.patch
  (git commit #63a6fd6603574c1c01324fbeb0863e39d3864c16)
- obsoletes U_Mesa-7.11-llvm3.patch
- obsoletes Mesa-llvm-3.0.patch
- disabled u_Fix-crash-in-swrast-when-setting-a-texture-for-a-pix.patch
  for now (obsolete as well?)
* Wed Feb 22 2012 jengelh@medozas.de
- use --enable-shared-dricore, saves ~33 MB
* Wed Feb 22 2012 sndirsch@suse.com
- readded build of non-gallium nouveau driver ("nouveau_vieux") to
  support again older NVIDIA GPUs
* Tue Feb 21 2012 coolo@suse.com
- fix requires of devel package in moving the %%package before the
  other packages that have custom versions.
  %%version in rpm is tricky - it's the _last_ version before the
  macro, not the main one.
* Tue Feb 21 2012 jengelh@medozas.de
- Split shared libraries per shlib pol.
* Sun Feb 12 2012 jengelh@medozas.de
- Update dependencies according to configure.ac,
  use pkgconfig symbols
- Parallel build with %%_smp_mflags
- Remove redundant tags/sections
* Thu Feb  9 2012 sndirsch@suse.com
- fixed buildreqs due to splitted xorg-x11-libs
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Thu Nov 17 2011 vljn@ovi.com
- Update to Mesa 7.11.1
  * U_glx-ignore-BadRequest-errors-from-DRI2Connect.diff included
* Thu Oct  6 2011 idonmez@suse.com
- Update Mesa-llvm-3.0.patch again to fix compilation
* Thu Sep 29 2011 idonmez@suse.com
- Update Mesa-llvm-3.0.patch for new llvm snapshot
* Thu Sep 15 2011 idonmez@suse.com
- Fix build with newest llvm, fdo#40754
* Tue Sep 13 2011 idonmez@suse.com
- Fix build with Factory
* Mon Sep 12 2011 sndirsch@suse.com
- revert previous change since it actually *broke* the build with
  Factory
* Mon Sep 12 2011 idonmez@suse.com
- Fix build with Factory too
* Fri Sep  9 2011 vljn@ovi.com
- Fix openSUSE 11.3 11.4 build
* Sun Sep  4 2011 vljn@ovi.com
- Update to Mesa 7.11 final
* Sun Sep  4 2011 meissner@suse.de
- llvm is only available for *x86* currently
* Tue Aug  9 2011 stefan.bruens@rwth-aachen.de
- add fix for bfo #28125 (DRI2 prevents indirect glx)
* Tue Aug  2 2011 mhopf@novell.com
- Obsolete Mesa-nouveau3d (included in standard Mesa package now)
- Also nuke from baselibs.conf
* Fri Jul 29 2011 mhopf@novell.com
- Update to Mesa 7.11-rc3
- U_Mesa-7.11-llvm3.patch: fix compatibility with llvm 3.0 (and pre-releases)
- gallium is now required for r300, r600
- nouveau is now built by default (except on < OS11.3)
* Thu Jul 28 2011 meissner@suse.de
- Also let ppc64 build the noveau driver, fixing build on ppc64.
* Sun Jul  3 2011 vljn@ovi.com
- Update Mesa 7.10.3
  * Few crashes and rendering fixes.
* Mon Jun 20 2011 sndirsch@novell.com
- libdrm-2.4.26-nouveau.diff
  * Fixes build of Mesa 7.10.2 nouveau driver with libdrm 2.4.26
  (fdo #35562)
* Thu Jun 16 2011 mhopf@novell.com
- Don't unpack MesaDemos during build; it's not needed any more.
* Fri Jun 10 2011 eich@suse.de
- u_Fix-crash-in-swrast-when-setting-a-texture-for-a-pix.patch:
  Update this patch closing a giant memory leak.
* Thu Jun  9 2011 eich@suse.de
- Replace patches:
  * add: u_GLX-SWrast-Make-GLX-with-SWrast-enabled-work-on-olde.patch
    This patch falls back to indirect rendering if SWrast doesn't work
    with older Xservers as no common configs/visuals can be found.
  * remove: Mesa_indirect_old_xserver_compatibility.diff
    this patch is superseded.
  * rename: 0001-Fix-crash-in-swrast-when-setting-a-texture-for-a-pix.patch
    to u_Fix-crash-in-swrast-when-setting-a-texture-for-a-pix.patch
* Sat Jun  4 2011 eich@suse.de
- Remove: intel-add-gem-string.patch
  This patch was barking up the wrong tree anyway.
  As discussed with Martin Grässlin from the Kwin project
  a patch from the upstream git master has been cherry-picked
  and added to kdebase4-workspace which makes this patch unneciessary.
  The patch to Kwin will become obsolete once Kwin is updated,
  this will be noticed easily in kdebase4-workspace.
* Tue May 24 2011 eich@suse.de
- Fix the driver directory search path in the spec file.
  This makes dri_driver_dir.diff obsolete.
* Thu May 19 2011 idoenmez@novell.com
- Add intel-add-gem-string.patch: Add back "GEM" string to Intel
  driver's version output to fix OpenGL effects in kwin.
* Tue May 17 2011 eich@suse.de
- Add packaging information for GLES2 devel files.
* Mon May 16 2011 eich@suse.de
- Add GLES2 support.
* Fri May  6 2011 mhopf@novell.com
- Update to 7.10.2
  * Many crash and rendering fixes
  * Fixes bug 678264 (Xserver crash with radeon/radeonhd UMS)
* Wed Mar 30 2011 fcrozat@novell.com
- Enable gallium driver for radeon and r600
* Sat Jan  8 2011 sndirsch@novell.com
- update to 7.10 final
* Mon Jan  3 2011 sndirsch@novell.com
- Update pre-7.10 state (git 96685a6)
  Fixes two screensaver GPU crashes on SandyBridge (xorg #32683)
* Mon Dec 20 2010 sndirsch@novell.com
- Update full mesa stack to pre-7.10 (git 32218e4).
  Fixes most of intel SandyBridge rendering issues.
- Set Mesa version to 7.9.801
- obsoletes commit-d316391.diff
- adjusted 0001-Fix-crash-in-swrast-when-setting-a-texture-for-a-pix.patch
* Sat Nov  6 2010 sndirsch@novell.com
- 0001-Fix-crash-in-swrast-when-setting-a-texture-for-a-pix.patch
  * Fix crash in swrast when setting a texture for a pixmap
    (bnc #641297)
- readd swrastg DRI driver
* Wed Nov  3 2010 sndirsch@novell.com
- exclude swrastg DRI driver (bnc #641297)
* Fri Oct  8 2010 meissner@suse.de
- --enable-gallium-nouveau also for PowerPC.
* Thu Oct  7 2010 sndirsch@novell.com
- commit-d316391.diff
  * i965: Fix gen6 pointsize handling to match pre-gen6. Fixes
    point-line-no-cull (bfo #30532)
* Tue Oct  5 2010 sndirsch@novell.com
- MesaLib 7.9
- obsoletes commit-73dab75.diff
* Thu Sep 30 2010 sndirsch@novell.com
- commit-73dab75.diff
  * i965: fallback lineloop on sandybridge for now (bfo #30420,
    comment #8)
* Wed Sep 29 2010 sndirsch@novell.com
- updated to MesaLib 7.9-RC2
* Mon Sep 27 2010 sndirsch@novell.com
- updated to MesaLib 7.9-RC1
* Wed Sep 15 2010 sndirsch@novell.com
- Mesa git master #83f5f50 (2010-09-14)
- obsoletes commit-4ebf07a.diff
* Wed Sep 15 2010 sndirsch@novell.com
- Mesa git master #fd328a (2010-09-11)
- commit-4ebf07a.diff
  * glx: Don't destroy DRI2 drawables for legacy glx drawables
    (bfo #30109)
* Thu Sep  9 2010 sndirsch@novell.com
- use TALLOC_LIBS/TALLOC_CFLAGS env. variables which obsolete the
  requirement for a patched libtalloc-devel package, i.e.
  talloc.pc is no longer required.
* Sun Aug 29 2010 sndirsch@suse.de
- Mesa git master #2dfd348 (2010-08-28)
- obsoletes libdrm_nouveau.diff.bz2, mesa-commit-06c72da.diff
- adjusted Mesa_indirect_old_xserver_compatibility.diff,
  dri_driver_dir.diff
- added libtalloc-devel bison flex libxml2-python to BuildRequires
- pkgconfig file for egl
* Fri Jul 23 2010 sndirsch@suse.de
- reenable build of mga DRI driver (bnc #466635)
* Tue Jul  6 2010 johannesobermayr@gmx.de
- bnc #620037
  * create nouveau_vieux_dri.so
  * add libdrm_nouveau.diff
  * separate Mesa-nouveau3d package
- fix some RPMLINT warnings
* Fri Jun 25 2010 sndirsch@suse.de
- Mesa 7.8.2
  * Various i965 and i915 driver fixes.
- adjusted Mesa_indirect_old_xserver_compatibility.diff,
  egl-buildfix.diff
* Wed Jun  9 2010 bg@novell.com
- sis does not work on hppa as well
* Mon Jun  7 2010 sndirsch@suse.de
- mesa-commit-06c72da.diff
  * intel: Update renderbuffers unconditionally in
    intelSetTexBuffer2() (bnc #610323)
* Sat May 22 2010 sndirsch@suse.de
- Mesa_indirect_old_xserver_compatibility.diff (revival)
  Workaround for enabling indirect rendering to older Xservers
  (bnc #469280, bnc #600672).
* Sat Apr 10 2010 sndirsch@suse.de
- removed legal check since affected source files no longer exist
- removed obsolete missing_Makefile.diff
- specfile cleanup
* Tue Apr  6 2010 sndirsch@suse.de
- Mesa 7.8.1
  * The primary purpose of this release is to fix a significant
    error in Mesa's copy of glxext.h and the libGL code that uses
    it. The release also contains some other bug fixes.
* Mon Mar 29 2010 sndirsch@suse.de
- update to 7.8 final release
* Thu Mar 18 2010 ro@suse.de
- use 7.8-rc1 tarballs
* Wed Mar 17 2010 ro@suse.de
- update to 7.8
  - dos, ggi and classic svga drivers removed along with
    their header files
- re-enable nouveau driver
* Sun Feb 28 2010 sndirsch@suse.de
- due to libdrm update disable build of nouveau driver for now
  (needs newer Mesa sources from git master)
* Fri Jan 22 2010 ro@suse.de
- fix build for ppc
* Tue Dec 22 2009 sndirsch@suse.de
- Mesa 7.7 final release
* Fri Dec 18 2009 sndirsch@suse.de
- Mesa 7.7 RC3
  * more bug fixes
* Tue Dec 15 2009 jengelh@medozas.de
- add baselibs.conf as a source
- enable parallel building
- build drivers for SPARC
* Tue Dec  8 2009 sndirsch@suse.de
- Mesa 7.7 RC2
  * more bug fixes
* Tue Dec  1 2009 sndirsch@suse.de
- Mesa 7.7 RC1
  * New features
  - VMware "SVGA" Gallium driver. This is a Gallium3D driver
    which targets the VMware virtual graphics device. It allows
    Linux OpenGL guest applications to utilize the 3D graphics
    hardware of the host operating system.
  - GL_ARB_draw_elements_base_vertex (supported in Intel i965
    and software drivers)
  - GL_ARB_depth_clamp (supported in Intel i965 DRI and software
    drivers)
  - GL_NV_depth_clamp (supported in Intel i965 DRI and software
    drivers)
  - GL_ARB_provoking_vertex (same as GL_EXT_provoking_vertex)
  - Wavefront .obj file loader/viewer demo (progs/demos/
    objviewer)
  * Bug fixes
  - Many assorted i965 driver fixes.
  - Many r300-gallium driver fixes; this driver is now
    considered unstable-quality instead of experimental-quality.
  * Changes
  - New Mesa texture/surface format infrastructure
  - Removed some unused Mesa device driver hooks
* Wed Oct  7 2009 mhopf@novell.com
- Add -DNDEBUG to CFLAGS.
  It's unfortunate, but a few newly added assert()s for testing memory leaks
  trigger in this release. But having memory leaks is less problematic than
  crashing compiz.
* Tue Sep 29 2009 sndirsch@suse.de
- Mesa 7.6
  * OpenVG front-end (state tracker for Gallium). This was written
    by Zack Rusin at Tungsten Graphics.
  * GL_ARB_vertex_array_object and GL_APPLE_vertex_array_object
    extensions (supported in Gallium drivers, Intel DRI drivers,
    and software drivers)
  * GL_ARB_copy_buffer extension (supported in Gallium drivers,
    Intel DRI drivers, and software drivers)
  * GL_ARB_map_buffer_range extension (supported in Gallium drivers,
    Intel DRI drivers, and software drivers)
  * GL_ARB_seamless_cube_map extension (supported in software drivers
    and i965 drivers)
  * GL_ARB_vertex_array_bgra (ARB synonym for GL_EXT_vertex_array_bgra)
  * GL_ARB_sync (supported in software drivers and Intel DRI drivers)
  * GL_EXT_provoking_vertex extension (supported in Gallium, i915, i965,
    and software drivers)
  * Rewritten radeon/r200/r300 driver using a buffer manager
  * radeon/r200/r300 GL_EXT_framebuffer_object support when used with
    kernel memory manager
  * radeon/r200/r300 support for GL_ARB_occlusion_query
  * r300 driver supports OpenGL 1.5
  * r300 driver support for GL_EXT_vertex_array_bgra, GL_EXT_texture_sRGB
  * i915/945 driver support for GL_ARB_point_sprite, GL_EXT_stencil_two_side
    and GL_ATI_separate_stencil extensions
  * Rewritten assembler for GL_ARB_vertex_program / GL_ARB_fragment_program.
  * Added configure --with-max-width=W, --with-max-height=H options to
    specify max framebuffer, viewport size.
  * Initial version of Gallium llvmpipe driver. This is a new driver based
    on LLVM which makes exensive use of run-time code generation. This is
    an "alpha" stage driver. See the src/gallium/drivers/llvmpipe/README
    file for more information.
  * i965 DRI driver fixes, including support for "unlimited" size constant
    buffers (GLSL uniforms)
* Mon Sep 28 2009 sndirsch@suse.de
- Mesa 7.5.1
  * bug-fix release fixing issues found since the 7.5.1 release.
  - Detect B43 chipset in Intel driver
  - Assorted bug fixes for i965/i945 drivers
  - Fixed Gallium glDrawPixels(GL_STENCIL_INDEX) failure.
  - Fixed GLSL linker/preprocessor version directive issue seen
    in Wine (such as bug 23946)
  - glUseProgram() is now compiled into display lists (bug 23746).
  - glUniform functions are now compiled into display lists
  - Auto mipmap generation didn't work reliably with Gallium.
  - Fixed random number usage in GLX code.
  - Fixed invalid GL_OUT_OF_MEMORY error sometimes raised by
    glTexSubImage2D when using Gallium.
* Fri Sep 11 2009 sndirsch@suse.de
- no longer package glew headers in Mesa-devel, which caused file
  conflicts with glew-devel (bnc #538344)
* Thu Sep  3 2009 sndirsch@suse.de
- Mesa 7.5.1
  * bug-fix release fixing issues found since the 7.5 release.
* Sun Aug  2 2009 jansimon.moeller@opensuse.org
- add ARM variant to configure
* Fri Jul 31 2009 sndirsch@suse.de
- Mesa-devel should require libdrm-devel (bnc #527097)
* Sat Jul 18 2009 sndirsch@suse.de
- Mesa 7.5
  * new features like e.g. Gallium3D
  * various bug fixes
  * removed some GL_SGIX_* extensions, which have been superseded
    by ARB versions
- obsoletes mesa-commit-88b702e.diff, mesa-commit-954dfba.diff,
  intel_release_static_region.patch
* Wed Jun 24 2009 sndirsch@suse.de
- Mesa 7.4.4
  * Fixed i965/i915 segfault in screen destruction (bfo #22408)
- adjusted intel_release_static_region.patch
- obsoletes Mesa-intel_unref_fb.patch
* Tue Jun 23 2009 sndirsch@suse.de
- Mesa-intel_unref_fb.patch
  * intel: call _mesa_unreference_framebuffer() in
    intelDestroyBuffer(). This was a call to
    _mesa_reference_framebuffer(ptr, NULL) but the NULL pointer is
    incorrect in Mesa 7.4.x. Fixes a failed assertion during screen
    tear-down.
* Sat Jun 20 2009 sndirsch@suse.de
- Mesa 7.4.3
  * Fixed texture object reference counting bug (bug 21756)
  * Allow depth/stencil textures to be attached to GL_STENCIL_ATTACHMENT point
    (SF bug 2793846)
  * Added missing glGet case for GL_VERTEX_ARRAY_BINDING_APPLE
  * Fixed some OSMesa build issues
  * Fixed a vertex buffer object crash
  * Fixed broken glTexImage3D() when image type = GL_BITMAP
  * Fixed some GLSL preprocessor bugs
  * Fixed framebuffer mem leak in i945/i965 DRI drivers
  * Fixed texture coordinate repeat bug in swrast (bug 21872)
  * Fixed incorrect viewport clamping (lower bound is zero, not one)
  * GLX fix for glean's makeCurrent test case
- obsoletes reverted applied mesa_7_4_branch-commit-63cde0e.diff
* Tue May 19 2009 sndirsch@suse.de
- mesa_7_4_branch-commit-63cde0e.diff
  * commit, which introduced a regression; revert it (bnc #504578)
* Fri May 15 2009 sndirsch@suse.de
- Mesa 7.4.2
  * Fixed segfault when rendering to front buffer with DRI 1.
  * Fixed swrast texture rectangle bug when wrap mode =
    GL_CLAMP_TO_BORDER and filter mode = GL_LINEAR. (bug 21461)
  * Fixed texture object mem leak during context destruction.
  * Fixed a state validation bug in glCopyTex[Sub]Image()
  * Fixed some i965 GLSL bugs.
  * Fixed an R300 driver texture object bad memory reference.
* Wed Apr 22 2009 sndirsch@suse.de
- no longer package static libGL/libGLU; can't work any longer
  due to static X libraries having been removed
* Sat Apr 18 2009 sndirsch@suse.de
- Mesa 7.4.1
  * Fixed a two-sided lighting bug in fixed-function-to-GPU code
    generation
  * Fixed some Darwin issues (Jeremy Huddleston)
  * Indexing the GLSL gl_EyePlane[] or gl_ObjectPlane[] arrays
    with a variable was broken, bug 20986
  * Fixed incorrect texture unit bias in TXB instruction
  * glTexParameter settings weren't always propogated to drivers
  * Assorted vertex/fragment program bug fixes
  * Fixed point rendering in software rasterizer
  * Fixed potential deadlock in object hash functions
  * Fix a couple bugs surrounding front-buffer rendering with
    DRI2, but this is not quite complete.
  * Fixed glPopAttrib() bug when restoring user clip planes
* Sat Mar 28 2009 sndirsch@suse.de
- Mesa 7.4 (final)
  * This is a stable release that just fixes bugs since the 7.3
    release.
* Thu Mar 26 2009 sndirsch@suse.de
- Mesa 7.4-rc2
  * more patches cherry-picked from the master branch
* Sat Mar 21 2009 sndirsch@suse.de
- Mesa 7.4-rc1
* Sat Mar  7 2009 sndirsch@suse.de
- mesa-commit-954dfba.diff
  * i965: bump texture limit to 4kx4k (bfo #18100)
  * obsoletes i965-GL_MAX_TEXTURE_SIZE-4096.diff
- mesa-commit-88b702e.diff
  * i965: Eric Anholt's patch for bumping up texture sizes
    (bfo #18100)
* Fri Feb 27 2009 mhopf@suse.de
- Mesa_indirect_old_xserver_compatibility.diff
  Workaround for enabling indirect rendering to older Xservers
  (bnc #469280).
* Wed Feb 25 2009 sndirsch@suse.de
- update to Mesa 7.3
- obsoletes MesaLib-7.2_intel-2008-q3_793c3b9-46921a5.diff,
  commit-7d99ddc.diff, commit-b4bf9ac.diff,
  i965_aperture_call_for_Q3.patch, mesa-7.1-fix-i8xx-vbos.patch
* Tue Feb 10 2009 sndirsch@suse.de
- commit-7d99ddc.diff
  * intel: Fix a number of memory leaks on context destroy.
    (bnc #457879,bfo #19665)
- intel_release_static_region.patch
  * detach static region from intel_renderbuffer on contex destroy
    (bnc #457879,bfo #19665)
* Fri Jan 23 2009 sndirsch@suse.de
- added intel-i810-Mesa, Mesa7 to Provides/Obsoletes, i.e. get rid
  of SLE10 packages (bnc #468796)
* Wed Jan 14 2009 sndirsch@suse.de
- i965_aperture_call_for_Q3.patch (Quanxian Wang)
  * addresses bfo #19242; based on Q3 release; the patch is
    coming from commit id 59b2c2adbbece27ccf54e58b598ea29cb3a5aa85,
    2fc9d671e0be77676818da51cd3b35b52af79421,
    c30eb2c104c19c758c0b2a2461ad7f38cfa747d0
* Tue Jan 13 2009 olh@suse.de
- obsolete old XFree86-Mesa{,-devel}-XXbit packages (bnc#437293)
* Fri Jan  9 2009 sndirsch@suse.de
- /etc/drirc
  * disable vblank_mode/force_s3tc_enable and enable
    disable_lowimpact_fallback for r300 driver to fix performance
    issues with GoogleEarth and OpenOffice.Org (bnc #438666)
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Fri Nov 28 2008 sndirsch@suse.de
- mesa-7.1-fix-i8xx-vbos.patch
  * For some reason the Intel 865 seem to claim VBO support in the
    docs, but doesn't seem to practice it in the hardware, or
    there is some missing errata. This restores the old pre-vbo
    code and uses it on all 8xx hw. (bfo #17963)
    This patch fixes OpenGL support on 845/855GM/865.
* Sat Nov 22 2008 sndirsch@suse.de
- disabled VBlank also for i965 DRI driver (bfo #17967)
* Mon Nov 17 2008 sndirsch@suse.de
- added global /etc/drirc to disable VBlank for i915 DRI driver
  (bnc #432980)
* Thu Nov 13 2008 sndirsch@suse.de
- disabled i965-GL_MAX_TEXTURE_SIZE-4096.diff; apparently it
  doesn't work for compiz/Desktop effects and is not required at
  all for 3D support in general (bnc #441572)
* Fri Oct 31 2008 sndirsch@suse.de
- commit-b4bf9ac.diff
  * i915: fix crash in i830_emit_state (bfo #17766)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue Oct 21 2008 sndirsch@suse.de
- MesaLib-7.2_intel-2008-q3_793c3b9-46921a5.diff
  * i965: Fix a potential assertion failure.
  * intel: GLSL 1.20 is broken in Mesa, so disable it in the i965
    driver
* Thu Oct  9 2008 sndirsch@suse.de
- Mesa 7.2_intel-2008-q3_793c3b9
  * Intel-2008-Q3-RC3 release (Mesa 7.2 + GEM code)
* Sat Sep 27 2008 sndirsch@suse.de
- Mesa 7.2_intel-2008-q3_e636f5b
  * Intel-2008-Q3-RC2 release (Mesa 7.2 + GEM code)
- replaced disable_ttm_warning.diff with disable_gem_warning.diff
- adjusted i965-GL_MAX_TEXTURE_SIZE-4096.diff
* Sat Sep 20 2008 sndirsch@suse.de
- Mesa 7.2:
  Mesa 7.2 is a stable release fixing bugs found in 7.1, which was
  a new development release. Mesa 7.2 implements the OpenGL 2.1
  API, but the version reported by glGetString(GL_VERSION) depends
  on the particular driver being used. Some drivers don't support
  all the features required in OpenGL 2.1. Note that this version
  of Mesa does not use the GEM memory manager. The master branch
  of git uses GEM. The prototype DRI2 code that was in 7.1 has
  also been removed. DRM version 2.3.1 should be used with Mesa 7.2
* Fri Aug 29 2008 sndirsch@suse.de
- added libexpat-devel to Buildrequires to fix build
* Thu Aug 28 2008 sndirsch@suse.de
- revert of commit-1724334.diff obsolete after adding the patches
  commit-5930aeb.diff/commit-78f50cd.diff (commits 5930aeb/78f50cd)
  to xorg-x11-server package (bfo #17069)
* Wed Aug 27 2008 sndirsch@suse.de
- updated to Mesa 7.1 final release
* Mon Aug 18 2008 sndirsch@suse.de
- reverted commit 1724334 to get RGB, Double-buffered visuals back;
  otherwise even GL applications like glxgears no longer start
  (bfo #17069)
* Sun Aug 17 2008 sndirsch@suse.de
- udpated to Mesa 7.1 RC4
  "This includes the latest GLSL fixes/features plus other assorted
  fixes from the past 2-3 weeks."
- obsoletes MesaLib-6befdca.diff
- adjusted disable_ttm_warning.diff (TTM --> GEM)
- adjusted i965-GL_MAX_TEXTURE_SIZE-4096.diff
* Mon Aug 11 2008 sndirsch@suse.de
- udpated to Mesa 7.1 RC3
  * bugfixes
* Mon Aug  4 2008 sndirsch@suse.de
- i965-GL_MAX_TEXTURE_SIZE-4096.diff
  * sets GL_MAX_TEXTURE_SIZE to 4096 for Intel 965 series
* Fri Aug  1 2008 sndirsch@suse.de
- commit-c71fa34.diff
  * added null texObj ptr check (bfo #15567, bnc #402687)
* Thu Jul 10 2008 sndirsch@suse.de
- even s390(x) needs swrast DRI driver now
- specfile cleanup
* Wed Jul  9 2008 sndirsch@suse.de
- no dri.pc for s390/s390x
* Tue Jul  8 2008 sndirsch@suse.de
- disable_ttm_warning.diff
  * disables confusing warning, that TTM cannot be initialized
* Fri Jul  4 2008 sndirsch@suse.de
- udpated to Mesa 7.1-pre
* Mon Apr 14 2008 sndirsch@suse.de
- unichrome-context.diff
  * Do not clear the current context before attempting to use it.
    (bnc #285496)
- no longer need to use LIBGL_ALWAYS_INDIRECT=1 on via hardware
  (bnc #285496)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Sat Apr  5 2008 sndirsch@suse.de
- update to Mesa bugfix release 7.0.3 (final)
* Wed Apr  2 2008 sndirsch@suse.de
- update to Mesa bugfix release 7.0.3 RC3
  * obsoletes commit-185320a.diff
* Thu Mar 13 2008 sndirsch@suse.de
- commit-185320a.diff
  Only call ProgramStringNotify if program parsing succeeded.
  Wine intentionally tries some out-of-spec programs to test
  strictness, and calling ProgramStringNotify on the results
  of a failed program parse resulted in crashes in the 965
  driver. (bfo #13492)
* Fri Feb 22 2008 sndirsch@suse.de
- update to Mesa bugfix release 7.0.3 RC2
  * Fixed GLX indirect vertex array rendering bug (14197)
  * Fixed crash when deleting framebuffer objects (bugs 13507,
    14293)
  * User-defined clip planes enabled for R300 (bug 9871)
  * Fixed glBindTexture() crash upon bad target (bug 14514)
  * Fixed potential crash in glDrawPixels(GL_DEPTH_COMPONENT) (bug
    13915)
  * Bad strings given to glProgramStringARB() didn't generate
    GL_INVALID_OPERATION
  * Fixed minor point rasterization regression (bug 11016)
* Wed Jan 23 2008 sndirsch@suse.de
- update to Mesa bugfix release 7.0.3 RC1
  * Added missing glw.pc.in file to release tarball
  * Fix GLUT/Fortran issues
  * GLSL gl_FrontLightModelProduct.sceneColor variable wasn't
    defined
  * Fix crash upon GLSL variable array indexes (not yet supported)
  * Two-sided stencil test didn't work in software rendering
  * Fix two-sided lighting bugs/crashes (bug 13368)
  * GLSL gl_FrontFacing didn't work properly
  * glGetActiveUniform returned incorrect sizes (bug 13751)
  * Fix several bugs relating to uniforms and attributes in GLSL
    API (Bruce Merry, bug 13753)
  * glTexImage3D(GL_PROXY_TEXTURE_3D) mis-set teximage depth field
* Sat Nov 10 2007 sndirsch@suse.de
- updated to Mesa 7.0.2
  * New features:
  - Updated Windows VC7 project files
  - Added DESTDIR variable for 'make install'
  - Added pkg-config files for gl, glu, glut and glw libraries
  - Added bluegene-xlc-osmesa and catamount-osmesa-pgi configs
  - Support for Intel G33/Q33/Q35 graphics chipsets
  * Bug fixes:
  - Fixed a vertex buffer wrapping issue (bug 9962)
  - Added mutex protection around texture object reference
    counters
  - Added checking/support for additional chips in the i915/i945
    family (see 11978)
  - Fixed a blending/banding issue (bug 11931)
  - Fixed a GLU matrix inversion bug (#6748)
  - Fixed problem with large glDrawArrays calls and indirect
    rendering (bug 12141)
  - Fixed an assortment of i965 driver bugs
  - Fixed x86-64 vertex transformation bug (12216)
  - Fixed X server crash caused by multiple indirect rendering
    clients
  - Parsing of state.texgen in ARB vertex/fragment programs
    didn't work (bug 12313)
  - Fixed a glCopyPixels/glPixelZoom bug (12417)
  - Fixed a bug when using glMaterial in display lists (10604)
  - Fixed a few GLUT/Fortran issues (Bill Mitchell)
  - Fixed Blender crash bug (12164)
  - Fixed some issues preventing cross-compiling
  - Fixed up broken GL_ATI_separate_stencil extension
  - glDrawArrays(count=0) led to a crash
  - Fix SSE code gen memory leak, possible crash
  - Fixed MMX 565 rgb conversion problem (bug 12614)
  - Added -fno-strict-aliasing and -fPIC flags for gcc
  - Fixed Blender crash in Unichrome driver (bug 13142)
* Wed Nov  7 2007 sndirsch@suse.de
- updated to Mesa 7.0.2 RC2
  * added -fPIC and -fno-strict-aliasing flags for gcc
  * applied a few patches (mmx code, edgeflag ptr check)
  * r200 texture from pixmap fixes
- obsoletes pic.diff
* Sun Nov  4 2007 sndirsch@suse.de
- pic.diff
  * fixes shared lib on i386 (X.Org Bug #1809)
* Wed Oct 31 2007 sndirsch@suse.de
- updated to Mesa 7.0.2 RC1
- obsoletes disable-libGL-warning.diff, i915-g33.diff and
  i915tex-g33.diff
- adjusted link-shared.diff and static.diff
* Mon Aug 13 2007 sndirsch@suse.de
- disable-libGL-warning.diff:
  * Just filters warnings about unsupported non-conformant visuals
    instead of relying on the visual id. (X.Org Bug #6689)
* Sun Aug 12 2007 sndirsch@suse.de
- disable-libGL-warning.diff:
  * ignore unsupported visual 0x4b (Bug #247471, X.Org Bug #6689)
* Sat Aug  4 2007 sndirsch@suse.de
- updated to bugfix relelase 7.0.1
* Wed Jul  4 2007 sndirsch@suse.de
- i915-g33.diff/i915tex-g33.diff
  * support for G33/Q33/Q35
* Sat Jun 23 2007 sndirsch@suse.de
- updated to final release 7.0
* Thu Jun 21 2007 sndirsch@suse.de
- updated Mesa to release 7.0 RC1
  * Mesa 7.0 is a stable, follow-on release to Mesa 6.5.3. The only
    difference is bug fixes. The major version number bump is due
    to OpenGL 2.1 API support.
* Mon May 28 2007 sndirsch@suse.de
- move GL headers, which conflict with GL headers of NVIDIA driver,
  from Mesa-devel back to Mesa; this still make rpmlint happy
* Sat May 26 2007 dmueller@suse.de
- add missing ldconfig call to %%post
- move include files to -devel package
* Fri May 25 2007 dmueller@suse.de
- fix undefined symbols for i915 (#277744)
* Tue May 22 2007 dmueller@suse.de
- fix various undefined symbols in dri drivers (#272875)
- build parallel
* Mon May 14 2007 sndirsch@suse.de
- link-shared.diff:
  * use shared lib for DRI drivers to save a lot of space (Bug
    [#272875])
* Mon Apr 30 2007 sndirsch@suse.de
- updated to Mesa 6.5.3
- obsoletes the following patches:
  * bug-211314_mesa-destroy_buffers.diff
  * bug-211314_mesa-framebuffer-counting.diff
  * bug-211314-patch-1.diff
  * bug-211314-patch-2.diff
  * bug-211314-patch-3.diff
  * bug-211314-patch-4.diff
  * bug-211314-patch-5.diff
  * bug-211314-patch-6.diff
  * bug-211314-patch-7.diff
  * bug-211314-patch-8.diff
  * bug-211314-patch-9.diff
  * bug-211314-patch-10.diff
  * bug-211314-patch-11.diff
  * bug-211314_mesa-refcount-memleak-fixes.diff
  * Mesa-6.5.2-fix_radeon_cliprect.diff
* Fri Apr 27 2007 sndirsch@suse.de
- back to Mesa 6.5.2 (Bug #269155/269042)
* Wed Apr 25 2007 sndirsch@suse.de
- 4th RC ready
  * This fixes some breakage in RC3.
* Tue Apr 24 2007 sndirsch@suse.de
- 3rd release candidate
  * updated Windows/VC8 project files.
* Sun Apr 22 2007 sndirsch@suse.de
- updated to Mesa 6.5.3rc2
  * a number of bug fixes since the first RC
* Sat Apr 21 2007 sndirsch@suse.de
- updated to Mesa 6.5.3rc1
- obsoletes the following patches:
  * bug-211314_mesa-destroy_buffers.diff
  * bug-211314_mesa-framebuffer-counting.diff
  * bug-211314-patch-1.diff
  * bug-211314-patch-2.diff
  * bug-211314-patch-3.diff
  * bug-211314-patch-4.diff
  * bug-211314-patch-5.diff
  * bug-211314-patch-6.diff
  * bug-211314-patch-7.diff
  * bug-211314-patch-8.diff
  * bug-211314-patch-9.diff
  * bug-211314-patch-10.diff
  * bug-211314-patch-11.diff
  * bug-211314_mesa-refcount-memleak-fixes.diff
  * Mesa-6.5.2-fix_radeon_cliprect.diff
* Tue Apr 10 2007 sndirsch@suse.de
- Mesa-6.5.2-fix_radeon_cliprect.diff:
  * fixes X.Org Bug #9876
* Wed Apr  4 2007 sndirsch@suse.de
- bug-211314_mesa-refcount-memleak-fixes.diff:
  * Fix for memleaks and refount bugs (Bug #211314)
* Mon Mar 19 2007 sndirsch@suse.de
- no longer apply bug-211314_mesa-context.diff (Bug #211314,
  commment #114)
- added different Mesa patches (Bug #211314, comments #114/#115)
* Wed Mar 14 2007 sndirsch@suse.de
- removed libIndirectGL.so (Bug #254317)
- README.updates: new location of DRI drivers (Bug #254318)
* Wed Jan 24 2007 sndirsch@suse.de
- fixed build on ppc64/s390/s390x
* Thu Jan 18 2007 sndirsch@suse.de
- added libIndirectGL for indirect rendering only (Bug #234154)
* Wed Jan 17 2007 sndirsch@suse.de
- bug-211314_mesa-context.diff:
  * fixes Xserver crash in software rendering fallback (Bug #211314)
* Tue Jan  9 2007 sndirsch@suse.de
- disabled build of sis DRI driver on i64 to fix build
* Sat Dec  2 2006 sndirsch@suse.de
- updated to Mesa 6.5.2
  * New features
  - New DRI memory manager system. Currently used by the i915tex
    driver. Other DRI drivers will be updated to use the new memory
    manager in coming months. To use the new driver you'll need the
    most recent DRM library and drivers (version 2.2 or later) and a
    recent xf86-video-intel driver module from X.org. New features
    resulting from this work include:
  * EXT_framebuffer_objects, render to texture
  * ARB_pixel_buffer_objects
  * Accelerated CopyTexSubimage, DrawPixels, ReadPixels, CopyPixels
  * Accelerated texture uploads from pixel buffer objects
  * Potentially texturing directly from the pixel buffer object
    (zero copy texturing).
  - New Intel i965 DRI driver
  - New minstall script to replace normal install program
  - Faster fragment program execution in software
  - Added (or fixed) support for GLX_SGI_make_current_read to the
    following drivers:
  * radeon
  * savage
  * mga
  * tdfx
  - Added support for ARB_occlusion_query to the tdfx driver
    (Ian Romanick).
  * Bug fixes
  - fixed invalid memory read while rendering textured points (bug 8320)
  - fixed problems with freebsd-dri configuration (bug 8344)
  - Mesa's fake glxGetCurrentContext() wasn't thread-aware
  - OPTION NV_position_invariant didn't work in NV vertex programs
  - glDrawPixels into a user-created framebuffer object could crash Xlib driver
  - Line clipping was broken in some circumstances
  - fragment.fogcoord register didn't always contain the correct value
  - RGBA logicops didn't work reliably in some DRI drivers
  - Fixed broken RGBA LogicOps in Intel DRI drivers
  - Fixed some fragment program bugs in Intel i915 DRI driver
  - Fixed glGetVertexAttribfvARB bug 8883
  - Implemented glGetUniform[fi]vARB() functions
  - Fixed glDrawPixels(GL_COLOR_INDEX, GL_BITMAP) segfault (bug 9044)
  - Fixed some gluBuild2DMipmaps() bugs (Greg McGarragh)
  - Fixed broken "mgl" name mangling
  - Indirect rending was broken for glMap* functions (bug 8899)
  * Internal code changes
  - The device driver functions ResizeBuffers and GetBufferSize have
    been decprecated.
  - OpenGL 2.0 and 2.1 support is nearly done. We need to do quite a
    bit more testing of the shading language functions.
* Thu Nov 23 2006 sndirsch@suse.de
- enabled build of i965 DRI driver on x86_64
* Fri Nov 10 2006 sndirsch@suse.de
- fixed typos (Bug #219732)
* Wed Oct 18 2006 sndirsch@suse.de
- added static libGLU to Mesa-devel-static package (Bug #212532)
* Tue Oct 10 2006 sndirsch@suse.de
- fixed build on s390x
* Mon Oct  9 2006 sndirsch@suse.de
- i915-crossbar.diff:
  * fixes ARB_texture_env_crossbar extension (X.Org Bug #8292)
* Mon Sep 18 2006 sndirsch@suse.de
- updated to Mesa 6.5.1:
  New:
  * Intel i965 DRI driver
  * GL_APPLE_vertex_array_object extension (Ian Romanick)
  * GL_EXT_texture_sRGB extension
  * GL_EXT_gpu_program_parameters (Ian Romanick)
  * "engine" demo
  * updated fbdev driver and GLUT for fbdev (Sean D'Epagnier)
  * many updates to the DRI drivers
  Changes:
  * The glVertexAttribARB functions no longer alias the
    conventional vertex attributes.
  * glxinfo program prints more info with -l option
  * GL_FRAGMENT_PROGRAM_NV and GL_FRAGMENT_PROGRAM_ARB are now
    compatible, in terms of glBindProgramARB()
  * The GL_ARB_vertex_program attribute vertex.weight is now
    accepted by the parser, even though the GL_ARB_vertex_blend and
    GL_EXT_vertex_weighting extensions aren't supported. Allows Warcraft
    to run.
  Bug fixes:
  * fixed broken texture border handling for depth textures (bug 6498)
  * removed the test for duplicated framebuffer attachments, per
    version 117 of the GL_EXT_framebuffer_object specification
  * fixed a few render-to-texture bugs, including render to depth
    texture
  * clipping of lines against user-defined clip planes was broken
    (6512)
  * assembly language dispatch for SPARC was broken (bug 6484)
  * assorted compilation fixes on various Unix platforms (Dan Schikore)
  * glPopAttrib could restore an invalid value for GL_DRAW_BUFFER
  * assorted minor fixes for 16 and 32 bit/channel modes
  * fixed assorted bugs in texture compression paths
  * fixed indirect rendering vertex array crashes (bug 6863)
  * glDrawPixels GL_INDEX_OFFSET didn't always work
  * fixed convolution memory leak (bug 7077)
  * rectangular depth textures didn't work
  * invalid mode to glBegin didn't generate an error (bug 7142)
  * 'normalized' parameter to glVertexAttribPointerARB didn't work
  * disable bogus GLX_SGI_video_sync extension in xlib driver
  * fixed R128 driver locking bug (Martijn van Oosterhout)
  * using evaluators with vertex programs caused crashes (bug 7564)
  * fragment.position wasn't set correctly for point/line primitives
  * fixed parser bug for scalar sources for GL_NV_fragment_program
  * max fragment program length was incorrectly 128, now 1024
  * writes to result.depth in fragment programs weren't clamped to
    [0,1]
  * fixed potential dangling pointer bug in glBindProgram()
  * fixed some memory leaks (and potential crashes) in Xlib driver
* Sat Sep  9 2006 sndirsch@suse.de
- removed two source files with imcompatible license from Mesa
  tarball (Bug #204110)
- added a check to specfile to make sure that these will not be
  reintroduced with the next Mesa update again (Bug #204110)
* Mon Aug 21 2006 sndirsch@suse.de
- moved via profile.d scripts from x11-tools to this package
* Thu Aug 17 2006 sndirsch@suse.de
- dri_driver_dir.diff:
  * DEFAULT_DRIVER_DIR is set during make call in specfile
    (Bug #199958)
- disabled build of GLw (extra package MesaGLw)
* Mon Jul 31 2006 sndirsch@suse.de
- updated to Mesa 6.5_20060712; required by xorg-server 1.1.99.3
- cleanup
* Wed Jul 19 2006 ro@suse.de
- adapt to /usr/lib move
* Sun Jun 25 2006 sndirsch@suse.de
- fixed build for X.Org 7.1
* Wed Jun 21 2006 sndirsch@suse.de
- udpated to Mesa 6.5
  * obsoletes
  - Mesa-glx-x11-render-texture-2.diff
  - Mesa-radeon-large-textures-1.diff
  - Mesa_945GM.patch
  - mesa-6.4.2-dri-copy-sub-buffer-2.patch
  - mesa-6.4.2-scissor-fix-1.patch
- cleanup: removed no longer used sources/patches
  * missing-headers.diff
  * missing-headers.tar.bz2
  * glidelibs-i386.tar.gz
* Mon Jun 19 2006 sndirsch@suse.de
- added missing manual pages (Bug #185707)
* Fri Jun 16 2006 dreveman@suse.de
- Fix issue in copy-sub-buffer patch. Extension was not
  enabled on all radeon cards. (bnc 174839)
- Add radeon large texture patch (back port from latest stable
  release of Mesa). (bnc 174839)
* Tue May 23 2006 sndirsch@suse.de
- no longer remove NVIDIA installer in %%pre
* Mon May 22 2006 sndirsch@suse.de
- reverted Mesa/MesaGLU split
- fixed libGLcore.so.1 (e.g. soname); required to create a
  non-conflicting package for the NVIDIA driver (Bug #175683)
* Tue May 16 2006 sndirsch@suse.de
- splitted off MesaGLU/MesaGLU-devel
- added ldconfig to %%postun
* Sat Apr 22 2006 sndirsch@suse.de
- licensefix.patch:
  * fixed incompatible GPL license (Bug #133238, Mesa Bug #6490)
* Thu Apr 13 2006 sndirsch@suse.de
- added /usr/X11R6/%%{_lib}/modules/dri/updates/README.updates to
  document DRI driver update mechanism
* Wed Apr 12 2006 sndirsch@suse.de
- enhanced search path for DRI driver updates (FATE #300553)
* Mon Apr  3 2006 sndirsch@suse.de
- mesa-6.4.2-dri-copy-sub-buffer-1.patch:
  * needed for open source drivers to work with Xgl (David Reveman)
* Wed Mar 15 2006 mhopf@suse.de
- Fix for bug #157051, issue 1:
  On intel the graphics is only displayed correctly after a scissor region
  other than full screen is specified.
* Mon Feb  6 2006 sndirsch@suse.de
- update to Mesa 6.4.2 (obsoletes tnl_init.diff)
  * New items:
  - added OSMesaColorClamp() function/feature
  - added wglGetExtensionStringARB() function
  * Bug fixes:
  - fixed some problems when building on Windows
  - GLw header files weren't installed by installmesa script (bug 5396)
  - GL/glfbdev.h file was missing from tarballs
  - fixed TNL initialization bug which could lead to crash (bug 5791)
* Mon Feb  6 2006 sndirsch@suse.de
- tnl_init.diff (Mesa Bug #5791):
  * fixes TNL initialization bug which could lead to crash
    (CVS changelog: use calloc instead of malloc so try_codegen
    field is initialized to zero)
* Mon Jan 30 2006 sndirsch@suse.de
- glxext-sgi-hyperpipe.patch:
  * GLX_SGIX_hyperpipe_group -> GLX_SGIX_hyperpipe (Bug #146646)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 sndirsch@suse.de
- Mesa_945GM.patch:
  * 945GM support by Charles Johnson (FATE #151391)
* Wed Dec 28 2005 sndirsch@suse.de
- moved header files and libGL.so from Mesa-devel to Mesa to make
  uninstallation of nvidia driver in %%pre of Mesa-devel obsolete
* Wed Nov 30 2005 sndirsch@suse.de
- update to Mesa 6.4.1
* Fri Nov 18 2005 sndirsch@suse.de
- updated to Mesa 6.4 branch (2005-11-18)
- added static libGL (new Mesa-devel-static package)
- removed glut headers from installation (we use freeglut!)
* Tue Nov 15 2005 sndirsch@suse.de
- updated to Mesa 6.4 branch (2005-11-12)
* Wed Nov  9 2005 sndirsch@suse.de
- fixed libOSMesa build
* Tue Nov  8 2005 sndirsch@suse.de
- added build of libOSMesa, e.g. required by tulip package
* Tue Nov  8 2005 sndirsch@suse.de
- added include files for SGI's OpenGL Xt/Motif widgets, e.g.
  required by z88 package
  * GLwMDrawA.h
  * GLwDrawAP.h
  * GLwMDrawAP.h
  * GLwDrawA.h
- enabled Motif support in libGLw, also required by z88 package
* Mon Nov  7 2005 sndirsch@suse.de
- use glx headers from xorg-x11-devel package
* Fri Oct 28 2005 sndirsch@suse.de
- Mesa-glx-x11-render-texture-2.diff/missing-headers.diff:
  * new MESA_render_texture extension for Xgl (dreveman/mhopf)
* Tue Oct 25 2005 sndirsch@suse.de
- fixed DRI driver path for 64bit platforms
* Tue Oct 25 2005 sndirsch@suse.de
- update to Mesa 6.4
* Mon Oct 24 2005 sndirsch@suse.de
- build DRI compatible libGL
* Fri Oct 21 2005 sndirsch@suse.de
- added dummy nvidia libGLcore.so.1 for applications, which are
  still linked against libGL.so.1 of older nvidia driver releases
- duplicate libGL (located in /usr/lib/GL) to make workarounds
  like LD_PRELOAD possible if nvidia driver is installed and its
  libGl does not work
* Wed Oct 19 2005 sndirsch@suse.de
- no longer install libglide (disables 3Dfx DRI support)
* Sun Oct  2 2005 sndirsch@suse.de
- created package
